@@ -1,11 +1,10 @@
 package geogebra;
 
+import geogebra.kernel.View;
 import geogebra.main.Application;
-import geogebra.main.DefaultApplication;
 import geogebra.plugin.GgbAPI;
 
 import java.awt.BorderLayout;
-import java.io.File;
 import java.net.URL;
 import java.util.Locale;
 
@@ -72,22 +71,14 @@ public class GeoGebraPanel extends JPanel {
      * call buildGUI() after this method.
      */
 	public GeoGebraPanel() {
-		this(null, null);
-	}
-	
-	/**
-     * Creates a GeoGebraPanel. Note that you need to 
-     * call buildGUI() after this method.
-     */
-	public GeoGebraPanel(URL ggbFile) {
-		this(ggbFile, null);
+		this(null);
 	}
 	
 	/**
      * Creates a GeoGebraPanel and loads the given ggbFile.
      * Note that you need to call buildGUI() after this method.
      */
-	public GeoGebraPanel(URL ggbFile, String externalCodebase) {
+	public GeoGebraPanel(URL ggbFile) {
 		// use filename as argument
 		String [] args = null;
 		if (ggbFile != null) {
@@ -96,7 +87,7 @@ public class GeoGebraPanel extends JPanel {
 		}
 		
 		// create GeoGebra application
-		app = new DefaultApplication(args, this, false, externalCodebase);
+		app = new Application(new CommandLineArguments(args), this, false);
 	}
 	
 	/**
@@ -117,6 +108,13 @@ public class GeoGebraPanel extends JPanel {
 		app.setShowToolBar(showToolBar, true);	
 	}
 	
+	/**
+	 * Sets the font size of the GeoGebra user interface.
+	 */
+	public synchronized void setFontSize(int points) {
+		app.setFontSize(points);
+	}
+	
 	/**
 	 * Sets the maximum pixel size of all icons in the GeoGebra
 	 * user interface including the toolbar. 
@@ -126,13 +124,6 @@ public class GeoGebraPanel extends JPanel {
 		app.setMaxIconSize(pixel);
 	}
 	
-	/**
-	 * Sets the font size of the GeoGebra user interface.
-	 */
-	public synchronized void setFontSize(int points) {
-		app.setFontSize(points);
-	}
-	
 	/**
 	 * Tells the panel to show/hide the menu bar.
 	 * Note that you need to call buildGUI() after this 
@@ -148,7 +139,7 @@ public class GeoGebraPanel extends JPanel {
 	 * method to update the panel's structure.
 	 */
 	public synchronized void setShowAlgebraInput(boolean showInputBar) {
-		app.setShowAlgebraInput(showInputBar);	
+		app.setShowAlgebraInput(showInputBar, true);	
 	}
 	
 	/**
@@ -157,7 +148,7 @@ public class GeoGebraPanel extends JPanel {
 	 * method to update the panel's structure.
 	 */
 	public synchronized void setShowAlgebraView(boolean show) {
-		app.setShowAlgebraView(show);	
+		app.getGuiManager().setShowView(show, Application.VIEW_ALGEBRA);	
 	}
 	
 	/**
@@ -166,7 +157,7 @@ public class GeoGebraPanel extends JPanel {
 	 * method to update the panel's structure.
 	 */
 	public synchronized void setShowSpreadsheetView(boolean show) {
-		app.setShowSpreadsheetView(show);	
+		app.getGuiManager().setShowView(show, Application.VIEW_SPREADSHEET);	
 	}
 	
 	/**
@@ -185,6 +176,20 @@ public class GeoGebraPanel extends JPanel {
 		app.setLanguage(locale);
 	}
 	
+	/**
+	 * Attaches a view to listen to kernel changes.
+	 */
+	public synchronized void attachView(View view) {
+		app.getKernel().attach(view);
+	}
+	
+	/**
+	 * Detaches a view from the kernel.
+	 */
+	public synchronized void detachView(View view) {
+		app.getKernel().detach(view);
+	}
+	
 	/**
 	 * Rebuilds the GeoGebra user interface in this panel.
 	 */
