@@ -46,6 +46,7 @@ import java.awt.geom.AffineTransform;
 import java.awt.geom.Arc2D;
 import java.awt.geom.Area;
 import java.awt.geom.Ellipse2D;
+import java.awt.geom.GeneralPath;
 import java.awt.geom.Point2D;
 import java.awt.geom.QuadCurve2D;
 import java.awt.geom.RectangularShape;
@@ -106,8 +107,8 @@ final public class DrawConic extends Drawable implements Previewable {
     private double x0, y0;
     private double k2;
     private GeoVec2D vertex;
-    private QuadCurve2D.Double parabola;    
-    private double [] parpoints = new double[6];        
+    private GeneralPath parabola;    
+    private double [] parpoints = new double[8];        
     
     // CONIC_HYPERBOLA   
     private boolean firstHyperbola = true;    
@@ -874,51 +875,59 @@ final public class DrawConic extends Drawable implements Previewable {
     	
         if (firstParabola) {                                      
             firstParabola = false;
-            parabola = new QuadCurve2D.Double();                    
+            parabola = new GeneralPath();                    
         }                
         // calc control points coords of parabola y^2 = 2 p x                
-        x0 = Math.max( Math.abs(vertex.x - view.xmin),
-                       		   Math.abs(vertex.x - view.xmax) );                                      
-        x0 = Math.max(x0, Math.abs(vertex.y - view.ymin));
-		x0 = Math.max(x0, Math.abs(vertex.y - view.ymax));
-		
-        /*
-        x0 *= 2.0d;
-        // y^2 = 2px
-        y0 = Math.sqrt(2*c.p*x0);
-        */
-        
-        // avoid sqrt by choosing x = k*p with         
-        // i = 2*k is quadratic number
-        // make parabola big enough: k*p >= 2*x0 -> 2*k >= 4*x0/p
-        x0 = 4*x0/conic.p;
-        
-        // changed these to doubles, see #654 y=x^2+100000x+1
-        double i = 4; 
-        k2 = 16;
-        
-        while (k2 < x0) {
-            i += 2;
-            k2 = i * i;
-        }
-        x0 = k2/2 * conic.p; // x = k*p
-        y0 = i * conic.p;    // y = sqrt(2k p^2) = i p                
-        
-		//	set transform
-		transform.setTransform(view.coordTransform);
-		transform.concatenate(view.getTransform(conic,M,ev));
-         
-        // setCurve(P0, P1, P2)    
-        //parabola.setCurve(x0, y0, -x0, 0.0, x0, -y0);  
-        //shape = transform.createTransformedShape(parabola);
-        parpoints[0] = x0;
-        parpoints[1] = y0;
-        parpoints[2] = -x0;
-        parpoints[3] = 0.0;
-        parpoints[4] = x0;
-        parpoints[5] = -y0;
-        transform.transform(parpoints, 0, parpoints, 0, 3);
-        parabola.setCurve(parpoints, 0);
+     // calc control points coords of parabola y^2 = 2 p x
+     		x0 = Math.max(Math.abs(vertex.getX() - view.getXmin()),
+     				Math.abs(vertex.getX() - view.getXmax()));
+     		x0 = Math.max(x0, Math.abs(vertex.getY() - view.getYmin()));
+     		x0 = Math.max(x0, Math.abs(vertex.getY() - view.getYmax()));
+
+     		/*
+     		 * x0 *= 2.0d; // y^2 = 2px y0 = Math.sqrt(2*c.p*x0);
+     		 */
+
+     		// avoid sqrt by choosing x = k*p with
+     		// i = 2*k is quadratic number
+     		// make parabola big enough: k*p >= 2*x0 -> 2*k >= 4*x0/p
+     		x0 = 4 * x0 / conic.p;
+
+     		// changed these to doubles, see #654 y=x^2+100000x+1
+     		double i = 4;
+     		k2 = 16;
+
+     		while (k2 < x0) {
+     			i += 2;
+     			k2 = i * i;
+     		}
+     		x0 = k2 / 2 * conic.p; // x = k*p
+     		y0 = i * conic.p; // y = sqrt(2k p^2) = i p
+
+     		// set transform
+     		transform.setTransform(view.coordTransform);
+     		transform.concatenate(view.getTransform(conic, M, ev));
+
+     		// setCurve(P0, P1, P2)
+     		// parabola.setCurve(x0, y0, -x0, 0.0, x0, -y0);
+     		// shape = transform.createTransformedShape(parabola);
+     		parpoints[0] = x0;
+     		parpoints[1] = y0;
+     		
+     		parpoints[2] = -x0/3;
+     		parpoints[3] = y0/3;
+     		
+     		parpoints[4] = -x0/3;
+     		parpoints[5] = -y0/3;
+     		
+     		parpoints[6] = x0;
+     		parpoints[7] = -y0;
+     		transform.transform(parpoints, 0, parpoints, 0, 4);
+     		parabola.reset();
+     		parabola.moveTo((float)parpoints[0], (float)parpoints[1]);
+     		parabola.curveTo(
+     			(float)parpoints[2], (float)parpoints[3], (float)parpoints[4],
+     			(float)parpoints[5], (float)parpoints[6], (float)parpoints[7]);
         shape = parabola;                     
 
         // set label coords
