@@ -13,13 +13,18 @@ the Free Software Foundation.
 package geogebra.euclidian;
 
 import geogebra.kernel.GeoElement;
+import geogebra.kernel.GeoFunction;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.ParametricCurve;
+import geogebra.kernel.VarString;
 import geogebra.kernel.roots.RealRootUtil;
+import geogebra.main.Application;
 
 import java.awt.Graphics2D;
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.Shape;
+import java.awt.geom.Area;
 import java.awt.geom.Point2D;
 
 /**
@@ -41,10 +46,21 @@ public class DrawParametricCurve extends Drawable {
 	// maximum number of bisections (max number of plot points = 2^MAX_DEPTH)
 	private static final int MAX_DEFINED_BISECTIONS = 16;
 	private static final int MAX_PROBLEM_BISECTIONS = 8;
+	
+	// maximum number of times to loop when xDiff, yDiff are both zero
+	// eg Curve[0sin(t), 0t, t, 0, 6]
+	private static final int MAX_ZERO_COUNT = 1000;
 
 	// the curve is sampled at least at this many positions to plot it
 	private static final int MIN_SAMPLE_POINTS = 80;
 	
+	public static final int GAP_LINE_TO = 0;
+	public static final int GAP_MOVE_TO = 1;
+	public static final int GAP_RESET_XMIN = 2;
+	public static final int GAP_RESET_YMIN = 3;
+	public static final int GAP_RESET_XMAX = 4;
+	public static final int GAP_RESET_YMAX = 5;
+	
 
 //	low quality settings
 //	// maximum and minimum distance between two plot points in pixels
@@ -70,12 +86,20 @@ public class DrawParametricCurve extends Drawable {
     private static int countPoints = 0;
 	private static long countEvaluations = 0;
    
+	/**
+	 * Creates graphical representation of the curve 
+	 * @param view Euclidian view in which it should be drawn
+	 * @param curve Curve to be drawn
+	 */
     public DrawParametricCurve(EuclidianView view, ParametricCurve curve) {
     	this.view = view;
+    	hitThreshold = view.getCapturingThreshold();
         this.curve = curve;
         geo = curve.toGeoElement();        
         update();
     }
+    
+    StringBuilder labelSB = new StringBuilder();
 
     final public void update() {				   
         isVisible = geo.isEuclidianVisible();
@@ -88,11 +112,32 @@ public class DrawParametricCurve extends Drawable {
 		
 		fillCurve = filling(curve);
 		
-		Point labelPoint = plotCurve(curve,
-					curve.getMinParameter(),
-					curve.getMaxParameter(), 
+		double min = curve.getMinParameter();
+		double max = curve.getMaxParameter();
+		if (curve instanceof GeoFunction){
+			double minView = ((GeoElement) curve).getXmin(view);
+			double maxView = ((GeoElement) curve).getXmax(view);
+			if (min<minView)
+				min=minView;
+			if (max>maxView)
+				max=maxView;				
+		}
+		Point labelPoint;
+		
+		
+		
+		if (Kernel.isEqual(min, max)) {
+			double [] eval = new double[2];
+			curve.evaluateCurve(min, eval);
+			view.toScreenCoords(eval);
+			labelPoint = new Point((int)eval[0], (int)eval[1]);
+		} else {
+			labelPoint = plotCurve(curve,
+					min,
+					max,
 					view, gp,
-					labelVisible, !fillCurve); 
+					labelVisible, fillCurve?0:1); 
+		}
 
 		// gp on screen?		
 		if (!gp.intersects(0,0, view.width, view.height)) {				
@@ -103,10 +148,41 @@ public class DrawParametricCurve extends Drawable {
 		if (labelPoint != null) {
 			xLabel = labelPoint.x;
 			yLabel = labelPoint.y;
-			labelDesc = geo.getLabelDescription();
-			addLabelOffset();
+			switch (geo.labelMode) {
+			case GeoElement.LABEL_NAME_VALUE :
+				labelSB.setLength(0);
+				labelSB.append('$');
+				labelSB.append(geo.getLabel());
+				labelSB.append('(');
+				labelSB.append(((VarString)geo).getVarString());
+				labelSB.append(")\\;=\\;");
+				labelSB.append(geo.getLaTeXdescription());
+				labelSB.append('$');
+				
+				labelDesc = labelSB.toString();
+				break;
+
+			case GeoElement.LABEL_VALUE :
+				labelSB.setLength(0);
+				labelSB.append('$');
+				labelSB.append(geo.getLaTeXdescription());
+				labelSB.append('$');
+				
+				labelDesc = labelSB.toString();
+				break;
+				
+			case GeoElement.LABEL_CAPTION: 
+			default : // case LABEL_NAME:
+				labelDesc = geo.getLabelDescription();
+			}
+			addLabelOffset(true);
 		}
+		//shape for filling
 		
+		if(geo.isInverseFill()){			
+			setShape(new Area(view.getBoundingPath()));
+			getShape().subtract(new Area(gp));
+		}
 		// draw trace
 		if (curve.getTrace()) {
 			isTracing = true;
@@ -122,9 +198,13 @@ public class DrawParametricCurve extends Drawable {
     
     /**
      * Draws a parametric curve (x(t), y(t)) for t in [t1, t2]. 
-     * @param gp: generalpath that can be drawn afterwards
-     * @param calcLabelPos: whether label position should be calculated and returned
-     * @param moveToAllowed: whether moveTo() may be used for gp
+     * @param t1  min value of parameter
+     * @param t2 max value of parameter
+     * @param curve curve to be drawn
+     * @param view Euclidian view to be used
+     * @param gp generalpath that can be drawn afterwards
+     * @param calcLabelPos whether label position should be calculated and returned
+     * @param moveToAllowed whether moveTo() may be used for gp
      * @return label position as Point
      * @author Markus Hohenwarter, based on an algorithm by John Gillam     
      */
@@ -132,7 +212,7 @@ public class DrawParametricCurve extends Drawable {
 			double t1, double t2, EuclidianView view, 
 			GeneralPathClipped gp,
 			boolean calcLabelPos, 
-			boolean moveToAllowed) 
+			int moveToAllowed) 
     {     		
 
     	countPoints = 0; 
@@ -172,11 +252,11 @@ public class DrawParametricCurve extends Drawable {
     /**
      * Draws a parametric curve (x(t), y(t)) for t in [t1, t2]. 
      * @param: max_param_step: largest parameter step width allowed
-     * @param gp: generalpath that can be drawn afterwards
-     * @param calcLabelPos: whether label position should be calculated and returned
-     * @param moveToAllowed: whether moveTo() may be used for gp
+     * @param gp generalpath that can be drawn afterwards
+     * @param calcLabelPos whether label position should be calculated and returned
+     * @param moveToAllowed whether moveTo() may be used for gp
      * @return label position as Point
-     * @author Markus Hohenwarter, based on an algorithm by John Gillam     
+     * @author Markus Hohenwarter, based on an algori5thm by John Gillam     
      */
 	 private static Point plotInterval(ParametricCurve curve,
 								double t1, double t2, int intervalDepth,
@@ -184,7 +264,7 @@ public class DrawParametricCurve extends Drawable {
 								EuclidianView view, 
 								GeneralPathClipped gp,
 								boolean calcLabelPos, 
-								boolean moveToAllowed) 
+								int moveToAllowed) 
 	 {		
 		// plot interval for t in [t1, t2]
 		// If we run into a problem, i.e. an undefined point f(t), we bisect
@@ -229,12 +309,46 @@ public class DrawParametricCurve extends Drawable {
 		// FIRST POINT
 		// c(t1) and c(t2) are defined, lets go ahead and move to our first point (x0, y0) 
 		// note: lineTo will automatically do a moveTo if this is the first gp point
-		if (moveToAllowed) {	
+		if (moveToAllowed == GAP_MOVE_TO) {	
 			moveTo(gp, x0, y0);
-		} else {
+		} else if (moveToAllowed == GAP_LINE_TO){
 			lineTo(gp, x0, y0);
-		}			
-	
+		}else if (moveToAllowed == GAP_RESET_XMIN){
+			double d = gp.getCurrentPoint().getY();
+			if(!Kernel.isEqual(d, y0)){
+				lineTo(gp, -10,d);
+				lineTo(gp, -10,y0);
+			}
+			lineTo(gp, x0, y0);
+
+		}
+		else if (moveToAllowed == GAP_RESET_XMAX){
+			double d = gp.getCurrentPoint().getY();
+			if(!Kernel.isEqual(d, y0)){
+				lineTo(gp, view.width+10,d);
+				lineTo(gp, view.width+10,y0);
+			}
+			lineTo(gp, x0, y0);
+			
+		}
+		else if (moveToAllowed == GAP_RESET_YMIN){
+			double d = gp.getCurrentPoint().getX();
+			if(!Kernel.isEqual(d, x0)){
+				lineTo(gp, d,-10);
+				lineTo(gp, x0,-10);
+			}
+				lineTo(gp, x0, y0);
+		}
+		else if (moveToAllowed == GAP_RESET_YMAX){
+			double d = gp.getCurrentPoint().getX();
+			if(!Kernel.isEqual(d, x0)){
+			lineTo(gp, gp.getCurrentPoint().getX(),view.height+10);
+			lineTo(gp, x0,view.height+10);
+			}
+			lineTo(gp, x0, y0);
+		}
+
+		//TODO	
 		// INIT plotting algorithm
 		int LENGTH = MAX_DEFINED_BISECTIONS + 1;
 		int dyadicStack[]=new int[LENGTH];
@@ -256,6 +370,7 @@ public class DrawParametricCurve extends Drawable {
 		// slope between (t1, t2)
 		double ydiff = y - y0;
 		double xdiff = x - x0;
+		int countDiffZeros = 0;
 		
 		// init previous slope using (t1, t1 + min_step)
 		curve.evaluateCurve(t1 + divisors[LENGTH-1], eval);	
@@ -290,6 +405,8 @@ public class DrawParametricCurve extends Drawable {
 					depth < MAX_DEFINED_BISECTIONS &&
 					// distance not ok  or  angle not ok  or  step too big
 					(!distanceOK || !angleOK || divisors[depth] > max_param_step)
+					// make sure we don't get stuck on eg Curve[0sin(t), 0t, t, 0, 6]
+					&& countDiffZeros < MAX_ZERO_COUNT
 				)
 			{
 				// push stacks
@@ -327,6 +444,12 @@ public class DrawParametricCurve extends Drawable {
 				y = eval[1]; // yEval(t);	
 				xdiff = x - x0;
 				ydiff = y - y0;	
+				
+				if (Kernel.isZero(xdiff) && Kernel.isZero(ydiff)) {
+					countDiffZeros++;
+				} else {
+					countDiffZeros = 0;
+				}
 					
 				// segment from last point off screen?
 				segOffScreen = isSegmentOffScreen(view, x0, y0, x, y);
@@ -341,7 +464,8 @@ public class DrawParametricCurve extends Drawable {
 			
 			// add point to general path: lineTo or moveTo?
 			boolean lineTo = true;
-			if (moveToAllowed) {
+			//TODO
+			if (moveToAllowed == GAP_MOVE_TO) {
 				if (segOffScreen) {
 					// don't draw segments that are off screen
 					lineTo = false;
@@ -380,7 +504,7 @@ public class DrawParametricCurve extends Drawable {
 			if (needLabelPos && onScreen) {
 				double xLabel = x + 10;
 				if (xLabel < 20) xLabel = 5;					
-			
+				if (xLabel > view.width - 30) xLabel = view.width-15;
 				double yLabel = y + 15;		
 				if (yLabel < 40) 
 					yLabel = 15;
@@ -534,7 +658,7 @@ public class DrawParametricCurve extends Drawable {
 		 // close to screen
 		 return false;
 	 }
-	 	 
+	 
 	 /**
 	  * Returns whether the angle between the vectors (vx, vy) and (wx, wy)
 	  * is smaller than MAX_BEND, where MAX_BEND = tan(MAX_ANGLE).
@@ -574,7 +698,7 @@ public class DrawParametricCurve extends Drawable {
 				EuclidianView view, 
 				GeneralPathClipped gp,
 				boolean calcLabelPos, 
-				boolean moveToAllowed, Point labelPoint) 
+				int moveToAllowed, Point labelPoint) 
 	 {
 		// stop recursion for too many intervals
 		if (intervalDepth > MAX_PROBLEM_BISECTIONS || t1 == t2) {	
@@ -667,6 +791,9 @@ public class DrawParametricCurve extends Drawable {
 	 /**
 	  * Calls gp.moveTo(x, y) only if the current point
 	  * is not already at this position.
+	  * @param gp path of the curve
+	  * @param x x-coord of start point
+	  * @param y y-coord of start point
 	  */
 	 public static void moveTo(GeneralPathClipped gp, double x, double y) {		
 		 drawTo(gp, x, y, false);
@@ -675,6 +802,9 @@ public class DrawParametricCurve extends Drawable {
 	 /**
 	  * Calls gp.lineTo(x, y) only if the current point
 	  * is not already at this position.
+	  * @param gp path of the curve
+	  * @param x x-coord of target point
+	  * @param y y-coord of target point
 	  */
 	 public static void lineTo(GeneralPathClipped gp, double x, double y) {			 		 
 		 drawTo(gp, x, y, true);
@@ -845,8 +975,9 @@ public class DrawParametricCurve extends Drawable {
 			
         	if (fillCurve) {
 				try {
-	            	g2.setPaint(geo.getFillColor());                                  
-					g2.fill(gp);    
+					
+					fill(g2, geo.isInverseFill()?getShape():gp, false); // fill using default/hatching/image as appropriate
+
 				} catch (Exception e) {
 					System.err.println(e.getMessage());
 				}   
@@ -860,19 +991,27 @@ public class DrawParametricCurve extends Drawable {
         }
     }		
     
+	/**
+	 * Draw trace of the curve
+	 * @param g2 Graphic to be used
+	 */
 	final void drawTrace(Graphics2D g2) {	   
 	   g2.setPaint(geo.getObjectColor());	   
 	   g2.setStroke(objStroke); 		   
 	   drawWithValueStrokePure(gp, g2);		   
 	}		
     
-	final public boolean hit(int x,int y) {  
+	final public boolean hit(int x,int y) {  		
     	if (isVisible) {
+    		Shape t = geo.isInverseFill()?getShape():gp;
     		if (strokedShape == null) {
     			strokedShape = objStroke.createStrokedShape(gp);
     		}    		
-    		return strokedShape.intersects(x-3,y-3,6,6);
-    	} else
+    		if (geo.getAlphaValue() > 0.0f || geo.isHatchingEnabled())
+    			return t.intersects(x-hitThreshold,y-hitThreshold,2*hitThreshold,2*hitThreshold); 					
+    		else
+    			return strokedShape.intersects(x-hitThreshold,y-hitThreshold,2*hitThreshold,2*hitThreshold); 
+         	} else
     		return false;
     	/*
     	return gp.intersects(x-3,y-3,6,6)
@@ -881,7 +1020,7 @@ public class DrawParametricCurve extends Drawable {
     }
 	
     final public boolean isInside(Rectangle rect) {
-    	return rect.contains(gp.getBounds());  
+    	return gp != null && rect.contains(gp.getBounds());  
     }
     
     public GeoElement getGeoElement() {
@@ -904,7 +1043,7 @@ public class DrawParametricCurve extends Drawable {
 	
 	final private static boolean filling(ParametricCurve curve) {
 		return !curve.isFunctionInX() &&
-				curve.toGeoElement().getAlphaValue() > 0;
+				(curve.toGeoElement().getAlphaValue() > 0 || curve.toGeoElement().isHatchingEnabled());
 	}
 
 }
