@@ -152,7 +152,7 @@ public final class DrawPoint extends Drawable {
         
         // Math.round to make sure that highlight circles drawn symmetrically
         // (eg after zoom when points aren't on pixel boundaries)
-        if (!view.getApplication().exporting) {
+        if (!view.getApplication().exporting && pointSize > 2) {
         	xUL = Math.round(xUL);
         	yUL = Math.round(yUL);
         }
