@@ -847,6 +847,24 @@ public abstract class Drawable extends DrawableND {
 		}
 	}
 
+	final void updateStrokesJustLineThickness(GeoElement geo) {
+		strokedShape = null;
+		strokedShape2 = null;
+
+		if (lineThickness != geo.lineThickness) {
+			lineThickness = geo.lineThickness;
+
+			float width = lineThickness / 2.0f;
+			objStroke = new BasicStroke(width, objStroke.getEndCap(), objStroke.getLineJoin(), objStroke.getMiterLimit(),
+					objStroke.getDashArray(), 0.0f);
+			decoStroke = new BasicStroke(width, objStroke.getEndCap(), objStroke.getLineJoin(), objStroke.getMiterLimit(),
+					decoStroke.getDashArray(), 0.0f);
+			selStroke = new BasicStroke(width + EuclidianView.SELECTION_ADD, objStroke.getEndCap(), objStroke.getLineJoin(), objStroke.getMiterLimit(),
+					selStroke.getDashArray(), 0.0f);
+
+		} 
+	}
+
 	final public static void drawWithValueStrokePure(Shape shape, Graphics2D g2) {
 		Object oldHint = g2.getRenderingHint(RenderingHints.KEY_STROKE_CONTROL);
 		g2.setRenderingHint(RenderingHints.KEY_STROKE_CONTROL, RenderingHints.VALUE_STROKE_PURE);
