@@ -8,7 +8,7 @@ import java.awt.Graphics2D;
 public interface Previewable {
 	
 	public void updatePreview(); 
-	public void updateMousePos(int x, int y);
+	public void updateMousePos(double x, double y);
 	public void drawPreview(Graphics2D g2);
 	public void disposePreview();
 	
