@@ -16,7 +16,6 @@ import geogebra.GeoGebra;
 import geogebra.euclidian.EuclidianView;
 import geogebra.export.epsgraphics.ColorMode;
 import geogebra.gui.util.FileTransferable;
-import geogebra.gui.util.ImageSelection;
 import geogebra.io.MyImageIO;
 import geogebra.main.Application;
 import geogebra.main.GeoGebraPreferences;
@@ -27,15 +26,19 @@ import geogebra.util.Util;
 import java.awt.BorderLayout;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
-import java.awt.Image;
 import java.awt.Toolkit;
+import java.awt.datatransfer.Clipboard;
+import java.awt.datatransfer.StringSelection;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
 import java.awt.image.BufferedImage;
+import java.io.ByteArrayOutputStream;
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
+import java.io.OutputStream;
 import java.text.NumberFormat;
 import java.util.Locale;
 
@@ -82,9 +85,30 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	private final int FORMAT_SVG = 3;
 	private final int FORMAT_EMF = 4;
 
-	public GraphicExportDialog(Application app) {
+	private final EuclidianView specifiedEuclidianView;
+
+	/**
+	 * Creates a dialog for exporting an image of the active EuclidianView
+	 * 
+	 * @param app
+	 */
+	public GraphicExportDialog(final Application app) {
+		this(app, null);
+
+	}
+
+	/**
+	 * Creates a dialog for exporting an image of the EuclidianView given as a
+	 * parameter.
+	 * 
+	 * @param app
+	 * @param specifiedEuclidianView
+	 */
+	public GraphicExportDialog(final Application app,
+			final EuclidianView specifiedEuclidianView) {
 		super(app.getFrame(), false);
 		this.app = app;
+		this.specifiedEuclidianView = specifiedEuclidianView;
 
 		sizeLabelFormat = NumberFormat.getInstance(Locale.ENGLISH);
 		sizeLabelFormat.setGroupingUsed(false);
@@ -93,8 +117,15 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		initGUI();
 	}
 
+	private EuclidianView getEuclidianView() {
+		if (specifiedEuclidianView != null) {
+			return specifiedEuclidianView;
+		}
+		return (EuclidianView) app.getActiveEuclidianView();
+	}
+
 	@Override
-	public void setVisible(boolean flag) {
+	public void setVisible(final boolean flag) {
 		if (flag) {
 			loadPreferences();
 			super.setVisible(true);
@@ -108,13 +139,13 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		setResizable(false);
 		setTitle(app.getPlain("ExportAsPicture"));
 
-		JPanel cp = new JPanel(new BorderLayout(5, 5));
+		final JPanel cp = new JPanel(new BorderLayout(5, 5));
 		cp.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
 		getContentPane().add(cp);
 
 		// format list
-		JPanel formatPanel = new JPanel(new FlowLayout(5));
-		String[] formats = {
+		final JPanel formatPanel = new JPanel(new FlowLayout(5));
+		final String[] formats = {
 				app.getPlain("png") + " (" + Application.FILE_EXT_PNG + ")",
 				app.getPlain("pdf") + " (" + Application.FILE_EXT_PDF + ")",
 				app.getPlain("eps") + " (" + Application.FILE_EXT_EPS + ")",
@@ -133,11 +164,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		p.setLayout(new BoxLayout(p, BoxLayout.Y_AXIS));
 
 		// scale
-		EuclidianView ev = (EuclidianView) app.getActiveEuclidianView();
+		final EuclidianView ev = getEuclidianView();
 
 		final PrintScalePanel psp = new PrintScalePanel(app, ev);
 		psp.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
+			public void actionPerformed(final ActionEvent e) {
 				updateSizeLabel();
 			}
 		});
@@ -146,7 +177,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		// dpi combo box
 		final JPanel dpiPanel = new JPanel(new FlowLayout(5));
 
-		String[] dpiStr = { "72", "96", "150", "300", "600" };
+		final String[] dpiStr = { "72", "96", "150", "300", "600" };
 		cbDPI = new JComboBox(dpiStr);
 		cbDPI.setSelectedItem("300");
 		final JLabel resolutionInDPILabel = new JLabel(
@@ -172,34 +203,35 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 
 		p.add(dpiPanel);
 		cbDPI.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent ae) {
+			public void actionPerformed(final ActionEvent ae) {
 				updateSizeLabel();
 			}
 		});
 
-		// if (cbFormat.getSelectedIndex()==FORMAT_SVG || cbFormat.getSelectedIndex()==FORMAT_PDF)
+		// if (cbFormat.getSelectedIndex()==FORMAT_SVG ||
+		// cbFormat.getSelectedIndex()==FORMAT_PDF)
 		// dpiPanel.add(textAsShapesCB);
 
 		cbTransparent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent arg0) {
+			public void actionPerformed(final ActionEvent arg0) {
 				transparent = cbTransparent.isSelected();
 			}
 		});
 
 		cbEMFPlus.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent arg0) {
+			public void actionPerformed(final ActionEvent arg0) {
 				EMFPlus = cbEMFPlus.isSelected();
 			}
 		});
 
 		textAsShapesCB.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent arg0) {
+			public void actionPerformed(final ActionEvent arg0) {
 				textAsShapes = textAsShapesCB.isSelected();
 			}
 		});
 
 		cbFormat.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent arg0) {
+			public void actionPerformed(final ActionEvent arg0) {
 				textAsShapesCB.setEnabled(true);
 				switch (cbFormat.getSelectedIndex()) {
 				case FORMAT_SVG:
@@ -242,7 +274,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		});
 
 		// width and height of picture
-		JPanel sizePanel = new JPanel(new FlowLayout(5));
+		final JPanel sizePanel = new JPanel(new FlowLayout(5));
 		sizePanel.add(new JLabel(app.getPlain("Size") + ":"));
 		sizeLabel = new JLabel();
 		sizePanel.add(sizeLabel);
@@ -252,19 +284,19 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		// Cancel and Export Button
 		cancelButton = new JButton(app.getPlain("Cancel"));
 		cancelButton.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
+			public void actionPerformed(final ActionEvent e) {
 				setVisible(false);
 			}
 		});
-		JButton exportButton = new JButton(app.getMenu("Save"));
+		final JButton exportButton = new JButton(app.getMenu("Save"));
 		exportButton.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				Thread runner = new Thread() {
+			public void actionPerformed(final ActionEvent e) {
+				final Thread runner = new Thread() {
 					@Override
 					public void run() {
 						setVisible(false);
 
-						int index = cbFormat.getSelectedIndex();
+						final int index = cbFormat.getSelectedIndex();
 						switch (index) {
 						case FORMAT_PNG: // PNG
 							exportPNG(false);
@@ -292,15 +324,16 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 				runner.start();
 			}
 		});
-		JButton exportClipboardButton = new JButton(app.getMenu("Clipboard"));
+		final JButton exportClipboardButton = new JButton(
+				app.getMenu("Clipboard"));
 		exportClipboardButton.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				Thread runner = new Thread() {
+			public void actionPerformed(final ActionEvent e) {
+				final Thread runner = new Thread() {
 					@Override
 					public void run() {
 						setVisible(false);
 
-						int index = cbFormat.getSelectedIndex();
+						final int index = cbFormat.getSelectedIndex();
 						switch (index) {
 						case FORMAT_PNG: // PNG
 							exportPNG(true);
@@ -329,7 +362,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 		});
 
-		JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
+		final JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
 		buttonPanel.add(exportButton);
 		buttonPanel.add(exportClipboardButton);
 		buttonPanel.add(cancelButton);
@@ -348,7 +381,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/*
 	 * dpi must be one of 72,96,150,300,600
 	 */
-	public void setDPI(String dpi) {
+	public void setDPI(final String dpi) {
 		cbDPI.setSelectedItem(dpi);
 	}
 
@@ -356,7 +389,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		try {
 			// format
 			int formatID = FORMAT_PNG;
-			String format = GeoGebraPreferences.getPref().loadPreference(
+			final String format = GeoGebraPreferences.getPref().loadPreference(
 					GeoGebraPreferences.EXPORT_PIC_FORMAT, "png");
 			if (format.equals("eps")) {
 				formatID = FORMAT_EPS;
@@ -367,10 +400,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 
 			// dpi
 			if (cbDPI.isEnabled()) {
-				String strDPI = GeoGebraPreferences.getPref().loadPreference(
-						GeoGebraPreferences.EXPORT_PIC_DPI, "300");
+				final String strDPI = GeoGebraPreferences.getPref()
+						.loadPreference(GeoGebraPreferences.EXPORT_PIC_DPI,
+								"300");
 				for (int i = 0; i < cbDPI.getItemCount(); i++) {
-					String dpi = cbDPI.getItemAt(i).toString();
+					final String dpi = cbDPI.getItemAt(i).toString();
 					if (dpi.equals(strDPI)) {
 						cbDPI.setSelectedIndex(i);
 					}
@@ -378,12 +412,14 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 
 			/*
-			 * // scale in cm double scale = Double.parseDouble(GeoGebraPreferences.loadPreference(
-			 * GeoGebraPreferences.EXPORT_PIC_SCALE, "1")); app.getEuclidianView().setPrintingScale(scale);
+			 * // scale in cm double scale =
+			 * Double.parseDouble(GeoGebraPreferences.loadPreference(
+			 * GeoGebraPreferences.EXPORT_PIC_SCALE, "1"));
+			 * app.getEuclidianView().setPrintingScale(scale);
 			 */
 
 			updateSizeLabel();
-		} catch (Exception e) {
+		} catch (final Exception e) {
 			e.printStackTrace();
 		}
 	}
@@ -410,21 +446,24 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 				GeoGebraPreferences.EXPORT_PIC_FORMAT, format);
 
 		/*
-		 * // scale in cm GeoGebraPreferences.savePreference(GeoGebraPreferences.EXPORT_PIC_SCALE,
+		 * // scale in cm
+		 * GeoGebraPreferences.savePreference(GeoGebraPreferences.
+		 * EXPORT_PIC_SCALE,
 		 * Double.toString(app.getEuclidianView().getPrintingScale()));
 		 */
 	}
 
 	private void updateSizeLabel() {
-		EuclidianView ev = (EuclidianView) app.getActiveEuclidianView();
-		double printingScale = ev.getPrintingScale();
+		final EuclidianView ev = getEuclidianView();
+		final double printingScale = ev.getPrintingScale();
 		// takes dpi into account (note: eps has 72dpi)
 		exportScale = (printingScale * getDPI()) / 2.54 / ev.getXscale();
 
-		StringBuilder sb = new StringBuilder();
+		final StringBuilder sb = new StringBuilder();
 		// cm size
-		double cmWidth = printingScale * (ev.getExportWidth() / ev.getXscale());
-		double cmHeight = printingScale
+		final double cmWidth = printingScale
+				* (ev.getExportWidth() / ev.getXscale());
+		final double cmHeight = printingScale
 				* (ev.getExportHeight() / ev.getYscale());
 		sb.append(sizeLabelFormat.format(cmWidth));
 		sb.append(" cm ");
@@ -433,7 +472,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		sb.append(sizeLabelFormat.format(cmHeight));
 		sb.append(" cm");
 
-		int index = cbFormat.getSelectedIndex();
+		final int index = cbFormat.getSelectedIndex();
 		if (index == FORMAT_PNG) {
 			// pixel size
 			pixelWidth = (int) Math.floor(ev.getExportWidth() * exportScale);
@@ -460,10 +499,10 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/**
 	 * Shows save dialog and exports drawing as eps.
 	 */
-	final private boolean exportEPS(boolean exportToClipboard) {
+	final private boolean exportEPS(final boolean exportToClipboard) {
 
-		EuclidianView ev = (EuclidianView) app.getActiveEuclidianView();
-		double printingScale = ev.getPrintingScale();
+		final EuclidianView ev = getEuclidianView();
+		final double printingScale = ev.getPrintingScale();
 
 		// set dpi to 72
 		exportScale = (printingScale * 72) / 2.54 / ev.getXscale();
@@ -471,26 +510,29 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		pixelWidth = (int) Math.floor(ev.getExportWidth() * exportScale);
 		pixelHeight = (int) Math.floor(ev.getExportHeight() * exportScale);
 
-		// Michael Borcherds 2008-03-02 BEGIN
 		File file;
-		String tempDir = DownloadManager.getTempDir();
+		OutputStream os;
 		if (exportToClipboard) {
+			final String tempDir = DownloadManager.getTempDir(); 
+			//os = new ByteArrayOutputStream();
+			// use file to get the correct filetype (so eg pasting into Word works)
+			// NB pasting into WordPad *won't* work with this method
 			file = new File(tempDir + "geogebra.eps");
 		} else {
-			// Michael Borcherds 2008-03-02 END
 			file = app.getGuiManager().showSaveDialog(Application.FILE_EXT_EPS,
 					null, app.getPlain("eps") + " " + app.getMenu("Files"),
 					true, false);
-		}
-		if (file == null) {
-			return false;
+			
+			if (file == null) { 
+				return false;
+			}
 		}
 		try {
+			
 
-			geogebra.export.epsgraphics.EpsGraphics g = new geogebra.export.epsgraphics.EpsGraphics(
+			final geogebra.export.epsgraphics.EpsGraphics g = new geogebra.export.epsgraphics.EpsGraphics(
 					app.getPlain("ApplicationName") + ", "
-							+ GeoGebra.GEOGEBRA_WEBSITE, (new FileOutputStream(
-							file)), 0, 0, pixelWidth, pixelHeight,
+							+ GeoGebra.GEOGEBRA_WEBSITE, new FileOutputStream(file), 0, 0, pixelWidth, pixelHeight,
 					ColorMode.COLOR_RGB);
 
 			// draw to epsGraphics2D
@@ -498,11 +540,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			g.close();
 
 			if (exportToClipboard) {
-				sendToClipboard(file); // Michael Borcherds 2008-03-02 END
+				sendToClipboard(file);
 			}
 
 			return true;
-		} catch (Exception ex) {
+		} catch (final Exception ex) {
 			app.showError("SaveFileFailed");
 			Application.debug(ex.toString());
 			return false;
@@ -512,12 +554,12 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/**
 	 * Exports drawing as emf
 	 */
-	final private boolean exportEMF(boolean exportToClipboard,
-			boolean useEMFplus) {
+	final private boolean exportEMF(final boolean exportToClipboard,
+			final boolean useEMFplus) {
 
 		// Michael Borcherds 2008-03-02 BEGIN
 		File file;
-		String tempDir = DownloadManager.getTempDir();
+		final String tempDir = DownloadManager.getTempDir();
 		if (exportToClipboard) {
 			file = new File(tempDir + "geogebra.emf");
 		} else {
@@ -544,8 +586,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			app.exporting = true;
 
 			g.startExport();
-			((EuclidianView) app.getActiveEuclidianView()).exportPaint(g,
-					exportScale);
+			getEuclidianView().exportPaint(g, exportScale);
 
 			g.endExport();
 			app.exporting = false;
@@ -555,11 +596,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 
 			return true;
-		} catch (Exception ex) {
+		} catch (final Exception ex) {
 			app.showError("SaveFileFailed");
 			Application.debug(ex.toString());
 			return false;
-		} catch (Error ex) {
+		} catch (final Error ex) {
 			app.showError("SaveFileFailed");
 			Application.debug(ex.toString());
 			return false;
@@ -569,10 +610,10 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/**
 	 * Exports drawing as pdf
 	 */
-	final private boolean exportPDF(boolean exportToClipboard) {
+	final private boolean exportPDF(final boolean exportToClipboard) {
 		// Michael Borcherds 2008-03-02 BEGIN
 		File file;
-		String tempDir = DownloadManager.getTempDir();
+		final String tempDir = DownloadManager.getTempDir();
 		if (exportToClipboard) {
 			file = new File(tempDir + "geogebra.pdf");
 		} else {
@@ -588,23 +629,24 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		try {
 			// export text as shapes or plaintext
 			// shapes: better representation
-			// text: smaller file size, but some unicode symbols don't export eg Upsilon
-			UserProperties props = (UserProperties) PDFGraphics2D
+			// text: smaller file size, but some unicode symbols don't export eg
+			// Upsilon
+			final UserProperties props = (UserProperties) PDFGraphics2D
 					.getDefaultProperties();
 			props.setProperty(PDFGraphics2D.EMBED_FONTS, !textAsShapes);
-			// props.setProperty(PDFGraphics2D.EMBED_FONTS_AS, FontConstants.EMBED_FONTS_TYPE1);
+			// props.setProperty(PDFGraphics2D.EMBED_FONTS_AS,
+			// FontConstants.EMBED_FONTS_TYPE1);
 			props.setProperty(PDFGraphics2D.TEXT_AS_SHAPES, textAsShapes);
 			PDFGraphics2D.setDefaultProperties(props);
 
-			VectorGraphics g = new PDFGraphics2D(file, new Dimension(
+			final VectorGraphics g = new PDFGraphics2D(file, new Dimension(
 					pixelWidth, pixelHeight));
 
 			// make sure LaTeX exported at hi res
 			app.exporting = true;
 
 			g.startExport();
-			((EuclidianView) app.getActiveEuclidianView()).exportPaint(g,
-					exportScale);
+			getEuclidianView().exportPaint(g, exportScale);
 			g.endExport();
 			app.exporting = false;
 
@@ -613,12 +655,12 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 
 			return true;
-		} catch (Exception ex) {
+		} catch (final Exception ex) {
 			ex.printStackTrace();
 			app.showError("SaveFileFailed");
 
 			return false;
-		} catch (Error ex) {
+		} catch (final Error ex) {
 			ex.printStackTrace();
 			app.showError("SaveFileFailed");
 
@@ -629,10 +671,10 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/**
 	 * Exports drawing as SVG
 	 */
-	final private boolean exportSVG(boolean exportToClipboard) {
+	final private boolean exportSVG(final boolean exportToClipboard) {
 
-		EuclidianView ev = (EuclidianView) app.getActiveEuclidianView();
-		double printingScale = ev.getPrintingScale();
+		final EuclidianView ev = getEuclidianView();
+		final double printingScale = ev.getPrintingScale();
 
 		// set dpi to 72
 		exportScale = (printingScale * 72) / 2.54 / ev.getXscale();
@@ -642,7 +684,7 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 
 		// Michael Borcherds 2008-03-02 BEGIN
 		File file;
-		String tempDir = DownloadManager.getTempDir();
+		final String tempDir = DownloadManager.getTempDir();
 		if (exportToClipboard) {
 			file = new File(tempDir + "geogebra.svg");
 		} else {
@@ -655,13 +697,15 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		if (file == null) {
 			return false;
 		}
-		ev.setTemporaryCoordSystemForExport(); // allow clipping with Export_1 and 2 Points
+		ev.setTemporaryCoordSystemForExport(); // allow clipping with Export_1
+												// and 2 Points
 		try {
 
 			// export text as shapes or plaintext
 			// shapes: better representation
-			// text: smaller file size, but some unicode symbols don't export eg Upsilon
-			UserProperties props = (UserProperties) SVGGraphics2D
+			// text: smaller file size, but some unicode symbols don't export eg
+			// Upsilon
+			final UserProperties props = (UserProperties) SVGGraphics2D
 					.getDefaultProperties();
 			props.setProperty(SVGGraphics2D.EMBED_FONTS, !textAsShapes);
 			props.setProperty(SVGGraphics2D.TEXT_AS_SHAPES, textAsShapes);
@@ -669,9 +713,10 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 
 			// Michael Borcherds 2008-03-01
 			// added SVGExtensions to support grouped objects in layers
-			SVGExtensions g = new SVGExtensions(file, new Dimension(pixelWidth,
-					pixelHeight));
-			// VectorGraphics g = new SVGGraphics2D(file, new Dimension(pixelWidth, pixelHeight));
+			final SVGExtensions g = new SVGExtensions(file, new Dimension(
+					pixelWidth, pixelHeight));
+			// VectorGraphics g = new SVGGraphics2D(file, new
+			// Dimension(pixelWidth, pixelHeight));
 
 			// make sure LaTeX exported at hi res
 			app.exporting = true;
@@ -683,7 +728,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			ev.drawObjectsPre(g);
 			g.endGroup("misc");
 
-			for (int layer = 0; layer <= ev.getMaxLayerUsed(); layer++) // draw only layers we need
+			for (int layer = 0; layer <= ev.getMaxLayerUsed(); layer++) // draw
+																		// only
+																		// layers
+																		// we
+																		// need
 			{
 				g.startGroup("layer" + layer);
 				ev.drawLayers[layer].drawAll(g);
@@ -698,11 +747,11 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 
 			return true;
-		} catch (Exception ex) {
+		} catch (final Exception ex) {
 			app.showError("SaveFileFailed");
 			ex.printStackTrace();
 			return false;
-		} catch (Error ex) {
+		} catch (final Error ex) {
 			app.showError("SaveFileFailed");
 			ex.printStackTrace();
 			return false;
@@ -711,17 +760,18 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 		}
 	}
 
-	final public boolean exportPNG(boolean exportToClipboard) {
+	final public boolean exportPNG(final boolean exportToClipboard) {
 		return exportPNG(exportToClipboard, true);
 	}
 
 	/**
 	 * Exports drawing as png with given resolution in dpi
 	 */
-	final public boolean exportPNG(boolean exportToClipboard, boolean showError) {
+	final public boolean exportPNG(final boolean exportToClipboard,
+			final boolean showError) {
 		// Michael Borcherds 2008-03-02 BEGIN
 		File file;
-		String tempDir = DownloadManager.getTempDir();
+		final String tempDir = DownloadManager.getTempDir();
 		if (exportToClipboard) {
 			file = new File(tempDir + "geogebra.png");
 		} else {
@@ -736,8 +786,9 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 
 		try {
 			// draw graphics view into image
-			EuclidianView ev = (EuclidianView) app.getActiveEuclidianView();
-			BufferedImage img = ev.getExportImage(exportScale, transparent);
+			final EuclidianView ev = getEuclidianView();
+			final BufferedImage img = ev.getExportImage(exportScale,
+					transparent);
 
 			// write image to file
 			MyImageIO.write(img, "png", getDPI(), file);
@@ -747,13 +798,13 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 			}
 
 			return true;
-		} catch (Exception ex) {
+		} catch (final Exception ex) {
 			if (showError) {
 				app.showError("SaveFileFailed");
 			}
 			Application.debug(ex.toString());
 			return false;
-		} catch (Error ex) {
+		} catch (final Error ex) {
 			if (showError) {
 				app.showError("SaveFileFailed");
 			}
@@ -765,10 +816,12 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	/**
 	 * Exports drawing as jpg.
 	 * 
-	 * final private boolean exportJPG() { File file = app.showSaveDialog( Application.FILE_EXT_JPG,
-	 * app.getPlain("jpg") + " " + app.getMenu("Files")); if (file == null) return false; try { BufferedImage
-	 * img = app.getEuclidianView().getExportImage( sizePanel.getSelectedWidth()); ImageIO.write(img, "jpg",
-	 * file); return true; } catch (IOException ex) { app.showError("SaveFileFailed");
+	 * final private boolean exportJPG() { File file = app.showSaveDialog(
+	 * Application.FILE_EXT_JPG, app.getPlain("jpg") + " " +
+	 * app.getMenu("Files")); if (file == null) return false; try {
+	 * BufferedImage img = app.getEuclidianView().getExportImage(
+	 * sizePanel.getSelectedWidth()); ImageIO.write(img, "jpg", file); return
+	 * true; } catch (IOException ex) { app.showError("SaveFileFailed");
 	 * Application.debug(ex.toString()); return false; } }
 	 */
 
@@ -776,31 +829,24 @@ public class GraphicExportDialog extends JDialog implements KeyListener {
 	 * Keylistener implementation of PropertiesDialog
 	 */
 
-	public void keyPressed(KeyEvent e) {
-		int code = e.getKeyCode();
+	public void keyPressed(final KeyEvent e) {
+		final int code = e.getKeyCode();
 		if (code == KeyEvent.VK_ESCAPE) {
 			setVisible(false);
 		}
 	}
 
-	public void keyReleased(KeyEvent e) {
+	public void keyReleased(final KeyEvent e) {
 	}
 
-	public void keyTyped(KeyEvent e) {
+	public void keyTyped(final KeyEvent e) {
 
 	}
 
 	// Michael Borcherds 2008-03-02 BEGIN
-	private void sendToClipboard(File file) {
-		FileTransferable ft = new FileTransferable(file);
+	private void sendToClipboard(final File file) {
+		final FileTransferable ft = new FileTransferable(file);
 		Toolkit.getDefaultToolkit().getSystemClipboard().setContents(ft, null);
 	}
 
-	private void sendToClipboard(Image img) {
-		ImageSelection imgSel = new ImageSelection(img);
-		Toolkit.getDefaultToolkit().getSystemClipboard()
-				.setContents(imgSel, null);
-	}
-	// Michael Borcherds 2008-03-02 END
-
 }
