@@ -10,10 +10,11 @@ import geogebra.kernel.AlgoBoxPlot;
 import geogebra.kernel.AlgoElement;
 import geogebra.kernel.AlgoFunctionAreaSums;
 import geogebra.kernel.AlgoHistogram;
-import geogebra.kernel.AlgoIntegralDefinite;
 import geogebra.kernel.AlgoIntegralFunctions;
 import geogebra.kernel.AlgoSlope;
+import geogebra.kernel.AlgoSumLeft;
 import geogebra.kernel.AlgoSumLower;
+import geogebra.kernel.AlgoSumRectangle;
 import geogebra.kernel.AlgoSumTrapezoidal;
 import geogebra.kernel.AlgoSumUpper;
 import geogebra.kernel.Construction;
@@ -23,11 +24,13 @@ import geogebra.kernel.GeoConicPart;
 import geogebra.kernel.GeoCurveCartesian;
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoFunction;
+import geogebra.kernel.GeoFunctionNVar;
 import geogebra.kernel.GeoLine;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoLocus;
 import geogebra.kernel.GeoNumeric;
 import geogebra.kernel.GeoPoint;
+import geogebra.kernel.GeoPolyLine;
 import geogebra.kernel.GeoPolygon;
 import geogebra.kernel.GeoRay;
 import geogebra.kernel.GeoSegment;
@@ -35,7 +38,8 @@ import geogebra.kernel.GeoText;
 import geogebra.kernel.GeoVec2D;
 import geogebra.kernel.GeoVector;
 import geogebra.kernel.Kernel;
-import geogebra.kernel.arithmetic.ExpressionNode;
+import geogebra.kernel.cas.AlgoIntegralDefinite;
+import geogebra.kernel.implicit.GeoImplicitPoly;
 import geogebra.main.Application;
 
 import java.awt.Color;
@@ -45,17 +49,21 @@ import java.awt.event.ActionListener;
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.StringTokenizer;
-
+/*
+import org.mozilla.javascript.Context;
+import org.mozilla.javascript.Scriptable;
+import org.mozilla.javascript.ScriptableObject;
+*/
 public abstract class GeoGebraExport implements ActionListener{
 	protected int beamerSlideNumber=1;
 	protected final double PRECISION_XRANGE_FUNCTION=0.00001;
-	protected StringBuffer code,codePoint,codePreamble,codeFilledObject,codeBeginDoc;
+	protected StringBuilder code,codePoint,codePreamble,codeFilledObject,codeBeginDoc;
 	protected Application app;
     protected Kernel kernel;
     protected Construction construction;
     protected EuclidianView euclidianView;
     protected ExportFrame frame;
-    protected HashMap CustomColor;
+    protected HashMap<Color,String> CustomColor;
     protected double xunit,yunit,xmin,xmax,ymin,ymax;
 	// The exported format: Latex, tex, ConTexT, Beamer
     protected int format=0;
@@ -64,7 +72,7 @@ public abstract class GeoGebraExport implements ActionListener{
     	this.app = app;
     	this.kernel = app.getKernel();
     	this.construction = kernel.getConstruction();
-    	this.euclidianView = app.getEuclidianView();
+    	this.euclidianView = ((EuclidianView)this.app.getActiveEuclidianView());
     	initGui();
     }
 
@@ -142,6 +150,8 @@ public abstract class GeoGebraExport implements ActionListener{
 	public void actionPerformed(ActionEvent e){
 		isBeamer=frame.isBeamer();
 		generateAllCode();
+		
+
 
 	}
 	/**
@@ -153,12 +163,12 @@ public abstract class GeoGebraExport implements ActionListener{
 	protected String sci2dec(double d){
 		String s=String.valueOf(d).toLowerCase(Locale.US);
 		StringTokenizer st=new StringTokenizer(s,"e");
-		StringBuffer number;
+		StringBuilder number;
 		if (st.countTokens()==1) return s;
 		else {
 			String token1=st.nextToken();
 			String token2=st.nextToken();
-			number=new StringBuffer(token1);
+			number=new StringBuilder(token1);
 			int exp=Integer.parseInt(token2);
 			if (exp>0){
 				int id_point=number.indexOf(".");
@@ -193,7 +203,7 @@ public abstract class GeoGebraExport implements ActionListener{
 	String createCustomColor(int red,int green,int blue){
 		final String suff="qrstuvwxyzabcdef";
 		int[] nb={red,green,blue};
-		StringBuffer sb=new StringBuffer();
+		StringBuilder sb=new StringBuilder();
 		for (int i=0;i<nb.length;i++){
 			int quot=nb[i]/16;
 			int reste=nb[i]%16;
@@ -207,15 +217,17 @@ public abstract class GeoGebraExport implements ActionListener{
 	/**
 	 * This method is generic method to generate code according to GeoElement nature
 	 * @param g GeoElement g
+	 * @param fromGeoList if GeoElement comes from a GeoList object
+	 * @param trimmedInter 
 	 */
-    protected void drawGeoElement(GeoElement g,boolean fromGeoList){
+    protected void drawGeoElement(GeoElement g,boolean fromGeoList,boolean trimmedInter){
     	if (g.isGeoList()){
     		GeoList geo=((GeoList)g);
     		for (int i=0;i<geo.size();i++){
-    			drawGeoElement(geo.get(i),true);
+    			drawGeoElement(geo.get(i),true,false);
     		}
     	}
-    	else if (g.isEuclidianVisible()) {
+    	else if (g.isEuclidianVisible()||trimmedInter) {
     		if (g.isGeoPoint()){
 				drawGeoPoint((GeoPoint)g);
 				drawLabel(g,null);
@@ -228,6 +240,9 @@ public abstract class GeoGebraExport implements ActionListener{
 			drawGeoRay((GeoRay)g);
 			drawLabel(g,null);
 		}
+		else if (g instanceof GeoPolyLine){
+			drawPolyLine((GeoPolyLine)g);			
+		} 
 		else if (g.isGeoLine()){
 			drawGeoLine((GeoLine)g);
 			drawLabel(g,null);
@@ -245,7 +260,15 @@ public abstract class GeoGebraExport implements ActionListener{
 //        		String label="$"+Util.toLaTeXString(g.getLabelDescription(),true)+"$";
         		drawLabel(g,euclidianView.getDrawableFor((GeoAngle)g));
         	}        	                                  
-     }  
+		}
+		else if(g.isGeoImplicitPoly()){
+			drawImplicitPoly((GeoImplicitPoly)g);
+		}
+  		// To draw Inequalities
+		else if (g.getObjectType().equals("FunctionNvar")){
+			drawGeoInequalities((GeoFunctionNVar)g);
+		}
+    	
         else if (g.isGeoNumeric()) {
             AlgoElement algo = g.getParentAlgorithm();
             if (algo == null) {
@@ -264,21 +287,24 @@ public abstract class GeoGebraExport implements ActionListener{
             	drawIntegralFunctions((GeoNumeric) g);
             	drawLabel(g,null);
             }
+        	// BoxPlot
+        	else if (algo instanceof AlgoBoxPlot){
+        		drawBoxPlot((GeoNumeric)g);
+        	}
             else if (algo instanceof AlgoFunctionAreaSums) {
             	// Trapezoidal Sum
             	if (algo instanceof AlgoSumTrapezoidal)
             		drawSumTrapezoidal((GeoNumeric)g);
-            	// BoxPlot
-            	else if (algo instanceof AlgoBoxPlot)
-            		drawBoxPlot((GeoNumeric)g);
+
             	// Histogram
             	else if (algo instanceof AlgoHistogram)
             		drawHistogram((GeoNumeric)g);
             	// Bar Chart
             	else if (algo instanceof AlgoBarChart)
             		drawHistogram((GeoNumeric)g);
-            	// Lower or Upper Sum
-            	else if (algo instanceof AlgoSumUpper || algo instanceof AlgoSumLower) 
+            	// Lower or Upper Sum, Left Sum or Rectangle Sum
+            	else if (algo instanceof AlgoSumUpper || algo instanceof AlgoSumLower
+            			||algo instanceof AlgoSumLeft||algo instanceof AlgoSumRectangle) 
             				drawSumUpperLower((GeoNumeric)g);
               drawLabel(g,null);
             }
@@ -346,6 +372,7 @@ public abstract class GeoGebraExport implements ActionListener{
         	drawLocus((GeoLocus)g);
         }
 	}
+    	
     }
     protected boolean isSinglePointConic(GeoElement geo){
 		if (geo.isGeoConic()){
@@ -379,35 +406,221 @@ public abstract class GeoGebraExport implements ActionListener{
 		if (tmp!=0) return tmp;
 		else return 1;
 	}
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoPoint
+	 * @param geo The point to export
+	 */
+	
 	abstract protected void drawGeoPoint(GeoPoint geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoLine
+	 * line[A,B]
+	 * @param geo The line to export
+	 */
+	
 	abstract protected void drawGeoLine(GeoLine geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoRay
+	 * ray[A,B]
+	 * @param geo The ray to export
+	 */
 	abstract protected void drawGeoRay(GeoRay geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoSegment
+	 * segment[A,B]
+	 * @param geo The segment to export
+	 */
 	abstract protected void drawGeoSegment(GeoSegment geo);
+
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * polygon[A,B,C]
+	 * @param geo The polygon to export
+	 */
+	
 	abstract protected void drawPolygon(GeoPolygon geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * slider[1,2,0.1]
+	 * @param geo The slider to export
+	 */
+	
 	abstract protected void drawSlider(GeoNumeric geo);
+	
+	
 	abstract protected void drawSlope(GeoNumeric geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * integral(f(x),a,b)
+	 * @param geo The object to export
+	 */
 	abstract protected void drawIntegral(GeoNumeric geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * integral(f(x),g(x),a,b)
+	 * @param geo The object to export
+	 */
+	
 	abstract protected void drawIntegralFunctions(GeoNumeric geo);
+
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by following commands
+	 * leftSum, rectangleSum, lowerSum upperSum
+	 * @param geo The object to export
+	 */
 	abstract protected void drawSumUpperLower(GeoNumeric geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command trapezoidalsum
+	 * @param geo The object to export
+	 */
 	abstract protected void drawSumTrapezoidal(GeoNumeric geo);
+
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * BoxPlot[0, 1, {2,2,3,4,5,5,6,7,7,8,8,8,9}]
+	 * @param geo The boxplot to export
+	 */
+	
 	abstract protected void drawBoxPlot(GeoNumeric geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Objects created by command:
+	 * Histogram[{0, 1, 2, 3, 4, 5}, {2, 6, 8, 3, 1}]
+	 * @param geo The histogram to export
+	 */
 	abstract protected void drawHistogram(GeoNumeric geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoAngle objects
+	 * angle[A,B,C]
+	 * @param geo The angle to export
+	 */
 	abstract protected void drawAngle(GeoAngle geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoVector objects
+	 * vector[A,B]
+	 * @param geo The vector to export
+	 */
+	
 	abstract protected void drawGeoVector(GeoVector geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoConic objects
+	 * conic[A,B,C,D,E]
+	 * @param geo The conic to export
+	 */
+	
 	abstract protected void drawGeoConic(GeoConic geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ GeoConicPart objects (sectors...)
+	 * @param geo The conic part to export
+	 */
 	abstract protected void drawGeoConicPart(GeoConicPart geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ the object's label
+	 * @param geo The label to export
+	 * @param drawGeo Drawable object attached to geo
+	 */
 	abstract protected void drawLabel(GeoElement geo,Drawable drawGeo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ the GeoFunction object
+	 * @param geo The function to export
+	 */
 	abstract protected void drawFunction(GeoFunction geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ implicit functions
+	 * @param geo The function to export
+	 */
+	abstract protected void drawImplicitPoly(GeoImplicitPoly geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ parametric functions
+	 * @param geo The function to export
+	 */
 	abstract protected void drawCurveCartesian (GeoCurveCartesian geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ Text on euclidian view
+	 * @param geo The text to export
+	 */
+	
 	abstract protected void drawText(GeoText geo);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ locus
+	 * @param geo The locus to export
+	 */
+	
 	abstract protected void drawLocus(GeoLocus geo);
+	
+	/**
+	 * Exports as PStricks or PGF a line defined by all its parameter
+	 * @param x1 x start
+	 * @param y1 y start
+	 * @param x2 x end
+	 * @param y2 y end 
+	 * @param geo geo Object
+	 */
+	
 	abstract protected void drawLine(double x1,double y1,double x2,double y2,GeoElement geo);
+	
+	/**
+	 * Export as PStricks or PGF arc mark for angle
+	 * @param geo geo Object
+	 * @param vertex center
+	 * @param angSt angle start
+	 * @param angEnd angle end
+	 * @param r radius
+	 */
 	abstract protected void drawArc(GeoAngle geo,double[] vertex,double angSt,double angEnd,double r);
+	
+	/**
+	 * Export as PStricks or PGF segment mark
+	 * @param geo geo Object
+	 * @param vertex 
+	 * @param angleTick angle 
+	 */
 	abstract protected void drawTick(GeoAngle geo,double[] vertex, double angleTick);
+	
+	
     abstract protected void drawArrowArc(GeoAngle geo,double[] vertex,double angSt, double angEnd,double r, boolean clockwise);
 	abstract protected void createFrame();
 	abstract protected void generateAllCode();
-	abstract protected void ColorCode(Color color, StringBuffer sb);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ color's code
+	 * @param color The color
+	 * @param sb The StringBuilder to complete
+	 */
+	
+	abstract protected void ColorCode(Color color, StringBuilder sb);
+	
+	/**
+	 * Export as PSTricks or PGF/TikZ PolyLine objects
+	 * polyline[A,B,C,D,E]
+	 * @param geo The Polyline objects
+	 */
+	abstract protected void drawPolyLine(GeoPolyLine geo);
+	
+	
+	/**
+	 *  Export inequalities as PSTricks or PGF
+	 * @param g The inequality function
+	 */
+	abstract protected void drawGeoInequalities(GeoFunctionNVar g);
 	/**
 	 * @return the xmin
 	 */
@@ -743,35 +956,32 @@ public abstract class GeoGebraExport implements ActionListener{
     		GeoElement[] geos=construction.getConstructionElement(step).getGeoElements();
     		for (int j=0;j<geos.length;j++){
             	GeoElement g = (GeoElement)(geos[j]);
-               	drawGeoElement(g,false);    
+            	drawGeoElement(g,false,false);    
     		}
     	}
     	
     }
 	
 
-	protected void startBeamer(StringBuffer sb){
+	protected void startBeamer(StringBuilder sb){
 		if (isBeamer) sb.append("\\onslide<"+beamerSlideNumber+"->{\n  ");
 	}
-	protected void endBeamer(StringBuffer sb){
+	protected void endBeamer(StringBuilder sb){
 		if (isBeamer) sb.append("}\n");
 	}
-	protected void resizeFont(StringBuffer sb){
+	protected void resizeFont(StringBuilder sb){
 		
 		// Number of units that represents the font size:
-		int ggbSize=app.getFontSize();
+		int ggbSize=app.getGUIFontSize();
 		double ggbYUnit=euclidianView.getYscale();
 		double fontUnits=ggbSize/ggbYUnit;
-		System.out.println("ggbSize "+ggbSize+" ggbYUnit "+ggbYUnit);
 		// Now, on the output, calculate the size in centimeter
 		double yunit=frame.getYUnit();
 		double sizeCM=fontUnits*yunit;
-		System.out.println("yunit "+yunit+" sizeCM "+sizeCM);
 		// 1cm=1/2.54 in
 		// 1 in=72.27pt
 		// new size in pt:
 		int sizept=(int)(sizeCM/2.54*72.27+0.5);
-		System.out.println(sizept);
 		int texSize=frame.getFontSize();
 		if (texSize==10){
 			if (sizept<=5) sb.append("\\tiny{");
@@ -810,4 +1020,36 @@ public abstract class GeoGebraExport implements ActionListener{
 			else sb.append("\\Huge{");
 		}
 	}
-}
+	protected String getImplicitExpr(GeoImplicitPoly geo){
+		StringBuilder sb=new StringBuilder();
+		double[][] coeff=geo.getCoeff();
+		boolean first=true;
+		for (int i=0;i<coeff.length;i++){
+			for (int j=0;j<coeff[i].length;j++){
+				double tmp=coeff[i][j];
+				if (tmp!=0){
+					if (tmp>0) {
+						if (!first) sb.append("+");
+					}
+					sb.append(tmp);
+					if (i==0){
+						if (j!=0) {
+							sb.append("*y^");
+							sb.append(j);
+						}
+					}
+					else {
+						sb.append("*x^");
+						sb.append(i);
+						if (j!=0) {
+							sb.append("*y^");
+							sb.append(j);
+						}
+					}
+				first=false;
+				}
+			}
+		}
+		return new String(sb);
+	}
+}
\ No newline at end of file
