@@ -18,8 +18,10 @@ import geogebra.kernel.Kernel;
 import geogebra.main.Application;
 
 import java.awt.BorderLayout;
+import java.awt.Dimension;
 import java.awt.event.ActionEvent;
 
+import javax.swing.BorderFactory;
 import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JPanel;
@@ -117,6 +119,30 @@ public class ScriptInputDialog extends InputDialog {
 	public JPanel getInputPanel() {
 		return inputPanel;
 	}
+
+	/** 
+	 * Returns the inputPanel and sets its preferred size from the given row 
+	 * and column value.  
+	 *  
+	 * @param row 
+	 * @param column 
+	 * @return 
+	 */ 
+	public JPanel getInputPanel(int row, int column) { 
+
+		Dimension dim = ((GeoGebraEditorPane) inputPanel.getTextComponent()) 
+				.getPreferredSizeFromRowColumn(row, column); 
+		inputPanel.setPreferredSize(dim); 
+
+		// add a small margin 
+		inputPanel.getTextComponent().setBorder(BorderFactory.createEmptyBorder(4,4,4,4)); 
+
+		return inputPanel; 
+
+	} 
+
+	
+	
 	
 	public JButton getApplyButton() {
 		return btApply;
