@@ -825,6 +825,12 @@ public class TextInputDialog extends InputDialog implements DocumentListener {
 				// make sure newText is using correct LaTeX setting
 				newText.setLaTeX(isLaTeX, true);
 				newText.updateRepaint();
+				
+				// make sure rounding works
+				if(newText.getParentAlgorithm()!=null) 
+					newText.getParentAlgorithm().update(); 
+				else 
+					newText.updateRepaint(); 
 
 				app.doAfterRedefine(newText);                                
 				return newText != null;
