@@ -650,7 +650,10 @@ public class InputBarHelpPanel extends JPanel implements TreeSelectionListener,
 		//define the regular and italic style
 		Style def = StyleContext.getDefaultStyleContext().getStyle(StyleContext.DEFAULT_STYLE);
 		Style regular = doc.addStyle("regular", def);
-		StyleConstants.setFontFamily(def, "SansSerif");
+		
+		// changed to use getFontCanDisplayAwt() so that Armenian displays OK
+		StyleConstants.setFontFamily(def, app.getFontCanDisplay(description).getFamily());
+		
 		Style s = doc.addStyle("italic", regular);
 		StyleConstants.setItalic(s, true);
 		
