@@ -12,6 +12,7 @@ import geogebra.main.MyError;
 import geogebra.util.AutoCompleteDictionary;
 
 import java.awt.Component;
+import java.awt.Font;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
@@ -480,8 +481,9 @@ AutoComplete, KeyListener, GeoElementSelectionListener {
 		int caretPos = getCaretPosition();
 
 		String text = getText();
-
-		if (ch == ',') {
+		// checking for isAltDown() because Alt+, prints another character on the PC
+		// TODO make this more robust - perhaps it could go in a document change listener
+		if (ch == ',' && !e.isAltDown()) {
 			if (caretPos < text.length() && text.charAt(caretPos) == ',') {
 				// User typed ',' just in ahead of an existing ',':
 				// We may be in the position of filling in the next argument of an autocompleted command
@@ -900,5 +902,18 @@ AutoComplete, KeyListener, GeoElementSelectionListener {
 
 	}
 
+	/** 
+	 * Set the font of completions and history commands 
+	 * @param font the new font 
+	 */ 
+	public void setPopupsFont(java.awt.Font font) { 
+		if (this.completionsPopup != null) { 
+			this.completionsPopup.setFont(font); 
+		} 
+		if (this.historyPopup != null) { 
+			this.historyPopup.setFont(font); 
+		} 
+	} 
+
 
 }
