@@ -38,6 +38,7 @@ import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
 import javax.swing.JToggleButton;
 import javax.swing.SwingUtilities;
+import javax.swing.Timer;
 
 /**
  * JToggle button combined with popup menu for mode selction
@@ -48,24 +49,26 @@ public class ModeToggleMenu extends JPanel {
 	ModeToggleButtonGroup bg;
 	private MyJToggleButton tbutton, mouseOverButton;
 	private JPopupMenu popMenu;
-	private ArrayList menuItemList;
+	private ArrayList<JMenuItem> menuItemList;
 	
 	private ActionListener popupMenuItemListener;
 	private Application app;
 	int size;
 	
-	public ModeToggleMenu(Application app, ModeToggleButtonGroup bg) {
+	final static Color bgColor = Color.white;
+	
+	public ModeToggleMenu(Application app, Toolbar toolbar, ModeToggleButtonGroup bg) {
 		this.app = app;
 		this.bg = bg;
-		
 		setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
-			
+		
 		tbutton = new MyJToggleButton(this);		
 		tbutton.setAlignmentY(BOTTOM_ALIGNMENT);
 		add(tbutton);
 		
-		popMenu = new JPopupMenu();		
-		menuItemList = new ArrayList();
+		popMenu = new JPopupMenu();	
+		popMenu.setBackground(bgColor);
+		menuItemList = new ArrayList<JMenuItem>();
 		popupMenuItemListener = new MenuItemListener();
 		size = 0;
 	}
@@ -82,7 +85,7 @@ public class ModeToggleMenu extends JPanel {
 		String modeText = mode + "";
 		
 		for (int i=0; i < size; i++) {
-			JMenuItem mi = (JMenuItem) menuItemList.get(i);
+			JMenuItem mi = menuItemList.get(i);
 			// found item for mode?
 			if (mi.getActionCommand().equals(modeText)) {
 				selectItem(mi);
@@ -118,6 +121,7 @@ public class ModeToggleMenu extends JPanel {
 		// add menu item to popu menu
 		JMenuItem mi = new JMenuItem();		
 		mi.setFont(app.getPlainFont());
+		mi.setBackground(bgColor);
 		
 		// tool name as text
 		mi.setText(app.getToolName(mode));				
@@ -143,7 +147,19 @@ public class ModeToggleMenu extends JPanel {
 			// add button to button group
 			bg.add(tbutton);
 		}
-	}		
+	}	
+	
+	/**
+	 * Removes all modes from the toggle menu. Used for the temporary perspective.
+	 * 
+	 * @author Florian Sonner
+	 * @version 2008-10-22
+	 */
+	public void clearModes() {
+		popMenu.removeAll();
+		menuItemList.clear();
+		size = 0;
+	}	
 	
 	public void addSeparator() {
 		popMenu.addSeparator();
@@ -187,10 +203,9 @@ public class ModeToggleMenu extends JPanel {
 				component = app.getMainComponent(); // if geogebrapanel is inside an awt window
 				Point locApp = component.getLocationOnScreen();
 				popMenu.show(component, locButton.x - locApp.x,
-						locButton.y - locApp.y + tbutton.getHeight());
-		} else {
-			popMenu.setVisible(false);			
-		}
+						locButton.y - locApp.y + tbutton.getHeight());		} else {
+							popMenu.setVisible(false);			
+						}
 
 		tbutton.repaint();
 	}		
@@ -216,6 +231,7 @@ implements MouseListener, MouseMotionListener, ActionListener {
 	private GeneralPath gp;
 	private boolean showToolTipText = true;
 	boolean popupTriangleHighlighting = false;
+	boolean popupTriangleClicked = false;
 	private ModeToggleMenu menu;		
 	
 	private static final Color arrowColor = new Color(0,0,0,130);
@@ -223,6 +239,8 @@ implements MouseListener, MouseMotionListener, ActionListener {
 	//private static final Color selColor = new Color(17, 26, 100, 200);
 	private static final Color selColor = new Color(0,0,153, 200);
 	private static final BasicStroke selStroke = new BasicStroke(3f);
+	
+	private Timer showMenuTimer;
 			
 	MyJToggleButton(ModeToggleMenu menu) {
 		super();
@@ -242,8 +260,10 @@ implements MouseListener, MouseMotionListener, ActionListener {
 	}
 	
 	// set mode
-	public void actionPerformed(ActionEvent e) {		
-		menu.setMode(Integer.parseInt(e.getActionCommand()));		
+	public void actionPerformed(ActionEvent e) {
+		//don't select mode if popup triangle clicked
+		if (!popupTriangleClicked || !menu.isPopupShowing())
+		  menu.setMode(Integer.parseInt(e.getActionCommand()));		
 	}
 
 	public void setIcon(Icon icon) {
@@ -315,7 +335,8 @@ implements MouseListener, MouseMotionListener, ActionListener {
 	
 	
 	private boolean popupTriangleClicked(int x, int y) {
-		return (menu.size > 1 && y > iconHeight-2);
+		popupTriangleClicked = (menu.size > 1 && y > iconHeight-4);
+		return popupTriangleClicked;
 	}
 
 	public void mouseClicked(MouseEvent e) {	
@@ -326,26 +347,52 @@ implements MouseListener, MouseMotionListener, ActionListener {
 		menu.setMouseOverButton(this);
 	}
 
+	public void mousePressed(MouseEvent e) {
+		if (!menu.isPopupShowing() && popupTriangleClicked(e.getX(), e.getY())) {
+			menu.setPopupVisible(true);
+			this.getModel().setArmed(false); // #541
+		} else {
+			// Display the menu after a specific amount of time as well, start 
+			// a timer for this. The mouseReleased method stops this timer,
+			// which ensures that the menu is not displayed if the user stopped
+			// to press this button.
+			if(showMenuTimer == null) {
+				showMenuTimer = new Timer(1000, new ActionListener() {
+					public void actionPerformed(ActionEvent e) {
+						menu.setPopupVisible(true);
+					}
+				});
+				showMenuTimer.setRepeats(false);
+			}
+			
+			showMenuTimer.start();
+		}
+	}
+
 	public void mouseExited(MouseEvent arg0) {
 		menu.setMouseOverButton(null);
 		if (popupTriangleHighlighting) {
 			popupTriangleHighlighting = false;
 			repaint();
 		}
+		
+		// Stop the timer to show the menu if the user is no longer
+		// hovering over this button.
+		if(showMenuTimer != null && showMenuTimer.isRunning()) {
+			showMenuTimer.stop();
+		}
 	}
 
-	public void mousePressed(MouseEvent e) {
-		if (!menu.isPopupShowing() && popupTriangleClicked(e.getX(), e.getY())) {
-			menu.setPopupVisible(true);
-		}			
-	}
-
-	public void mouseReleased(MouseEvent e) {	
+	public void mouseReleased(MouseEvent e) {
 		if (menu.isPopupShowing() && !popupTriangleClicked(e.getX(), e.getY())) {
 			menu.setPopupVisible(false);
-		}	
+		}
 		
-		doClick();		
+		// Stop the timer to show the menu if the user released his mouse. In case
+		// the timer already executed his action this has no effect anyway.
+		if(showMenuTimer != null && showMenuTimer.isRunning()) {
+			showMenuTimer.stop();
+		}	
 	}
 	
 	public void doClick() {
