@@ -18,23 +18,22 @@ the Free Software Foundation.
 
 package geogebra.gui.view.algebra;
 
+import geogebra.gui.SetLabels;
+import geogebra.gui.inputfield.AutoCompleteTextField;
+import geogebra.gui.view.Gridable;
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.Kernel;
+import geogebra.kernel.View;
 import geogebra.main.Application;
-import geogebra.main.View;
 
-import java.awt.BasicStroke;
-import java.awt.Color;
+import java.awt.Component;
 import java.awt.Font;
-import java.awt.Graphics;
-import java.awt.Graphics2D;
-import java.awt.RenderingHints;
-import java.awt.font.TextLayout;
+import java.util.ArrayList;
 import java.util.EventObject;
 import java.util.HashMap;
 
+import javax.swing.BorderFactory;
 import javax.swing.DefaultCellEditor;
-import javax.swing.JTextField;
 import javax.swing.JTree;
 import javax.swing.ToolTipManager;
 import javax.swing.event.CellEditorListener;
@@ -52,52 +51,102 @@ import javax.swing.tree.TreePath;
  * @author  Markus
  * @version 
  */
-public class AlgebraView extends JTree implements View {	
+public class AlgebraView extends JTree implements View, Gridable, SetLabels{	
 		
 	private static final long serialVersionUID = 1L;
 	
+	/**
+	 * Tree mode where the objects are categorized by their dependency
+	 * (free, dependent, auxiliary) -- default value 
+	 */
+	public static final int MODE_DEPENDENCY = 0;
+	
+	/**
+	 * Tree mode where the objects are categorized by their type 
+	 * (points, circles, ..)
+	 */
+	public static final int MODE_TYPE = 1;
+	
+	/**
+	 * Tree mode where the objects are categorized by the view on which their value is computed 
+	 * (xOyPlane, space, ...)
+	 */	
+	public static final int MODE_VIEW = 2;
 
-
-	private Application app; // parent appame
+	protected Application app; // parent appame
 	private Kernel kernel;
-	private DefaultTreeModel model;
 	
 	private MyRenderer renderer;
 	private MyDefaultTreeCellEditor editor;
-	private JTextField editTF;
+	private AutoCompleteTextField editTF;
 	
 	// store all pairs of GeoElement -> node in the Tree
-	private HashMap nodeTable = new HashMap(100);
+	private HashMap<GeoElement, DefaultMutableTreeNode> nodeTable = new HashMap<GeoElement, DefaultMutableTreeNode>(500);
+	
+	/**
+	 * The tree model.
+	 */
+	protected DefaultTreeModel model;
 
-	// nodes
-	private DefaultMutableTreeNode root, depNode, indNode, auxiliaryNode;	
-	private TreePath tpInd, tpDep, tpAux; // tree paths for main nodes
+	/**
+	 * Root node for tree mode MODE_DEPENDENCY.
+	 */
+	protected DefaultMutableTreeNode rootDependency;
+	
+	/**
+	 * Nodes for tree mode MODE_DEPENDENCY
+	 */
+	private DefaultMutableTreeNode depNode, indNode;
 
+	protected DefaultMutableTreeNode auxiliaryNode;
+
+	/**
+	 * Root node for tree mode MODE_TYPE.
+	 */
+	private DefaultMutableTreeNode rootType;
+	
+	/**
+	 * Nodes for tree mode MODE_TYPE
+	 */
+	private HashMap<String, DefaultMutableTreeNode> typeNodesMap;
+	
+	/**
+	 * The mode of the tree, see MODE_DEPENDENCY, MODE_TYPE
+	 */
+	protected int treeMode;
+	
+	/**
+	 * Should we show auxiliary objects?
+	 */
 	private GeoElement selectedGeoElement;
 	private DefaultMutableTreeNode selectedNode;
 	
-	//	closing cross
-	private static BasicStroke crossStroke = new BasicStroke(1.5f); 
-	private static int crossBorder = 4;
-	private static int crossOffset = crossBorder + 6;
-	private boolean highlightCross;
+	private AlgebraHelperBar helperBar;
+	
+	private AlgebraController algebraController;
+	public AlgebraController getAlgebraController() {
+		return algebraController;
+	}
 
+	/**
+	 * Flag for LaTeX rendering
+	 */
+	final private static boolean renderLaTeX = true;
+
+
+	
+	
 	/** Creates new AlgebraView */
-	public AlgebraView(AlgebraController algCtrl) {		
+	public AlgebraView(AlgebraController algCtrl) {	
+		
+		Application.debug("XXX creating Algebra View XXX",1);
+		
 		app = algCtrl.getApplication();
 		kernel = algCtrl.getKernel();
-		algCtrl.setView(this);					
-
-		// tree's selection model	
-		/*
-		TreeSelectionModel tsm = new DefaultTreeSelectionModel();
-		tsm.setSelectionMode(TreeSelectionModel.DISCONTIGUOUS_TREE_SELECTION);
-		setSelectionModel(tsm);		
-		tsm.addTreeSelectionListener(new TreeSelectionListener() {
-			public void valueChanged(TreeSelectionEvent e) {				
-				selectionChanged();	
-			}				 
-		});*/
+		algCtrl.setView(this);	
+		this.algebraController = algCtrl;
+		// this is the default value
+		treeMode = MODE_DEPENDENCY;
 
 		// cell renderer (tooltips) and editor
 		ToolTipManager.sharedInstance().registerComponent(this);
@@ -108,24 +157,16 @@ public class AlgebraView extends JTree implements View {
 
 		// add listener
 		addMouseListener(algCtrl);
-		addMouseMotionListener(algCtrl);		
-
-		// build default tree structure
-		root = new DefaultMutableTreeNode();
-		depNode = new DefaultMutableTreeNode(); // dependent objects
-		indNode = new DefaultMutableTreeNode();
-		auxiliaryNode = new DefaultMutableTreeNode();
-				
+		addMouseMotionListener(algCtrl);
 		
-		// independent objects                  
-		root.add(indNode);
-		root.add(depNode);
-		root.add(auxiliaryNode);
-
-		// create model from root node
-		model = new DefaultTreeModel(root);
-		// this.treeModel = model;        
+		// add small border
+		setBorder(BorderFactory.createEmptyBorder(2,2,2,0));
+		
+		// initializes the tree model
+		model = new DefaultTreeModel(null);
+		initModel();
 		setModel(model);
+		
 		setLargeModel(true);
 		setLabels();
 
@@ -137,14 +178,64 @@ public class AlgebraView extends JTree implements View {
 		setScrollsOnExpand(true);	
 		setRowHeight(-1); // to enable flexible height of cells
 		
-		tpInd = new TreePath(indNode.getPath());
-		tpDep = new TreePath(depNode.getPath());
-		tpAux =new TreePath(auxiliaryNode.getPath()); 	
-		
-		// needed in applets
+		setToggleClickCount(1);
+				
+        // enable drag n drop
+		algCtrl.enableDnD();
+			
+		//attachView();						
+	}
+	
+	/**
+	 * Method to initialize the tree model of the current tree mode. This method
+	 * should be called whenever the tree mode is changed, it won't initialize
+	 * anything if not necessary.
+	 * 
+	 * This method will also actually change the model of the tree.
+	 */
+	protected void initModel() {	
+		// build default tree structure
+		if(treeMode == MODE_DEPENDENCY) {
+			// don't re-init anything
+			if(rootDependency == null) {
+				rootDependency = new DefaultMutableTreeNode();
+				depNode = new DefaultMutableTreeNode(); // dependent objects
+				indNode = new DefaultMutableTreeNode();
+				auxiliaryNode = new DefaultMutableTreeNode();
+				
+				// independent objects                  
+				rootDependency.add(indNode);
+				rootDependency.add(depNode);
+			}
+			
+			// set the root
+			model.setRoot(rootDependency);
+
+			// add auxiliary node if neccessary
+			if(app.showAuxiliaryObjects) {
+				if(!auxiliaryNode.isNodeChild(rootDependency)) {
+					model.insertNodeInto(auxiliaryNode, rootDependency, rootDependency.getChildCount());
+				}
+			}
+		} else {
+			// don't re-init anything
+			if(rootType == null) {
+				rootType = new DefaultMutableTreeNode();
+				typeNodesMap = new HashMap<String, DefaultMutableTreeNode>(5);
+			}
+			
+			// always try to remove the auxiliary node
+			if(app.showAuxiliaryObjects && auxiliaryNode != null) {
+				removeAuxiliaryNode();
+			}
+
+			// set the root
+			model.setRoot(rootType);
+		}
+	}
+	
+	protected void removeAuxiliaryNode(){
 		model.removeNodeFromParent(auxiliaryNode);
-		
-		attachView();						
 	}
 	
 	boolean attached = false;
@@ -152,15 +243,14 @@ public class AlgebraView extends JTree implements View {
 	public void attachView() {
 		clearView();
 		kernel.notifyAddAll(this);
-		kernel.attach(this);	
+		kernel.attach(this);
 		attached = true;
 	}
 
 	public void detachView() {
 		kernel.detach(this);
 		clearView();
-		attached = false;
-		//kernel.notifyRemoveAll(this);		
+		attached = false;		
 	}
 	
 	public void updateFonts() {
@@ -169,11 +259,12 @@ public class AlgebraView extends JTree implements View {
 		editor.setFont(font);
 		renderer.setFont(font);
 		editTF.setFont(font);
-	}    
+	}
 
 	private void initTreeCellRendererEditor() {
-		renderer = new MyRenderer(app);		
-		editTF = new JTextField();
+		renderer = newMyRenderer(app);		
+		editTF = new AutoCompleteTextField(0, app, true);
+		editTF.setAutoComplete(false);
 		editor = new MyDefaultTreeCellEditor(this, renderer, 
 									new MyCellEditor(editTF, app));
 		
@@ -181,6 +272,15 @@ public class AlgebraView extends JTree implements View {
 		setCellRenderer(renderer);
 		setCellEditor(editor);
 	}
+	
+	/**
+	 * 
+	 * @param app
+	 * @return new renderer of a cell
+	 */
+	protected MyRenderer newMyRenderer(Application app){
+		return new MyRenderer(app, this);
+	}
 
 	public void clearSelection() {
 		super.clearSelection();
@@ -192,115 +292,81 @@ public class AlgebraView extends JTree implements View {
 	}
 	
 	public boolean showAuxiliaryObjects() {
-		return auxiliaryNode.getParent() != null;
+		return app.showAuxiliaryObjects;
 	}
 	
 	public void setShowAuxiliaryObjects(boolean flag) {
-		if (flag == showAuxiliaryObjects()) return;
+		
+		app.showAuxiliaryObjects = flag;
+	
 		cancelEditing();
 		
 		if (flag) {
 			clearView();
-			//	add to root
-			model.insertNodeInto(auxiliaryNode, root, root.getChildCount());		
+			
+			if(getTreeMode() == MODE_DEPENDENCY) {
+				model.insertNodeInto(auxiliaryNode, rootDependency, rootDependency.getChildCount());
+			}
+			
 			kernel.notifyAddAll(this);
 		} else {
-			model.removeNodeFromParent(auxiliaryNode);			
+			// if we're listing the auxiliary objects in a single leaf we can
+			// just remove that leaf, but for type-based categorization those
+			// auxiliary nodes might be scattered across the whole tree,
+			// therefore we just rebuild the tree
+			if(getTreeMode() == MODE_DEPENDENCY) {
+				if(auxiliaryNode.getParent() != null) {
+					model.removeNodeFromParent(auxiliaryNode);
+				}
+			} else {
+				clearView();
+				kernel.notifyAddAll(this);
+			}
 		}					
 	}
 	
-	final public void paint(Graphics g) { 	 
-		if (!kernel.isNotifyRepaintActive()) 
+	/**
+	 * @return The display mode of the tree, see MODE_DEPENDENCY, MODE_TYPE
+	 */
+	public int getTreeMode() {
+		return treeMode;
+	}
+	
+	/**
+	 * @param value Either AlgebraView.MODE_DEPDENCY or AlgebraView.MODE_TYPE
+	 */
+	public void setTreeMode(int value) {
+		if(getTreeMode() == value) {
 			return;
-				
-		super.paint(g);
-				
-		// draw a cross in the upper right corner 
-		// to close the algebra view
-		if (!app.isApplet())
-			drawClosingCross((Graphics2D) g);
-	}		
-	
-	private void drawClosingCross(Graphics2D g2) {
-		int width = getWidth();			
-		g2.setStroke(crossStroke);
-		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, 
-				RenderingHints.VALUE_ANTIALIAS_ON);
+		}
 		
-		if (highlightCross) {
-			g2.setColor(Color.red);
-		} else {
-			g2.setColor(Color.gray);
-		}
-		g2.drawLine(width-crossOffset, crossBorder, width-crossBorder, crossOffset);
-		g2.drawLine(width-crossOffset, crossOffset, width-crossBorder, crossBorder);
+		clearView();
 		
-		if (highlightCross) {
-			g2.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, 
-								RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);
-			// "close" 
-			String strClose = app.getMenu("Close");
-			TextLayout layout = new TextLayout(strClose, app.getSmallFont(), g2.getFontRenderContext());
-			g2.setColor(Color.gray);
-			
-			int stringX = (int) (width - crossOffset - crossOffset - layout.getAdvance());
-			
-			g2.drawString(strClose, stringX, layout.getAscent()+2);
+		this.treeMode = value;
+		initModel();
+		
+		kernel.notifyAddAll(this);
+		setLabels();
+	}
+	
+	/**
+	 * @return The helper bar for this view.
+	 */
+	public AlgebraHelperBar getHelperBar() {
+		if(helperBar == null) {
+			helperBar = newAlgebraHelperBar();
 		}
+		
+		return helperBar;
 	}
 	
-	boolean hitClosingCross(int x, int y) {
-		return !app.isApplet() && 
-				(y <= crossOffset) && 
-		  		(x >= getWidth() - crossOffset);		
+	/**
+	 * 
+	 * @return new algebra helper bar
+	 */
+	protected AlgebraHelperBar newAlgebraHelperBar(){
+		return new AlgebraHelperBar(this, app);
 	}
-	
-	void setClosingCrossHighlighted(boolean flag) {
-		if (flag == highlightCross) return;		
-		highlightCross = flag;		
-		repaint();
-	}
-	
-	/* *
-	 * selection mangament
-	 *
-	private GeoElement [] selectedGeos; 
-	 
-	
-	public GeoElement [] getAllSelectedGeoElements() {
-		return selectedGeos;
-	}						
-	
-	private void selectionChanged() {
-		TreePath[] paths = getSelectionPaths();			
-		if (paths == null) { // no paths selected			
-			app.clearSelectedGeos();
-			return;
-		} 
-				
-		// get all GeoElements out of selection		
-		for (int i=0; i < paths.length; i++) {
-			Object ob = paths[i].getLastPathComponent();
-			Object userOb  = ((DefaultMutableTreeNode) ob).getUserObject();
-			if (userOb instanceof GeoElement) {			
-				app.addSelectedGeo((GeoElement) userOb, false);
-			}
-		}		
-		kernel.notifyRepaint();
-	}*/
-	
-	/*
-	public void select(GeoElement geo, boolean flag) {
-		DefaultMutableTreeNode node =
-			(DefaultMutableTreeNode) nodeTable.get(geo);
-		if (node != null) {
-			TreePath tp = new TreePath(node.getPath());			
-			if (flag) 
-				addSelectionPath(tp);
-			else 
-				removeSelectionPath(tp);
-		}
-	}	*/
 
 	public static GeoElement getGeoElementForLocation(JTree tree, int x, int y) {
 		TreePath tp = tree.getPathForLocation(x, y);
@@ -330,8 +396,16 @@ public class AlgebraView extends JTree implements View {
 	 */
 	public void startEditing(GeoElement geo, boolean shiftDown) {
 		if (geo == null) return;
+		
+		// open Object Properties for eg GeoImages
+		if (!geo.isAlgebraViewEditable()) {
+			ArrayList<GeoElement> geos = new ArrayList<GeoElement>();
+			geos.add(geo);
+			app.getGuiManager().showPropertiesDialog(geos);
+			return;
+		}
 
-		if (!shiftDown || !geo.isPointOnPath()) {
+		if (!shiftDown || !geo.isPointOnPath() && !geo.isPointInRegion()) {
 			if (!geo.isIndependent()
 			|| !attached )		// needed for F2 when Algebra View closed
 			 {
@@ -364,7 +438,7 @@ public class AlgebraView extends JTree implements View {
 			expandPath(tp);
 			makeVisible(tp);
 			scrollPathToVisible(tp);						
-			startEditingAtPath(tp); // open editing text field
+			startEditingAtPath(tp); // opend editing text field
 		}
 	}
 
@@ -373,35 +447,74 @@ public class AlgebraView extends JTree implements View {
 	 * by the application if the language setting is changed.
 	 */
 	public void setLabels() {
-		// tree node labels        		
-		setNodeLabel(indNode, app.getPlain("FreeObjects"));
-		setNodeLabel(depNode, app.getPlain("DependentObjects"));
-		setNodeLabel(auxiliaryNode, app.getPlain("AuxiliaryObjects"));		
+		
+		setTreeLabels();
+		
+		if(helperBar != null) {
+			helperBar.updateLabels();
+		}
 	}
-
-	/** update everything up the tree */
-	private void setNodeLabel(DefaultMutableTreeNode node, String label) {
-		node.setUserObject(label);
-		if (model != null) model.nodeChanged(node);
+	
+	/**
+	 * set labels on the tree
+	 */
+	protected void setTreeLabels(){
+		if(getTreeMode() == MODE_DEPENDENCY) {
+			indNode.setUserObject(app.getPlain("FreeObjects"));
+			model.nodeChanged(indNode);
+			
+			depNode.setUserObject(app.getPlain("DependentObjects"));
+			model.nodeChanged(depNode);
+			
+			auxiliaryNode.setUserObject(app.getPlain("AuxiliaryObjects"));
+			model.nodeChanged(auxiliaryNode);
+		} else {
+			DefaultMutableTreeNode node;
+			for (String key : typeNodesMap.keySet()) {
+				node = typeNodesMap.get(key);
+				node.setUserObject(app.getPlain(key));
+				model.nodeChanged(node);
+			}
+		}
 	}
 
-	/*
-	public String getToolTipText(MouseEvent evt) {				
-		GeoElement geo = getGeoElementForLocation(evt.getX(), evt.getY());
-	   	if (geo == null) return null;
-	   	return geo.getLongDescriptionHTML(true, true);    	   	
-	}*/
-
 	/**
 	 * adds a new node to the tree
 	 */
 	public void add(GeoElement geo) {	
-		if (isEditing())
-			cancelEditing();	
-				
-		if (geo.isLabelSet() && geo.isSetAlgebraVisible()) {			
+		cancelEditing();	
+		
+		if (geo.isLabelSet() && geo.showInAlgebraView() && geo.isSetAlgebraVisible()) {
+			// don't add auxiliary objects if the tree is categorized by type
+			if(getTreeMode() != MODE_DEPENDENCY && !showAuxiliaryObjects() && geo.isAuxiliaryObject()) {
+				return;
+			}
+			
 			DefaultMutableTreeNode parent, node;
 			node = new DefaultMutableTreeNode(geo);
+			parent = getParentNode(geo);
+			
+
+			// add node to model (alphabetically ordered)
+			int pos = getInsertPosition(parent, geo);
+			
+			model.insertNodeInto(node, parent, pos);
+			nodeTable.put(geo, node);
+			
+			// ensure that the leaf with the new obect is visible
+			expandPath(new TreePath(new Object[] { model.getRoot(), parent }));
+		}
+	}
+
+	/**
+	 * 
+	 * @param geo
+	 * @return parent node of this geo
+	 */
+	protected DefaultMutableTreeNode getParentNode(GeoElement geo){
+		DefaultMutableTreeNode parent;
+		
+		if(treeMode == MODE_DEPENDENCY) {				
 			if (geo.isAuxiliaryObject()) {
 				parent = auxiliaryNode;
 			}				
@@ -411,25 +524,33 @@ public class AlgebraView extends JTree implements View {
 			else {				
 				parent = depNode;
 			}
-
-			// add node to model (alphabetically ordered)
-			int pos = getInsertPosition(parent, geo);			
-			model.insertNodeInto(node, parent, pos);				
-			nodeTable.put(geo, node);
+		} else {
+			// get type node
+			String typeString = geo.getObjectType();
+			parent = (DefaultMutableTreeNode) typeNodesMap.get(typeString);
 			
-			// show new node			
-			if (parent == indNode)
-				expandPath(tpInd);
-			else if (parent == depNode)
-				expandPath(tpDep);
-			else
-				expandPath(tpAux);
-								
-			//TreePath tp = new TreePath(node.getPath());			
-			//this.scrollPathToVisible(tp);											
+			// do we have to create the parent node?
+			if (parent == null) {
+				String transTypeString = geo.translatedTypeString();
+				parent = new DefaultMutableTreeNode(transTypeString);									
+				typeNodesMap.put(typeString, parent);
+				
+				// find insert pos
+				int pos = rootType.getChildCount();
+				for (int i=0; i < pos; i++) {
+					DefaultMutableTreeNode child = (DefaultMutableTreeNode) rootType.getChildAt(i);
+					if (transTypeString.compareTo(child.toString()) < 0) {
+						pos = i;
+						break;
+					}
+				}
+				
+				model.insertNodeInto(parent, rootType, pos);				
+			}
 		}
+		
+		return parent;
 	}
-
 	
 	/**
 	 * Gets the insert position for newGeo to insert it in alphabetical
@@ -448,7 +569,7 @@ public class AlgebraView extends JTree implements View {
 		// bigger then last?
 		DefaultMutableTreeNode node = (DefaultMutableTreeNode) parent.getLastChild();	
 		String nodeLabel = ((GeoElement) node.getUserObject()).getLabel();	
-		if (newLabel.compareTo(nodeLabel) > 0) 
+		if (GeoElement.compareLabels(newLabel, nodeLabel) > 0) 
 			return right;				
 		
 		// binary search
@@ -457,7 +578,7 @@ public class AlgebraView extends JTree implements View {
 			node = (DefaultMutableTreeNode) parent.getChildAt(middle);
 			nodeLabel = ((GeoElement) node.getUserObject()).getLabel();
 			
-			if (newLabel.compareTo(nodeLabel) < 0) {
+			if (GeoElement.compareLabels(newLabel, nodeLabel) < 0) {
 				right = middle;
 			} else {
 				left = middle + 1;
@@ -484,7 +605,7 @@ public class AlgebraView extends JTree implements View {
 			DefaultMutableTreeNode node = (DefaultMutableTreeNode) parent.getChildAt(middle);
 			String nodeLabel = ((GeoElement) node.getUserObject()).getLabel();
 			
-			int compare = geoLabel.compareTo(nodeLabel);
+			int compare = GeoElement.compareLabels(geoLabel, nodeLabel);
 			if (compare < 0)
 				right = middle -1;
 		    else if (compare > 0)
@@ -514,21 +635,39 @@ public class AlgebraView extends JTree implements View {
 	/**
 	 * removes a node from the tree
 	 */
-	public void remove(GeoElement geo) {
-		if (isEditing())
-			cancelEditing();
+	public void remove(GeoElement geo) {		
+		cancelEditing();
 		DefaultMutableTreeNode node = (DefaultMutableTreeNode) nodeTable.get(geo);
-		if (node != null) removeFromModel(node);		
+		
+		if (node != null) 
+		{
+			removeFromModel(node, ((DefaultTreeModel)getModel()));		
+		}
 	}
 	
 	public void clearView() {
-		nodeTable.clear();		
-		indNode.removeAllChildren();
-		depNode.removeAllChildren();
-		auxiliaryNode.removeAllChildren();
+		nodeTable.clear();
+		
+		clearTree();
+		
 		model.reload();
 	}
 	
+	/**
+	 * remove all from the tree
+	 */
+	protected void clearTree() {
+		if(getTreeMode() == MODE_DEPENDENCY) {
+			indNode.removeAllChildren();
+			depNode.removeAllChildren();
+			auxiliaryNode.removeAllChildren();
+		} else {
+			rootType.removeAllChildren();
+			typeNodesMap.clear();
+		}
+	}
+	
+	
 	final public void repaintView() {
 		repaint();
 	}
@@ -541,40 +680,104 @@ public class AlgebraView extends JTree implements View {
 		add(geo);
 	}
 	
+	/**
+	 * Reset the algebra view if the mode changed.
+	 */
+	public void setMode(int mode) {
+		reset();
+	}
+	
 	public void reset() {
-	  if (isEditing())
-		cancelEditing();
+	  	cancelEditing();
 	  repaint();
 	}
 
-	private void removeFromModel(DefaultMutableTreeNode node) {
-		// remove node from model
+	/**
+	 * Remove this node from the model.
+	 * @param node
+	 * @param model
+	 */
+	private void removeFromModel(DefaultMutableTreeNode node, DefaultTreeModel model) {
 		model.removeNodeFromParent(node);
 		nodeTable.remove(node.getUserObject());
-		//updateNodeLabel(parent);                   
+		
+		// remove the type branch if there are no more children
+		if(treeMode == MODE_TYPE) {
+			String typeString = ((GeoElement)node.getUserObject()).getObjectType();
+			DefaultMutableTreeNode parent = (DefaultMutableTreeNode) typeNodesMap.get(typeString);
+			
+			// this has been the last node
+			if(parent.getChildCount() == 0) {
+				typeNodesMap.remove(typeString);
+				model.removeNodeFromParent(parent);
+			}
+		}            
 	}
 
 	/**
 	   * updates node of GeoElement geo (needed for highlighting)
 	   * @see EuclidianView.setHighlighted()
 	   */
-	final public void update(GeoElement geo) {	
-		if (isEditing())
-			cancelEditing();
+	final public void update(GeoElement geo) {			
 		DefaultMutableTreeNode node =
-			(DefaultMutableTreeNode) nodeTable.get(geo);						
+			(DefaultMutableTreeNode) nodeTable.get(geo);
+		
 		if (node != null) {
-			model.nodeChanged(node);		
+			
+			/* occasional exception when animating
+			 * Exception in thread "AWT-EventQueue-0" java.lang.ArrayIndexOutOfBoundsException: 1 >= 1
+	at java.util.Vector.elementAt(Vector.java:432)
+	at javax.swing.tree.DefaultMutableTreeNode.getChildAt(DefaultMutableTreeNode.java:230)
+	at javax.swing.tree.VariableHeightLayoutCache.treeNodesChanged(VariableHeightLayoutCache.java:412)
+	at javax.swing.plaf.basic.BasicTreeUI$Handler.treeNodesChanged(BasicTreeUI.java:3669)
+	at javax.swing.tree.DefaultTreeModel.fireTreeNodesChanged(DefaultTreeModel.java:466)
+	at javax.swing.tree.DefaultTreeModel.nodesChanged(DefaultTreeModel.java:328)
+	at javax.swing.tree.DefaultTreeModel.nodeChanged(DefaultTreeModel.java:261)
+	at geogebra.gui.view.algebra.AlgebraView.update(AlgebraView.java:726)
+	at geogebra.kernel.Kernel.notifyUpdate(Kernel.java:2082)
+	at geogebra.kernel.GeoElement.update(GeoElement.java:3269)
+	at geogebra.kernel.GeoPoint.update(GeoPoint.java:1169)
+	at geogebra.kernel.GeoElement.updateCascade(GeoElement.java:3313)
+	at geogebra.kernel.GeoElement.updateCascade(GeoElement.java:3369)
+	at geogebra.kernel.AnimationManager.actionPerformed(AnimationManager.java:179)
+
+			 */
+			try {
+				((DefaultTreeModel)getModel()).nodeChanged(node);
+			} catch (Exception e) {
+				e.printStackTrace();
+			}
+			/*
+			 * Cancel editing if the updated geo element has been edited, but
+			 * not otherwise because editing geos while animation is running
+			 * won't work then (ticket #151). 
+			 */
+			if (isEditing()) {
+				if(getEditingPath().equals(new TreePath(node.getPath()))) {
+					cancelEditing();
+				}
+			}
 		} 	
 	}
 	
+
+	
+	
+	
 	final public void updateAuxiliaryObject(GeoElement geo) {
 		remove(geo);
 		add(geo);
-	}		
-
+	}
 
 
+	/**
+	 * Returns true if rendering is done with LaTeX
+	 * @return
+	 */
+	public boolean isRenderLaTeX() {
+		return renderLaTeX;
+	}
+	
 	/**
 	 * inner class MyEditor handles editing of tree nodes
 	 *
@@ -596,6 +799,7 @@ public class AlgebraView extends JTree implements View {
 		}
 
 		public void editingStopped(ChangeEvent event) {
+			
 			// get the entered String
 			String newValue = getCellEditorValue().toString();
 			
@@ -611,12 +815,13 @@ public class AlgebraView extends JTree implements View {
 			// change without redefine
 			boolean redefine = !selectedGeoElement.isPointOnPath();
 			
-			GeoElement geo = kernel.getAlgebraProcessor().changeGeoElement(selectedGeoElement, newValue, redefine);			
+			GeoElement geo = kernel.getAlgebraProcessor().changeGeoElement(selectedGeoElement, newValue, redefine, true);			
 			if (geo != null) {				
 				selectedGeoElement = geo;
 				selectedNode.setUserObject(selectedGeoElement);
 			}			
-			model.nodeChanged(selectedNode); // refresh display        
+			
+			((DefaultTreeModel)getModel()).nodeChanged(selectedNode); // refresh display        
 		}
 
 		/*
@@ -629,6 +834,7 @@ public class AlgebraView extends JTree implements View {
 			
 			return false;		
 		}
+
 		//
 		// TreeSelectionListener
 		//
@@ -670,15 +876,52 @@ public class AlgebraView extends JTree implements View {
 
 	}  // MyEditor
 
-	public String getContentXML() {		
-		return "";
+	public int getViewID() {
+		return Application.VIEW_ALGEBRA;
 	}
 
-	public String getGuiXML() {		
-		return "";
+	public Application getApplication() {
+		return app;
+	}
+
+	public int[] getGridColwidths() {
+		return new int[]{getWidth()};
+	}
+
+	public int[] getGridRowHeights() {
+//		Object root=model.getRoot();
+//		ArrayList<Integer> heights=new ArrayList<Integer>();
+//		for (int i=0;i<model.getChildCount(root);i++){
+//			Object folder=model.getChild(root, i);
+//			if (model.)
+//		}
+////		m.getChildCount(root);
+//		
+//		return new int[]{getHeight()};
+		int[] heights=new int[getRowCount()];
+		for (int i=0;i<heights.length;i++){
+			heights[i]=getRowBounds(i).height;
+		}
+		heights[0]+=2;
+		return heights;
+	}
+
+	public Component[][] getPrintComponents() {
+		return new Component[][]{{this}};
 	}
 	
-	
-	
+	/**
+	 * returns settings in XML format
+	 *
+	public void getXML(StringBuilder sb) {
+		
+		sb.append("<algebraView>\n");
+			sb.append("\t<useLaTeX ");
+			sb.append(" value=\"");
+			sb.append(isRenderLaTeX());
+			sb.append("\"");
+			sb.append("/>\n");
+		sb.append("</algebraView>\n");
+	}*/
 
 } // AlgebraView
