@@ -11,7 +11,11 @@ the Free Software Foundation.
 */
 package geogebra.gui.view.consprotocol;
 
+import geogebra.gui.SetLabels;
 import geogebra.main.Application;
+import geogebra.main.settings.AbstractSettings;
+import geogebra.main.settings.ConstructionProtocolSettings;
+import geogebra.main.settings.SettingListener;
 
 import java.awt.Component;
 import java.awt.Cursor;
@@ -30,17 +34,17 @@ import javax.swing.JButton;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JSpinner;
-import javax.swing.JSpinner.NumberEditor;
 import javax.swing.SpinnerModel;
 import javax.swing.SpinnerNumberModel;
 import javax.swing.Timer;
+import javax.swing.JSpinner.NumberEditor;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
 /**
  * Navigation buttons for the construction protocol
  */
-public class ConstructionProtocolNavigation extends JPanel implements ActionListener {
+public class ConstructionProtocolNavigation extends JPanel implements ActionListener, SettingListener, SetLabels {
 
 	/**
 	 * 
@@ -53,7 +57,7 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
 	private JPanel playPanel;
 	
 	private Application app;
-	private ConstructionProtocol prot;
+	private ConstructionProtocolView prot;
 	private boolean showPlayButton = true, 
 					showConsProtButton = true;
 	
@@ -64,7 +68,7 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
 	 * Creates a new navigation bar to step through the construction protocol.
 	 * @param internalNavigation: true if navigation bar is part of the protocol window
 	 */
-	public ConstructionProtocolNavigation(ConstructionProtocol prot) {		
+	public ConstructionProtocolNavigation(ConstructionProtocolView prot) {
 		this.prot = prot;			
 		app = prot.getApplication();	
 				
@@ -77,11 +81,17 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
 		NumberEditor numEdit = new JSpinner.NumberEditor(spDelay, "#.##");
 		DecimalFormat format = numEdit.getFormat();
 		format.setDecimalFormatSymbols(new DecimalFormatSymbols(Locale.ENGLISH));
-		spDelay.setEditor(numEdit);
 		
 		lbSteps = new JLabel();
 		
-		initGUI();			
+		initGUI();
+		
+/*		//next 3 rows moved into EuclidianDockPanel.loadComponent
+		//because it not neccessary for all Contruction protocol navigation issue
+		ConstructionProtocolSettings cps = app.getSettings().getConstructionProtocol();
+		settingsChanged(cps);
+		cps.addListener(this);
+		*/
 	}
 		
 	public boolean isPlayButtonVisible() {
@@ -168,10 +178,12 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
 		btOpenWindow.setIcon(app.getImageIcon("table.gif"));			
 		btOpenWindow.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				app.getGuiManager().showConstructionProtocol();					
+				//app.getGuiManager().showConstructionProtocol();
+				if(!app.getGuiManager().showView(Application.VIEW_CONSTRUCTION_PROTOCOL))
+					app.getGuiManager().setShowView(true, Application.VIEW_CONSTRUCTION_PROTOCOL);
 			}				
-		});			
-			
+		});
+		
 		// add panels together to center
 		setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));		
 		add(leftPanel);
@@ -188,7 +200,7 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
 		if (btPlay != null)
 			btPlay.setText(app.getPlain("Play"));
 		if (btOpenWindow != null)
-			btOpenWindow.setToolTipText(app.getPlain("ConstructionProtocol"));
+			btOpenWindow.setToolTipText(app.getPlainTooltip("ConstructionProtocol"));
 	}
 	
 	/**
@@ -307,5 +319,14 @@ public class ConstructionProtocolNavigation extends JPanel implements ActionList
         		stopAnimation();
         	}
         }       
-    }	
+    }
+
+	public void settingsChanged(AbstractSettings settings) {
+		ConstructionProtocolSettings cps = (ConstructionProtocolSettings)settings;
+		setPlayButtonVisible(cps.showPlayButton());
+		setPlayDelay(cps.getPlayDelay());
+		setConsProtButtonVisible(cps.showConstructionProtocol());
+		update();
+		
+	}	
 }
