@@ -357,22 +357,19 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 
 
 			// plot panel (extension of EuclidianView)
-			//======================================================
-			plotPanel = new PlotPanelEuclidianView(app.getKernel());
-			plotPanel.setMouseEnabled(true);
+			// ======================================================
+			plotPanel = new PlotPanelEuclidianView(app.getKernel(),
+					exportToEVAction);
+			plotPanel.setMouseEnabled(true, true);
 			plotPanel.setMouseMotionEnabled(true);
-
-			plotPanel.setBorder(BorderFactory.createCompoundBorder(
-					BorderFactory.createEmptyBorder(2, 2, 2, 2),
-					BorderFactory.createBevelBorder(BevelBorder.LOWERED))); 
-
+			
+			/*
+			 * plotPanel.setBorder(BorderFactory.createCompoundBorder(
+			 * BorderFactory.createEmptyBorder(2, 2, 2, 2),
+			 * BorderFactory.createBevelBorder(BevelBorder.LOWERED)));
+			 */
 			plotPanel.setBorder(BorderFactory.createEmptyBorder());
 
-			plotPanel.setBorder(BorderFactory.createEmptyBorder());
-
-			addPlotPanelExportMenu(plotPanel);
-
-
 			// table panel
 			//======================================================
 			table = new ProbabilityTable(app, this);
@@ -669,7 +666,7 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 			//     offset = 1 - lowest discrete x value 
 
 			double  firstX = ((GeoNumeric)discreteValueList.get(0)).getDouble();
-			MyDouble offset = new MyDouble(kernel, 1d - firstX);
+			MyDouble offset = new MyDouble(kernel, 1d - firstX + 0.5);
 
 			ExpressionNode low = new ExpressionNode(kernel, lowPoint, ExpressionNode.XCOORD, null);
 			ExpressionNode high = new ExpressionNode(kernel, highPoint, ExpressionNode.XCOORD, null);				
@@ -745,9 +742,14 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 
 			// create density curve
 			expr = buildDensityCurveExpression(selectedDist);
+			
+			// make sure eg Normal works in Swedish (Normal == PerpendicularLine)
+			kernel.setUseInternalCommandNames(true);
 
 			densityCurve = createGeoFromString(expr, null, true);
 
+			kernel.setUseInternalCommandNames(false);
+
 			cons.removeFromConstructionList(densityCurve.getParentAlgorithm());
 
 			densityCurve.setObjColor(COLOR_PDF);
@@ -1288,6 +1290,13 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 		if(isDiscrete){
 			high = Math.round(high);
 			low = Math.round(low);
+			
+			// make sure arrow keys move points in 1s
+			lowPoint.setAnimationStep(1);
+			highPoint.setAnimationStep(1);
+		} else {
+			lowPoint.setAnimationStep(0.1);
+			highPoint.setAnimationStep(0.1);			
 		}
 		setXAxisPoints();
 		updateIntervalProbability();
@@ -1972,28 +1981,44 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 	//============================================================
 
 
-	private void addPlotPanelExportMenu(PlotPanelEuclidianView plotPanel){
+	/**
+	 * Action to export all GeoElements that are currently displayed in this
+	 * panel to a EuclidianView. The viewID for the target EuclidianView is
+	 * stored as a property with key "euclidianViewID".
+	 * 
+	 * This action is passed as a parameter to plotPanel where it is used in
+	 * the plotPanel context menu and the EuclidianView transfer handler
+	 * when the plot panel is dragged into an EV.
+	 */
+	AbstractAction exportToEVAction = new AbstractAction() {
+		private static final long serialVersionUID = 1L;
 
-		AbstractAction exportToEVAction = new AbstractAction(app
-				.getMenu("CopyToGraphics"), app
-				.getImageIcon("edit-copy.png")) {
-			private static final long serialVersionUID = 1L;
-
-			public void actionPerformed(ActionEvent e) {
-				if(app.getShiftDown())
-					exportGeosToEV(Application.VIEW_EUCLIDIAN2);
-				else
-					exportGeosToEV(Application.VIEW_EUCLIDIAN);
+		public void actionPerformed(ActionEvent event){
+			Integer euclidianViewID = (Integer) this.getValue("euclidianViewID");
+			
+			// if null ID then use EV1 unless shift is down, then use EV2
+			if(euclidianViewID == null){
+				euclidianViewID = app.getShiftDown()? app.getEuclidianView2().getViewID() : app.getEuclidianView().getViewID();
 			}
-		};
+			
+			// do the export
+			exportGeosToEV(euclidianViewID);
+			
+			// null out the ID property
+			this.putValue("euclidianViewID", null);
+		}
+	};
+	
+	
+	
 
-		plotPanel.appendActionList(exportToEVAction);
-	}
-
-
-
-
-	public void exportGeosToEV(int viewID){
+	/**
+	 * Exports all GeoElements that are currently displayed in this panel to a target
+	 * EuclidianView.
+	 * 
+	 * @param euclidianViewID	viewID of the target EuclidianView
+	 */
+	public void exportGeosToEV(int euclidianViewID){
 
 		app.setWaitCursor();
 		ArrayList<GeoElement> newGeoList = new ArrayList<GeoElement>();
@@ -2097,7 +2122,7 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 
 				// create interval bar chart
 				// ============================
-				double offset = 1 - ((GeoNumeric)discreteValueList.get(0)).getDouble();  
+				double offset = 1 - ((GeoNumeric)discreteValueList.get(0)).getDouble() + 0.5;  
 				expr = "Take[" + discreteProbListCopy.getLabel()  + ", x(" 
 				+ lowPointCopy.getLabel() + ")+" + offset + ", x(" + highPointCopy.getLabel() +")+" + offset +"]";
 				GeoElement intervalProbList  = (GeoList) createGeoFromString(expr, null, false);
@@ -2146,12 +2171,12 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 			// set the EV location and auxiliary = false for all of the new geos
 			for(GeoElement geo: newGeoList){
 				geo.setAuxiliaryObject(false);
-				if(viewID == Application.VIEW_EUCLIDIAN){
+				if(euclidianViewID  == Application.VIEW_EUCLIDIAN){
 					geo.addView(Application.VIEW_EUCLIDIAN);
 					geo.removeView(Application.VIEW_EUCLIDIAN2);
 					geo.update();
 				}
-				else if(viewID == Application.VIEW_EUCLIDIAN2){
+				else if(euclidianViewID == Application.VIEW_EUCLIDIAN2){
 					geo.addView(Application.VIEW_EUCLIDIAN2);
 					geo.removeView(Application.VIEW_EUCLIDIAN);
 					geo.update();
@@ -2159,7 +2184,7 @@ implements View, ActionListener, FocusListener, ChangeListener, SettingListener
 			}
 
 			// set the window dimensions of the target EV to match the prob calc dimensions
-			EuclidianView ev  = (EuclidianView) app.getView(viewID);
+			EuclidianView ev  = (EuclidianView) app.getView(euclidianViewID );
 			ev.setRealWorldCoordSystem(plotSettings.xMin, plotSettings.xMax, plotSettings.yMin, plotSettings.yMax);
 			ev.setAutomaticAxesNumberingDistance(plotSettings.xAxesIntervalAuto, 0);
 			ev.setAutomaticAxesNumberingDistance(plotSettings.yAxesIntervalAuto, 1);
