@@ -2,6 +2,7 @@ package geogebra.gui.view.probcalculator;
 
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoFunction;
+import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.NumberValue;
 import geogebra.main.Application;
 
@@ -659,7 +660,16 @@ public class ProbabilityManager {
 	private double evaluateExpression(String expr){
 
 		NumberValue nv;
-		nv =  app.getKernel().getAlgebraProcessor().evaluateToNumeric(expr, false);	
+		
+		Kernel kernel = app.getKernel();
+		
+		// make sure eg Normal works in Swedish (Normal == PerpendicularLine)
+		kernel.setUseInternalCommandNames(true);
+		
+		nv =  kernel.getAlgebraProcessor().evaluateToNumeric(expr, false);	
+		
+		kernel.setUseInternalCommandNames(false);
+		
 		double result = nv.getDouble();
 
 		return result;
