@@ -209,14 +209,14 @@ public class CellRangeProcessor {
 	 * Creates a GeoList of lists where each element is a list
 	 * of cells in each column spanned by the range list
 	 */
-	public GeoList createCollectionList(ArrayList<CellRange> rangeList, boolean copyByValue) {
+	public GeoList createCollectionList(ArrayList<CellRange> rangeList, boolean copyByValue, boolean addToConstruction) {
 
 		GeoList tempGeo = new GeoList(cons);
 		boolean oldSuppress = cons.isSuppressLabelsActive();
 		cons.setSuppressLabelCreation(true);
 		for(CellRange cr : rangeList){
 			for(int col=cr.getMinColumn(); col<=cr.getMaxColumn(); col++){
-				tempGeo.add(createListFromColumn(col, copyByValue, false, false, GeoElement.GEO_CLASS_NUMERIC));
+				tempGeo.add(createListFromColumn(col, copyByValue, false, false, GeoElement.GEO_CLASS_NUMERIC, addToConstruction));
 			}
 		}
 		cons.setSuppressLabelCreation(oldSuppress);
@@ -606,7 +606,8 @@ public class CellRangeProcessor {
 
 
 	/** Creates a GeoList from the cells in an array of cellranges. Empty cells are ignored.
-	 * Uses these defaults: do not create undo point, do not sort, do not filter by geo type. */
+	 * Uses these defaults: do not create undo point, do not sort, do not filter by geo type,
+	 * set a label. */
 	public GeoElement createList(ArrayList<CellRange> rangeList,  boolean scanByColumn, boolean copyByValue) {
 		return  createList(rangeList,  scanByColumn, copyByValue, false, false, null, true) ;
 	}
@@ -620,9 +621,11 @@ public class CellRangeProcessor {
 		
 		GeoList geoList = null;
 		ArrayList<GeoElement> list = null;
-		if (copyByValue) geoList = new GeoList(cons);
-		else list = new ArrayList<GeoElement>();
-		
+		if (copyByValue)
+			geoList = new GeoList(cons);
+		else
+			list = new ArrayList<GeoElement>();
+
 		ArrayList<Point> cellList = new ArrayList<Point>();
 
 		// temporary fix for catching duplicate cells caused by ctrl-seelct
@@ -666,33 +669,21 @@ public class CellRangeProcessor {
 				}
 			}
 
-			// remove last comma
-			//if(listString.length()>1)
-			//	listString.deleteCharAt(listString.length()-1);
 
-			//listString.append("}");
-			
 			if (!copyByValue) {
 				AlgoDependentList algo = new AlgoDependentList(cons, list, false);
+				if(!setLabel){
+					cons.removeFromConstructionList(algo);
+				}
 				geoList = (GeoList) algo.getGeoElements()[0];
 			}
 
 			if(isSorted){
-				//listString.insert(0, "Sort[" );
-				//listString.append("]");
 				AlgoSort algo = new AlgoSort(cons, geoList);
 				cons.removeFromConstructionList(algo);
 				geoList = (GeoList)algo.getGeoElements()[0];
 			}
 
-
-			//Application.debug(listString);
-			// convert list string to geo
-			//geos = table.kernel.getAlgebraProcessor()
-			//.processAlgebraCommandNoExceptions(listString.toString(), false);
-
-
-
 		} catch (Exception ex) {
 			Application.debug("Creating list failed with exception " + ex);
 		}
@@ -719,11 +710,11 @@ public class CellRangeProcessor {
 	 * @param isSorted
 	 * @param doStoreUndo
 	 * @param geoTypeFilter
-	 * @param setLabel
+	 * @param addToConstruction
 	 * @return
 	 */
 	public GeoElement createListFromFrequencyTable(CellRange cr,  boolean scanByColumn, boolean copyByValue, 
-			boolean isSorted, boolean doStoreUndo, Integer geoTypeFilter, boolean setLabel) {
+			boolean isSorted, boolean doStoreUndo, Integer geoTypeFilter, boolean addToConstruction) {
 
 		double value;
 		int freq;
@@ -764,7 +755,7 @@ public class CellRangeProcessor {
 		if(doStoreUndo)
 			app.storeUndoInfo();
 		
-		if (setLabel)
+		if (addToConstruction)
 			geoList.setLabel(null);
 
 		if(geoList != null)
@@ -780,14 +771,14 @@ public class CellRangeProcessor {
 
 	/** Creates a list from all cells in a spreadsheet column */
 	public GeoElement createListFromColumn(int column, boolean copyByValue, boolean isSorted,
-			boolean storeUndoInfo, Integer geoTypeFilter) {
+			boolean storeUndoInfo, Integer geoTypeFilter, boolean addToConstruction) {
 
 		ArrayList<CellRange> rangeList = new ArrayList<CellRange>();
 		CellRange cr = new CellRange(table,column,-1);
 		cr.setActualRange();
 		rangeList.add(cr);
 
-		return  createList(rangeList,  true, copyByValue, isSorted, storeUndoInfo, geoTypeFilter, true) ;
+		return  createList(rangeList,  true, copyByValue, isSorted, storeUndoInfo, geoTypeFilter, addToConstruction) ;
 	}
 
 	/** Returns true if all cell ranges in the list are columns */
@@ -804,13 +795,13 @@ public class CellRangeProcessor {
 	 * Creates a string expression for a matrix where each sub-list is a list
 	 * of cells in the columns spanned by the range list
 	 */
-	public String createColumnMatrixExpression(ArrayList<CellRange> rangeList, boolean copyByValue) {
+	public String createColumnMatrixExpression(ArrayList<CellRange> rangeList, boolean copyByValue, boolean addToConstruction) {
 		GeoElement tempGeo;
 		StringBuilder sb = new StringBuilder();
 		sb.append("{");
 		for(CellRange cr : rangeList){
 			for(int col=cr.getMinColumn(); col<=cr.getMaxColumn(); col++){
-				tempGeo = createListFromColumn(col, copyByValue, false, false, GeoElement.GEO_CLASS_NUMERIC);
+				tempGeo = createListFromColumn(col, copyByValue, false, false, GeoElement.GEO_CLASS_NUMERIC, addToConstruction);
 				sb.append(tempGeo.getCommandDescription());
 				sb.append(",");
 				tempGeo.remove();
