@@ -11,8 +11,14 @@ import java.awt.datatransfer.Clipboard;
 import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.StringSelection;
 import java.awt.datatransfer.Transferable;
+import java.awt.datatransfer.UnsupportedFlavorException;
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.Reader;
 import java.io.StringReader;
+import java.net.URL;
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.LinkedList;
@@ -28,94 +34,302 @@ import javax.swing.text.html.parser.ParserDelegator;
 
 public class CopyPasteCut {
 
+	// ggb support classes
 	protected Kernel kernel;
 	protected Application app;
 	protected MyTable table;
+	protected DefaultTableModel tableModel;
+	protected SpreadsheetView view;
 
-	protected String externalBuf;
-	protected GeoElement[][] internalBuf;
-	protected int bufColumn;
-	protected int bufRow;
 
+	/**
+	 * Stores copied cell geo values as a tab-delimited string.
+	 */
+	protected String cellBufferStr;
+
+
+	/**
+	 * Stores copied cell geos as GeoElement[columns][rows]
+	 */
+	protected GeoElement[][] cellBufferGeo;
+
+
+	/**
+	 * Records the first row and first column of the current cell range copy source
+	 */
+	protected int sourceColumn1, sourceRow1;
+
+
+
+	/**
+	 * Stores construction index values while performing a paste
+	 */
+	private Object [] constructionIndexes;
+
+
+
+	/***************************************
+	 * Constructor
+	 */
 	public CopyPasteCut(JTable table0, Kernel kernel0) {
+
 		table = (MyTable)table0;
+		tableModel = (DefaultTableModel) table.getModel();
 		kernel = kernel0;	
 		app = kernel.getApplication();
+
+		view = table.getView();
+
 	}
 
-	public void copy(int column1, int row1, int column2, int row2, boolean skipInternalCopy) {
-		// external
-		externalBuf = "";
+
+	/**
+	 * Combines the GeoElement.toValueStrings from a given block of cell geos
+	 * into a single tab-delimited string. This string is stored in (1) the
+	 * global String field cellBufferStr and (2) the system clipboard.
+	 * 
+	 * If skipGeoCopy = false, the geos are also stored in the global
+	 * GeoElement[][] field cellBufferGeo
+	 * 
+	 * The cell block is defined by upper-left corner (column1, row1) 
+	 * and lower left corner (column2, row2)
+	 * 
+	 * @param column1
+	 * @param row1
+	 * @param column2
+	 * @param row2
+	 * @param skipGeoCopy
+	 */
+	public void copy(int column1, int row1, int column2, int row2, boolean skipGeoCopy) {
+
+		// copy tab-delimited geo values into the external buffer 
+		cellBufferStr = "";
 		for (int row = row1; row <= row2; ++ row) {
 			for (int column = column1; column <= column2; ++ column) {
 				GeoElement value = RelativeCopy.getValue(table, column, row);
 				if (value != null) {
-					externalBuf += value.toValueString();
-					//if (value.isChangeable()) {
-					//	externalBuf += value.toValueString();
-					//}
-					//else {
-					//	String def = value.getDefinitionDescription();
-					//	def = def.replaceAll("\\s+", "");
-					//	externalBuf += def;
-					//}
+					cellBufferStr += value.toValueString();
 				}
 				if (column != column2) {
-					externalBuf += "\t";
+					cellBufferStr += "\t";
 				}
 			}
 			if (row != row2) {
-				externalBuf += "\n";
+				cellBufferStr += "\n";
 			}
 		}
+
+		// store the tab-delimited values in the clipboard
 		Toolkit toolkit = Toolkit.getDefaultToolkit();
 		Clipboard clipboard = toolkit.getSystemClipboard();
-		StringSelection stringSelection = new StringSelection(externalBuf);
+		StringSelection stringSelection = new StringSelection(cellBufferStr);
 		clipboard.setContents(stringSelection, null);
 
-		// internal
-		if (skipInternalCopy) {
-			internalBuf = null;
+
+		// store copies of the actual geos in the internal buffer
+		if (skipGeoCopy) {
+			cellBufferGeo = null;
 		}
 		else
 		{
-			bufColumn = column1;
-			bufRow = row1;
-			internalBuf = RelativeCopy.getValues(table, column1, row1, column2, row2);
+			sourceColumn1 = column1;
+			sourceRow1 = row1;
+			cellBufferGeo = RelativeCopy.getValues(table, column1, row1, column2, row2);
 		}
 	}
 
+
+	/**
+	 * Copies the contents of the cell block defined by upper-left corner
+	 * (column1, row1) and lower left corner (column2, row2) into the system
+	 * clipboard and then deletes these geos.
+	 * 
+	 * TODO: The external buffer is nulled out so that a followup paste will
+	 * not perform a relative copy. This needs to be fixed, relative copy is
+	 * expected by the user.
+	 * 
+	 * @param column1
+	 * @param row1
+	 * @param column2
+	 * @param row2
+	 * @return
+	 */
 	public boolean cut(int column1, int row1, int column2, int row2) {
 
 		copy(column1, row1, column2, row2, false);
-		externalBuf = null;
+		// null out the external buffer so that paste will not do a relative copy
+		cellBufferStr = null;
 		return delete(column1, row1, column2, row2);	
 	}
 
+
+	/** Paste data from the clipboard using a cell range target */
+	public boolean paste(CellRange cr) {
+		return paste(cr.getMinColumn(),cr.getMinRow(),cr.getMaxColumn(),cr.getMaxRow());
+	}
+
+	/** Paste data from the clipboard */
 	public boolean paste(int column1, int row1, int column2, int row2) {
+
 		Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
 		Transferable contents = clipboard.getContents(null);
-		String buf = null;
+
+		return paste( column1,  row1,  column2,  row2,  contents);
+	}
+
+	
+	
+	public boolean paste(int column1, int row1, int column2, int row2, Transferable contents) {
+
 		boolean succ = false;
-		
-		/*
-		// print available data formats on clipboard
-		StringBuffer sb = new StringBuffer();
-		for (int i = 0; i < contents.getTransferDataFlavors().length; i++) {
-			sb.append(contents.getTransferDataFlavors()[i]);
-			sb.append("\n");
+
+		// extract a String from the Transferable 
+		String transferString = getTransferString(contents); 
+
+
+		// test if the transfer string is the same as the internal cell copy string,
+		// if true, then we have a tab-delimited list of cell geos and can paste them with relative cell references
+		boolean doInternalPaste = transferString != null && cellBufferStr != null && transferString.equals(cellBufferStr);
+
+
+
+		// create new geos from cellBufferStr and then paste them into the 
+		// target cells with relative cell references
+		// ========================================================
+
+		if (doInternalPaste  && cellBufferGeo != null) {
+			Construction cons = kernel.getConstruction();
+			kernel.getApplication().setWaitCursor();
+			try {
+				succ = true;
+				int columnStep = cellBufferGeo.length;
+				int rowStep = cellBufferGeo[0].length;
+
+				int maxColumn = column2;
+				int maxRow = row2;
+				// paste all data if just one cell selected
+				// ie overflow selection rectangle 
+				if (row2 == row1 && column2 == column1)
+				{
+					maxColumn = column1 + columnStep;
+					maxRow = row1 + rowStep;
+				}
+
+				// collect all redefine operations	
+				cons.startCollectingRedefineCalls();
+
+				// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
+				for (int c = column1 ; c <= column2 ; c+= columnStep)
+					for (int r = row1 ; r <= row2 ; r+= rowStep)
+						succ = succ && pasteInternal(c, r, maxColumn, maxRow);
+
+				// now do all redefining and build new construction 
+				cons.processCollectedRedefineCalls();
+
+
+			} catch (Exception ex) {
+				ex.printStackTrace(System.out);
+				app.showError(ex.getMessage());
+
+				//======================================	
+				// TODO: Why is this call here ????
+				// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
+				//succ = pasteExternalMultiple(buf, column1, row1, column2, row2);
+				//==========================================
+
+			} finally {
+				cons.stopCollectingRedefineCalls();
+				kernel.getApplication().setDefaultCursor();
+			}
 		}
-		Application.debug(sb.toString());
-*/
 
 
+
+		// Use the transferString data to create and paste new geos 
+		// into the target cells without relative cell references
+		// ========================================================
+
+		else if (transferString != null) {
+			//Application.debug("newline index "+buf.indexOf("\n"));
+			//Application.debug("length "+buf.length());
+
+			// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
+			succ = pasteExternalMultiple(transferString, column1, row1, column2, row2);
+		}
+
+		return succ;
+	}
+
+
+
+	/**
+	 * Returns a string object extracted from the given Transferable. If the
+	 * DataFlavor is "text/html;class=java.lang.String" an attempt is made to
+	 * convert the transferable object into a CSV string (e.g. data transferred
+	 * from Excel)
+	 * 
+	 * @param contents
+	 * @return
+	 */
+	private String getTransferString(Transferable contents){
+
+
+		// exit if no content
+		if(contents == null) return null;
+
+
+		// print available data formats in Transferable contents 
+		//Application.debug(Arrays.toString(contents.getTransferDataFlavors()));
+
+
+		// now try to extract a string from the Transferable
+
+		String buf = null;
 		try {
 			DataFlavor HTMLflavor = new	DataFlavor("text/html;class=java.lang.String");
-			String str = (String) contents.getTransferData(HTMLflavor);
 
-			final StringBuffer sbHTML = new StringBuffer();
+			//System.out.println("is HTML? " + contents.isDataFlavorSupported(HTMLflavor));
 
-			// convert HTML table into CSV
+			if(contents.isDataFlavorSupported(HTMLflavor)){
+				buf = convertHTMLTableToCSV((String) contents.getTransferData(HTMLflavor));
+			}
+
+		} catch (ClassNotFoundException e) {
+			e.printStackTrace();
+		} catch (UnsupportedFlavorException e) {
+			e.printStackTrace();
+		} catch (IOException e) {
+			e.printStackTrace();
+		}
+
+
+		// no HTML found, try plain text
+		if (buf == null && (contents != null) && contents.isDataFlavorSupported(DataFlavor.stringFlavor)) {
+			try {
+				buf = (String)contents.getTransferData(DataFlavor.stringFlavor);
+				//Application.debug("pasting from String: "+buf);
+			} catch (Exception ex) {
+				Application.debug("transferable has no String");
+				//ex.printStackTrace();
+				//app.showError(ex.getMessage());
+			}
+		}
+
+		return buf;
+
+	}
+
+
+
+	/** 
+	 * Converts HTML table into CSV
+	 */
+	private String convertHTMLTableToCSV(String HTMLTableString){
+
+		final StringBuilder sbHTML = new StringBuilder();
+
+		try {
+			// prepare the parser
 			HTMLEditorKit.ParserCallback callback = 
 				new HTMLEditorKit.ParserCallback () {
 				boolean foundTable = false;
@@ -134,7 +348,7 @@ public class CopyPasteCut {
 
 						if (containsComma && (data[0] != '"' || data[data.length-1] != '"'))
 							appendQuotes = true;
-						
+
 						if (containsComma) {
 							boolean isNumber = true;
 							int noOfCommas = 0;
@@ -142,14 +356,14 @@ public class CopyPasteCut {
 								if (data[i] == ',') noOfCommas++;
 								else if (data[i] < '0' || data[i] > '9') isNumber = false;
 							}
-							
+
 							// check for European-style decimal comma
 							if (isNumber && noOfCommas == 1)
 								for (int i = 0 ; i < data.length ; i++)
-								if (data[i] == ',') {
-									//Application.debug("replacing , with .");
-									data[i] = '.';
-								}
+									if (data[i] == ',') {
+										//Application.debug("replacing , with .");
+										data[i] = '.';
+									}
 						}
 
 						if (appendQuotes) sbHTML.append('"');
@@ -159,6 +373,7 @@ public class CopyPasteCut {
 					}
 					//System.out.println(data);
 				}
+
 				public void handleStartTag(HTML.Tag tag, 
 						MutableAttributeSet attrSet, int pos) {
 					if (tag == HTML.Tag.TABLE) {
@@ -188,112 +403,57 @@ public class CopyPasteCut {
 					}
 
 				}
-
 			};
-			Reader reader = new StringReader(str);
-			new ParserDelegator().parse(reader, callback, true);
-			
-			if (sbHTML.length() != 0) {
-				// found HTML table to paste (as CSV)
-				buf = sbHTML.toString();
-				Application.debug("pasting from HTML <table>: "+buf);
-			}
 
+			// parse the text
+			Reader reader = new StringReader(HTMLTableString);
+			new ParserDelegator().parse(reader, callback, true);
 		}
+
 		catch (Exception e) {
 			Application.debug("clipboard: no HTML");
 		}			
 
-		//Application.debug("paste: "+row1+" "+row2+" "+column1+" "+column2);
 
-		// no HTML found, try plain text
-		if ( buf == null && (contents != null) && contents.isDataFlavorSupported(DataFlavor.stringFlavor)) {
-			try {
-				buf = (String)contents.getTransferData(DataFlavor.stringFlavor);
-				Application.debug("pasting from String: "+buf);
-			} catch (Exception ex) {
-				Application.debug("clipboard: no String");
-				//ex.printStackTrace();
-				//app.showError(ex.getMessage());
-				// Util.handleException(table, ex);
-			}
-		}
-
-		if (buf != null && externalBuf != null && buf.equals(externalBuf) && internalBuf != null) {
-			Construction cons = kernel.getConstruction();
-			kernel.getApplication().setWaitCursor();
-			try {
-				succ = true;
-				int columnStep = internalBuf.length;
-				int rowStep = internalBuf[0].length;
-
-				int maxColumn = column2;
-				int maxRow = row2;
-				// paste all data if just one cell selected
-				// ie overflow selection rectangle 
-				if (row2 == row1 && column2 == column1)
-				{
-					maxColumn = column1 + columnStep;
-					maxRow = row1 + rowStep;
-				}
-
-				// collect all redefine operations	
-				cons.startCollectingRedefineCalls();
-
-				// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
-				for (int c = column1 ; c <= column2 ; c+= columnStep)
-					for (int r = row1 ; r <= row2 ; r+= rowStep)
-						succ = succ && pasteInternal(c, r, maxColumn, maxRow);
-				
-				// now do all redefining and build new construction 
-				cons.processCollectedRedefineCalls();
-
-
-			} catch (Exception ex) {
-				ex.printStackTrace(System.out);
-				app.showError(ex.getMessage());
-
-				//for (int c = column1 ; c <= column2 ; c++)
-				//for (int r = row1 ; r <= row2 ; r++)
-				//	pasteExternal(buf, c, r);
-
-				// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
-				succ = pasteExternalMultiple(buf, column1, row1, column2, row2);
-
-				// Util.handleException(table, ex);
-			} finally {
-				cons.stopCollectingRedefineCalls();
-				kernel.getApplication().setDefaultCursor();
-			}
-		}
-		else if (buf != null) {
-			//Application.debug("newline index "+buf.indexOf("\n"));
-			//Application.debug("length "+buf.length());
-
-			// paste data multiple times to fill in the selection rectangle (and maybe overflow a bit)
-			succ = pasteExternalMultiple(buf, column1, row1, column2, row2);
-		}
-
-		return succ;
+		if (sbHTML.length() != 0) 	//found HTML table to paste as CSV		
+			return sbHTML.toString();  
+		else
+			return null;
 	}
 
-	Object [] constructionIndexes;
 
 
+
+
+	/**
+	 * Creates copies of the geos stored in cellBufferGeo, naming them to correspond with the 
+	 * given target cell range and the original source cells.
+	 * Relative cell references are applied to the new geos.
+	 * 
+	 * The target cell range is defined by upper left corner (column1, row1) 
+	 * and lower right corner (maxColumn, maxRow).
+	 * 
+	 * @param column1
+	 * @param row1
+	 * @param maxColumn
+	 * @param maxRow
+	 * @return
+	 * @throws Exception
+	 */
 	public boolean pasteInternal(int column1, int row1, int maxColumn, int maxRow) throws Exception {		
-		int width = internalBuf.length;
+		int width = cellBufferGeo.length;
 		if (width == 0) return false;
-		int height = internalBuf[0].length;
+		int height = cellBufferGeo[0].length;
 		if (height == 0) return false;
 
 		app.setWaitCursor();
 		boolean succ = false; 
 
 		//Application.debug("height = " + height+" width = "+width);
-		int x1 = bufColumn;
-		int y1 = bufRow;
-		int x2 = bufColumn + width - 1;
-		int y2 = bufRow + height - 1;
+		int x1 = sourceColumn1;
+		int y1 = sourceRow1;
+		int x2 = sourceColumn1 + width - 1;
+		int y2 = sourceRow1 + height - 1;
 		int x3 = column1;
 		int y3 = row1;
 		int x4 = column1 + width - 1;
@@ -317,6 +477,7 @@ public class CopyPasteCut {
 		int count = 0;
 
 
+		// ensure the table is large enough to contain the new data
 		DefaultTableModel model = (DefaultTableModel)table.getModel();
 		if (model.getRowCount() < y4 + 1) {
 			model.setRowCount(y4 + 1);
@@ -324,22 +485,26 @@ public class CopyPasteCut {
 		if (model.getColumnCount() < x4 + 1) {
 			table.setMyColumnCount(x4 + 1);
 		}
-		GeoElement[][] values1 = internalBuf;//RelativeCopy.getValues(table, x1, y1, x2, y2);
+
+
+
+		GeoElement[][] values1 = cellBufferGeo;//RelativeCopy.getValues(table, x1, y1, x2, y2);
 		try {
 			for (int x = x1; x <= x2; ++ x) {
 				int ix = x - x1;
 				for (int y = y1; y <= y2; ++ y) {
 					int iy = y - y1;
-					
+
 					// check if we're pasting back into what we're copying from
 					boolean inSource =  x + (x3-x1) <= x2 &&
-										x + (x3-x1) >= x1 &&
-										y + (y3-y1) <= y2 &&
-										y + (y3-y1) >= y1;
-					
-					
+					x + (x3-x1) >= x1 &&
+					y + (y3-y1) <= y2 &&
+					y + (y3-y1) >= y1;
+
+
 					//Application.debug("x1="+x1+" x2="+x2+" x3="+x3+" x4="+x4+" x="+x+" ix="+ix);
 					//Application.debug("y1="+y1+" y2="+y2+" y3="+y3+" y4="+y4+" y="+y+" iy="+iy);
+
 					if (ix+column1 <= maxColumn && iy+row1 <= maxRow//) { // check not outside selection rectangle
 							&& (!inSource) ) { // check we're not pasting over what we're copying
 
@@ -382,50 +547,63 @@ public class CopyPasteCut {
 		return succ;
 	}
 
+
+
+
+
+
 	//protected static Pattern pattern = Pattern.compile("\\s*(\\\"([^\\\"]+)\\\")|([^,\\t\\\"]+)");
 	//protected static Pattern pattern = Pattern.compile("\\s*(\\\"([^\\\"]+)\\\")|([^\\t\\\"]+)");
+	
 	protected static Pattern pattern1 = Pattern.compile("((\\\"([^\\\"]+)\\\")|([^\\t\\\"\\(]+)|(\\([^)]+\\)))?(\\t|$)");
 	protected static Pattern pattern2 = Pattern.compile("((\\\"([^\\\"]+)\\\")|([^,\\\"\\(]+)|(\\([^)]+\\)))?(,|$)");
 
 	public static String[][] parseData(String input) {
-		
+
 		//Application.debug("parse data: "+input);
-		
+
 		String[] lines = input.split("\\r*\\n", -1);
 		String[][] data = new String[lines.length][];
 		for (int i = 0; i < lines.length; ++ i) {
-			
+
 			// trim() removes tabs which we need
 			lines[i] = geogebra.util.Util.trimSpaces(lines[i]);
 			LinkedList list = new LinkedList();
-			
+
 			int firstCommaIndex = lines[i].indexOf(",");
 			int lastCommaIndex = lines[i].lastIndexOf(",");
 			int firstBracketIndex = lines[i].indexOf("[");
 			int lastBracketIndex = lines[i].lastIndexOf("]");
+			int firstTabIndex = lines[i].indexOf("\t");
 			
-			if (firstCommaIndex > firstBracketIndex && lastCommaIndex < lastBracketIndex) {
-				// assume it's a GeoGebra command and therefore we don't want to split on commas etc
+			// no commas, brackets or tabs, so add entire line
+			if (firstCommaIndex == -1 && firstBracketIndex == -1 && firstTabIndex == -1)
+					list.addLast(lines[i]);	
+			
+			// brackets enclose the expression, so assume it's a GeoGebra command and add entire line
+			else if (firstCommaIndex > firstBracketIndex && lastCommaIndex < lastBracketIndex) {
 				list.addLast(lines[i]);
+				
+			// otherwise split on commas and tabs	
 			} else {
-			
+
 				Matcher matcher = null;
-				if (lines[i].indexOf('\t') != -1) {
+				if (firstTabIndex != -1) {
 					matcher = pattern1.matcher(lines[i]);
 				}
 				else {
 					matcher = pattern2.matcher(lines[i]);
 				}
-	
+
 				while (matcher.find()) {
 					String data1 = matcher.group(3);
 					String data2 = matcher.group(4);
 					String data3 = matcher.group(5);
-					
+
 					//Application.debug("data1: "+data1);
 					//Application.debug("data2: "+data2);
 					//Application.debug("data3: "+data3);
-	
+
 					if (data1 != null) {
 						data1 = data1.trim();
 						data1 = checkDecimalComma(data1); // allow decimal comma
@@ -452,7 +630,8 @@ public class CopyPasteCut {
 		}
 		return data;		
 	}
-	
+
+
 	/*
 	 * change 3,4 to 3.4
 	 * leave {3,4,5} alone
@@ -461,10 +640,12 @@ public class CopyPasteCut {
 		if (str.indexOf("{") == -1 && str.indexOf(",") == str.lastIndexOf(",")) {
 			str = str.replaceAll(",", "."); // allow decimal comma
 		}
-		
+
 		return str;
 	}
 
+
+
 	private boolean pasteExternalMultiple(String buf,int column1, int row1, int column2, int row2) {
 		/*
 		int newlineIndex = buf.indexOf("\n");
@@ -480,14 +661,19 @@ public class CopyPasteCut {
 		    }
 		}*/
 		boolean succ = true;
+
+		// convert the input String buf into a 2D array defined by tab or comma delimiters
 		String[][] data = parseData(buf);
+
+
 		int rowStep = data.length;
 		int columnStep = data[0].length;
-		
+
 		if (columnStep == 0) return false;
 
 		int maxColumn = column2;
 		int maxRow = row2;
+
 		// paste all data if just one cell selected
 		// ie overflow selection rectangle 
 		if (row2 == row1 && column2 == column1)
@@ -505,6 +691,19 @@ public class CopyPasteCut {
 
 	}
 
+	/**
+	 * Creates new cell geos using the string values stored in the given String[][].
+	 * Cells are named to correspond with the target cell range defined by upper
+	 * left corner (column1, row1) and lower right corner (maxColumn, maxRow).
+	 * Does not apply relative cell references.
+	 * 
+	 * @param data
+	 * @param column1
+	 * @param row1
+	 * @param maxColumn
+	 * @param maxRow
+	 * @return
+	 */
 	public boolean pasteExternal(String[][] data, int column1, int row1, int maxColumn, int maxRow) {
 		app.setWaitCursor();
 		boolean succ = false;			
@@ -528,6 +727,7 @@ public class CopyPasteCut {
 					if (column < 0 || column > maxColumn) continue;
 					int ix = column - column1;
 					//Application.debug(iy + " " + ix + " [" + data[iy][ix] + "]");
+					if(data[iy][ix] == null) continue;
 					data[iy][ix] = data[iy][ix].trim();
 					if (data[iy][ix].length() == 0) {
 						GeoElement value0 = RelativeCopy.getValue(table, column, row);
@@ -540,8 +740,9 @@ public class CopyPasteCut {
 					}
 					else {
 						GeoElement value0 = RelativeCopy.getValue(table, column, row);
-						values2[iy][ix] = MyCellEditor.prepareAddingValueToTableNoStoringUndoInfo(kernel, table, data[iy][ix], value0, column, row);
-						values2[iy][ix].setAuxiliaryObject(values2[iy][ix].isGeoNumeric()); 
+						values2[iy][ix] = RelativeCopy.prepareAddingValueToTableNoStoringUndoInfo(kernel, table, data[iy][ix], value0, column, row);
+						//values2[iy][ix].setAuxiliaryObject(values2[iy][ix].isGeoNumeric()); 
+						values2[iy][ix].setAuxiliaryObject(true); 
 						table.setValueAt(values2[iy][ix], row, column);
 					}
 				}
@@ -589,104 +790,29 @@ public class CopyPasteCut {
 				//}
 			}
 		}
+
+		// Let the trace manager know about the delete 
+		// TODO add SelectAll
+		if(table.getSelectionType()==MyTable.COLUMN_SELECT){
+			view.getTraceManager().handleColumnDelete(column1, column2);
+		}
+
 		return succ;
 	}
 
-	public void createPointsAndAList2(GeoElement[][] values) throws Exception {
-		LinkedList list = new LinkedList();
 
-		/* 
-		 * Markus Hohenwarter, 2008-08-24, I think this is not needed...
-		 * 
-		if (values.length == 2) {
-	   	 	for (int i = 0; i < values[0].length && i < values[1].length; ++ i) {
-	   	 		GeoElement v1 = values[0][i];
-	   	 		GeoElement v2 = values[1][i];
-	   	 		if (v1 != null && v2 != null && v1.isGeoNumeric() && v2.isGeoNumeric()) {
-	   	 			String text = "(" + v1.getLabel() + "," + v2.getLabel() + ")";
-	   	 			GeoElement [] geos = table.kernel.getAlgebraProcessor().processAlgebraCommandNoExceptionHandling(text, false);
+	public void deleteAll() {
 
-	   	 			// set label P_1, P_2, etc.
-	   	 		    String pointName = geos[0].getIndexLabel("P");
-	   	 		    geos[0].setLabel(pointName);
+		table.copyPasteCut.delete(0, 0, tableModel.getColumnCount(), tableModel.getRowCount());
 
-	   	 			list.addLast(pointName);
-	   	 		}
-	   	 	}
-	   	 }
-		 */
-
-		// create points
-		if (values.length > 0) {
-			for (int i = 0; i < values.length; ++ i) {
-				if (values[i].length != 2) continue;
-				GeoElement v1 = values[i][0];
-				GeoElement v2 = values[i][1];
-				if (v1 != null && v2 != null && v1.isGeoNumeric() && v2.isGeoNumeric()) {	   	 			
-					String text = "(" + v1.getLabel() + "," + v2.getLabel() + ")";
-					GeoElement [] geos = table.kernel.getAlgebraProcessor().processAlgebraCommandNoExceptionHandling(text, false);
-
-					// set label P_1, P_2, etc.
-					String pointName = geos[0].getIndexLabel("P");
-					geos[0].setLabel(pointName);
-
-					list.addLast(geos[0].getLabel());
-				}
-			}
-		}
-
-		// create list of points
-		if (list.size() > 0) {
-			String[] points = (String[])list.toArray(new String[0]);	   		
-			String text = "{";
-			for (int i = 0; i < points.length; ++ i) {
-				text += points[i];
-				if (i != points.length - 1) text += ",";
-			}
-			text += "}";
-
-			GeoElement [] geos = table.kernel.getAlgebraProcessor().processAlgebraCommandNoExceptionHandling(text, false);
-
-			// set list name
-			String listName = geos[0].getIndexLabel("L");
-			geos[0].setLabel(listName);
-		}
 	}
 
-	public void createPointsAndAList1(GeoElement[][] values) throws Exception {
-		LinkedList list = new LinkedList();
-		if (values.length == 1 && values[0].length > 0) {
-			for (int i = 0; i < values[0].length; ++ i) {
-				GeoElement v1 = values[0][i];
-				if (v1 != null && v1.isGeoPoint()) {
-					list.addLast(v1.getLabel());
-				}
-			}
-		}
-		if (values.length > 0 && values[0].length == 1) {
-			for (int i = 0; i < values.length; ++ i) {
-				GeoElement v1 = values[i][0];
-				if (v1 != null && v1.isGeoPoint()) {
-					list.addLast(v1.getLabel());
-				}
-			}
-		}
 
-		if (list.size() > 0) {
-			String[] points = (String[])list.toArray(new String[0]);	   		 
-			String text = "={";
-			for (int i = 0; i < points.length; ++ i) {
-				text += points[i];
-				if (i != points.length - 1) text += ",";
-			}
-			text += "}";
-			GeoElement [] geos = table.kernel.getAlgebraProcessor().processAlgebraCommandNoExceptionHandling(text, false);
 
-			// set list name
-			String listName = geos[0].getIndexLabel("L");
-			geos[0].setLabel(listName);
-		}
-	}
+
+
+
+
 	class Record {
 		int id, x1, y1, x2, y2;
 		public Record(int id, int x1, int y1, int x2, int y2){
@@ -741,4 +867,70 @@ public class CopyPasteCut {
 	}
 	private static Comparator comparator;
 
+
+
+
+
+	//====================================================
+	//   File and URL 
+	//====================================================
+
+
+	// default pasteFromFile: clear spreadsheet and then paste from upper left corner
+	public boolean pasteFromURL(URL url) {
+
+		CellRange cr = new CellRange(table, 0,0,0,0);
+		return pasteFromURL(url, cr, true);
+
+	}
+
+
+	public boolean pasteFromURL(URL url, CellRange targetRange, boolean clearSpreadsheet) {
+
+		// read file 
+		StringBuilder contents = new StringBuilder();
+
+		try {				
+			InputStream is = url.openStream();
+			BufferedReader input = new BufferedReader(new InputStreamReader(is));
+			try {
+				String line = null;
+				while ((line = input.readLine()) != null) {
+					contents.append(line);
+					contents.append(System.getProperty("line.separator"));
+				}
+			} finally {
+				input.close();
+
+			}
+		} catch (IOException ex) {
+			ex.printStackTrace();
+			return false;
+		}
+
+		//System.out.println(dataFile.getName() + ": " + contents.capacity());
+
+		// copy file contents to clipboard		
+		StringSelection stringSelection = new StringSelection(contents.toString());
+		Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
+		Transferable oldContent = clipboard.getContents(null);
+		clipboard.setContents(stringSelection, null);
+
+
+		// paste from clipboard into spreadsheet
+		if(clearSpreadsheet){
+			deleteAll();
+		}
+
+		boolean oldEqualsSetting = view.isEqualsRequired();
+		view.setEqualsRequired(true);
+		boolean succ = paste(targetRange);
+		clipboard.setContents(oldContent, null);
+		view.setEqualsRequired(oldEqualsSetting);
+
+		return succ;
+
+	}
+
+
 }
