@@ -988,7 +988,7 @@ public class InspectorView extends InputDialog implements View, MouseListener, L
 
 
 	private String evaluateToText(String expr){
-		GeoText text = kernel.getAlgebraProcessor().evaluateToText(expr, false);	
+		GeoText text = kernel.getAlgebraProcessor().evaluateToText(expr, false, true);	
 		return text.getTextString();
 	}
 
