@@ -444,10 +444,11 @@ public class RelativeCopy {
 			String row1 = "" + (row + 1);
 			String column2 = GeoElement.getSpreadsheetColumnName(column + dx);
 			String row2 = "" + (row + dy + 1);
-			// space needed 2 E2 not 2E2
+			Application.debug("X "+text);
 			text = replaceAll(pattern2, text, "::" + column1 + "::" + row1, " " + column2 + row2);
 			text = replaceAll(pattern2, text, "$" + column1 + "::" + row1, "$" + column1 + row2);
 			text = replaceAll(pattern2, text, "::" + column1 + "$" + row1, column2 + "$" + row1);
+			Application.debug("Y "+text);
 
 		}
 
