@@ -339,10 +339,13 @@ View, ComponentListener, FocusListener, Gridable, SettingListener
 			doRemove(geo, location.y, location.x);
 		}
 
-
-		if(geo.isGeoBoolean()){
-			table.oneClickEditMap.remove(location);
-		}
+		switch (geo.getGeoClassType()){ 
+		case GeoElement.GEO_CLASS_BOOLEAN: 
+		case GeoElement.GEO_CLASS_BUTTON: 
+		case GeoElement.GEO_CLASS_LIST: 
+			table.oneClickEditMap.remove(geo);                               
+		} 
+		
 	}
 
 	private void doRemove(GeoElement geo, int row, int col) {
@@ -1210,6 +1213,7 @@ View, ComponentListener, FocusListener, Gridable, SettingListener
 	}
 
 	public boolean setFileBrowserDirectory(String rootString, int mode) {
+		settings().setInitialBrowserMode(mode); 
 		return getFileBrowser().setRoot(rootString, mode);
 	}
 
