@@ -1093,7 +1093,7 @@ StatPanelInterface{
 			boxPlot = null;
 
 			statDialog.getStatDialogController().removeRegressionGeo();
-			statDialog.getStatDialogController().removeDataListSelected();
+			statDialog.getStatDialogController().disposeDataSelectedList();
 			plotGeoList.clear();
 		
 			// =================================================================
