@@ -423,12 +423,15 @@ public class StatDialogController {
 	}
 
 	public void removeRegressionGeo(){
-		if(geoRegression != null)
-			removeStatGeo(geoRegression);
+		if(geoRegression != null){
+			geoRegression.remove();
+			geoRegression = null;
+		}
 	}
 
-	public void removeDataListSelected(){
-		dataSelected = null;
+	
+	public void disposeDataSelectedList(){
+			dataSelected = null;
 	}
 
 
@@ -437,9 +440,13 @@ public class StatDialogController {
 	 */
 	public void removeStatGeos(){
 
-		removeStatGeo(dataSelected);
-		removeStatGeo(geoRegression);
-
+		if(dataSelected != null){
+			dataSelected.remove();
+			dataSelected = null;
+		}
+		
+		removeRegressionGeo();
+		
 		if(sd.comboStatPanel != null) {
 			sd.comboStatPanel.removeGeos();
 		}
@@ -449,12 +456,7 @@ public class StatDialogController {
 		}
 	}
 
-	private static void removeStatGeo(GeoElement statGeo){
-		if(statGeo != null){
-			statGeo.remove();
-			statGeo = null;
-		}
-	}
+	
 
 	public SummaryStatistics getSummaryStatistics(GeoList dataList){
 
