@@ -1,5 +1,6 @@
 package geogebra.kernel;
 
+
 /**
  * @author  Victor Franco Espino, Markus Hohenwarter
  * @version 11-02-2007
@@ -25,7 +26,7 @@ public class AlgoCurvature extends AlgoElement {
     	}    	
     }
     
-    AlgoCurvature(Construction cons, GeoPoint A, GeoFunction f) {
+    public AlgoCurvature(Construction cons, GeoPoint A, GeoFunction f) {
         super(cons);
         this.f = f;
         this.A = A;
@@ -35,7 +36,7 @@ public class AlgoCurvature extends AlgoElement {
         compute();
     }
  
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoCurvature";
     }
 
@@ -60,4 +61,9 @@ public class AlgoCurvature extends AlgoElement {
     	else     	
     		K.setUndefined();    	
     }   
+    
+	public void remove() {  
+    	super.remove();  
+    }
+
 }
\ No newline at end of file
