@@ -28,10 +28,6 @@ import geogebra.kernel.arithmetic.ExpressionNode;
  */
 public class AlgoDependentText extends AlgoElement {
 
-    /**
-	 * 
-	 */
-	private static final long serialVersionUID = 1L;
 	private ExpressionNode root;  // input
     private GeoText text;     // output              
         
@@ -75,17 +71,27 @@ public class AlgoDependentText extends AlgoElement {
 	protected void setInputOutput() {
         input = root.getGeoElementVariables();
         
-        output = new GeoElement[1];        
-        output[0] = text;        
+        setOutputLength(1);        
+        setOutput(0,text);        
         setDependencies(); // done by AlgoElement
     }    
     
     public GeoText getGeoText() { return text; }
-    
+    String oldFormat = "";
     // calc the current value of the arithmetic tree
     protected final void compute() {	
-    	
+    	String format = text.getPrintDecimals()+","+text.getPrintFigures();
     	text.setTemporaryPrintAccuracy();
+    	if(!format.equals(oldFormat)){
+    		oldFormat = format;
+    		for(int i=0;i<input.length;i++)
+    			if(input[i].getParentAlgorithm()!=null &&
+    					input[i].isGeoText() && !input[i].isLabelSet()){
+    				input[i].setVisualStyle(text);
+    				input[i].getParentAlgorithm().update();
+    			}
+    	}
+    	
     	
     	try {    	
 	    	boolean latex = text.isLaTeX();
@@ -108,11 +114,13 @@ public class AlgoDependentText extends AlgoElement {
     
     final public String toString() {
         // was defined as e.g.  text0 = "Radius: " + r
+    	if (root == null) return "";
         return root.toString();
     }
     
     final public String toRealString() {
         // was defined as e.g.  text0 = "Radius: " + r
+    	if (root == null) return "";
         return root.toRealString();
     }
 }
