@@ -39,9 +39,6 @@ import java.util.TreeSet;
 public abstract class AlgoElement extends ConstructionElement implements EuclidianViewCE {
 
 	private static ResourceBundle rbalgo2command;
-	// Added for Intergeo File Format (Yves Kreis) -->
-	private static ResourceBundle rbalgo2intergeo;
-	// <-- Added for Intergeo File Format (Yves Kreis)
 
 	protected GeoElement[] input;
 	/**
@@ -384,24 +381,6 @@ public abstract class AlgoElement extends ConstructionElement implements Euclidi
 		return rbalgo2command.getString(classname);
 	}
 
-	// Added for Intergeo File Format (Yves Kreis) -->
-	private String getIntergeoString(String classname) {
-		// init rbalgo2intergeo if needed
-		// for translation of Algo-classname to Intergeo name
-		if (rbalgo2intergeo == null) {
-			rbalgo2intergeo = app.initAlgo2IntergeoBundle();
-		}
-
-		// translate algorithm class name to Intergeo name
-		try {
-			return rbalgo2intergeo.getString(classname);
-		} catch (MissingResourceException e) {
-			return classname;
-		}
-	}
-
-	// <-- Added for Intergeo File Format (Yves Kreis)
-
 	// in setInputOutput() the member vars input and output are set
 	abstract protected void setInputOutput();
 
@@ -1029,7 +1008,9 @@ public abstract class AlgoElement extends ConstructionElement implements Euclidi
 	private void appendCheckVector(StringBuilder sb, GeoElement geo, boolean real) {
 		String cmd = real ? geo.getRealLabel() : geo.getLabel();
 		if (geo.isGeoVector()) {
-			String vectorCommand = app.getCommand("Vector") + "["; // want it translated eg for redefine
+			String vectorCommand = "Vector[";
+			if(kernel.isPrintLocalizedCommandNames())
+				vectorCommand = app.getCommand("Vector") + "["; // want it translated eg for redefine
 																	// dialog
 			boolean needsWrapping = !geo.isLabelSet() && !cmd.startsWith(vectorCommand);
 
@@ -1076,30 +1057,6 @@ public abstract class AlgoElement extends ConstructionElement implements Euclidi
 		return cmdname;
 	}
 
-	/**
-	 * translate class name to Intergeo name Intergeo File Format (Yves Kreis)
-	 * 
-	 * @return intergeo command name
-	 */
-	String getIntergeoName() {
-		String cmdname, classname;
-		// get class name
-		// classname = this.getClass().toString();
-		// classname = classname.substring(classname.lastIndexOf('.') + 1);
-		classname = getClassName();
-		// dependent algorithm is an "Expression"
-		if (classname.startsWith("AlgoDependent")) {
-			cmdname = "Expression";
-		} else if (classname.equals("AlgoPointOnPath")) {
-			AlgoPointOnPath algo = (AlgoPointOnPath) this;
-			cmdname = getIntergeoString(classname + "+" + algo.getPath().toGeoElement().getClassName());
-		} else {
-			// translate algorithm class name to Intergeo name
-			cmdname = getIntergeoString(classname);
-		}
-		return cmdname;
-	}
-
 	/**
 	 * Returns this algorithm and it's output objects (GeoElement) in XML format. GeoGebra File Format.
 	 */
@@ -1169,47 +1126,6 @@ public abstract class AlgoElement extends ConstructionElement implements Euclidi
 		}
 	}
 
-	/**
-	 * Returns this algorithm or it's output objects (GeoElement) in I2G format. Intergeo File Format. (Yves
-	 * Kreis)
-	 */
-	@Override
-	public void getI2G(StringBuilder sb, int mode) {
-		// this is needed for helper commands like
-		// intersect for single intersection points
-		if (!isPrintedInXML) {
-			return;
-		}
-
-		// USE INTERNAL COMMAND NAMES IN EXPRESSION
-		boolean oldValue = kernel.isPrintLocalizedCommandNames();
-		kernel.setPrintLocalizedCommandNames(false);
-
-		try {
-			if (mode == CONSTRAINTS) {
-				// command
-				String cmdname = getIntergeoName();
-				if (!cmdname.equals("Expression")) {
-					sb.append(getCmdI2G(cmdname));
-				}
-			} else {// if (output != null){
-				// output
-				GeoElement geo;
-				for (int i = 0; i < getOutputLength(); i++) {
-					geo = getOutput(i);
-					// save only GeoElements that have a valid label
-					if (geo.isLabelSet()) {
-						geo.getI2G(sb, mode);
-					}
-				}
-			}
-		} catch (Exception e) {
-			e.printStackTrace();
-		}
-
-		kernel.setPrintLocalizedCommandNames(oldValue);
-	}
-
 	// Expressions should be shown as out = expression
 	// e.g. <expression label="u" exp="a + 7 b"/>
 	protected String getExpXML() {
@@ -1322,56 +1238,11 @@ public abstract class AlgoElement extends ConstructionElement implements Euclidi
 		return sb.toString();
 	}
 
-	// standard command has cmdname, output, input
-	// Added for Intergeo File Format (Yves Kreis) -->
-	private String getCmdI2G(String cmdname) {
-		StringBuilder sb = new StringBuilder();
-		sb.append("\t\t<" + cmdname + ">\n");
-
-		String type;
-
-		// add output information
-		// if (output != null) {
-		for (int i = 0; i < getOutputLength(); i++) {
-			type = getXMLtypeString(getOutput(i));
-			sb.append("\t\t\t<" + type + " out=\"true\">");
-			sb.append(Util.encodeXML(getOutput(i).getLabel()));
-			sb.append("</" + type + ">\n");
-		}
-		// }
-
-		// add input information
-		if (input != null) {
-			if (cmdname.equals("line_parallel_to_line_through_point")
-					|| cmdname.equals("line_perpendicular_to_line_through_point")) {
-				type = getXMLtypeString(input[1]);
-				sb.append("\t\t\t<" + type + ">");
-				sb.append(Util.encodeXML(input[1].getLabel()));
-				sb.append("</" + type + ">\n");
-				type = getXMLtypeString(input[0]);
-				sb.append("\t\t\t<" + type + ">");
-				sb.append(Util.encodeXML(input[0].getLabel()));
-				sb.append("</" + type + ">\n");
-			} else {
-				for (int i = 0; i < input.length; i++) {
-					type = getXMLtypeString(input[i]);
-					sb.append("\t\t\t<" + type + ">");
-					sb.append(Util.encodeXML(input[i].getLabel()));
-					sb.append("</" + type + ">\n");
-				}
-			}
-		}
-
-		sb.append("\t\t</" + cmdname + ">\n");
-		return sb.toString();
-	}
 
 	final public String getXMLtypeString(GeoElement geo) {
 		return geo.getClassName().substring(3).toLowerCase(Locale.US);
 	}
 
-	// <-- Added for Intergeo File Format (Yves Kreis)
-
 	/**
 	 * Sets whether the output of this command should be labeled. This setting is used for getXML().
 	 * 
