@@ -18,6 +18,7 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.euclidian.EuclidianConstants;
 import geogebra.kernel.arithmetic.NumberValue;
 
 /**
@@ -36,18 +37,19 @@ public class AlgoEllipseFociLength extends AlgoConicFociLength {
 		        super(cons, label, A, B, a);		       
 		    }
 
-	protected String getClassName() {
+	public String getClassName() {
         return "AlgoEllipseFociLength";
     }
 	
+	public int getRelatedModeID() {
+    	return EuclidianConstants.MODE_ELLIPSE_THREE_POINTS;
+    }
+    
+	
 	 final public String toString() {
-        StringBuffer sb = new StringBuffer();
-
         // Michael Borcherds 2008-03-30
         // simplified to allow better Chinese translation
-        sb.append(app.getPlain("EllipseWithFociABandFirstAxisLengthC",A.getLabel(),B.getLabel(),a.toGeoElement().getLabel()));	        	      
-        
-        return sb.toString();
+        return app.getPlain("EllipseWithFociABandFirstAxisLengthC",A.getLabel(),B.getLabel(),a.toGeoElement().getLabel());	        	      
     }
 
 }
