@@ -18,6 +18,7 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.euclidian.EuclidianConstants;
 import geogebra.kernel.arithmetic.NumberValue;
 
 /**
@@ -36,9 +37,14 @@ public class AlgoHyperbolaFociLength extends AlgoConicFociLength {
         super(cons, label, A, B, a);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoHyperbolaFociLength";
     }
+    
+    public int getRelatedModeID() {
+    	return EuclidianConstants.MODE_HYPERBOLA_THREE_POINTS;
+    }
+    
 
 	final public String toString() {
         // Michael Borcherds 2008-03-30
