@@ -12,6 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.euclidian.EuclidianConstants;
+
 
 
 /**
@@ -31,28 +33,23 @@ public class AlgoIntersectPolynomialLine extends AlgoRootsPolynomial {
         super(cons, f, g);                      
     }
     
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoIntersectPolynomialLine";
     }
     
+    public int getRelatedModeID() {
+    	return EuclidianConstants.MODE_INTERSECT;
+    }
+    
     public GeoPoint [] getIntersectionPoints() {
         return super.getRootPoints();
     }
 
     public final String toString() {
-        StringBuffer sb = new StringBuffer();
         // Michael Borcherds 2008-03-31
         // simplified to allow better translation
-        sb.append(app.getPlain("IntersectionPointOfAB",input[0].getLabel(),input[1].getLabel()));
+        return app.getPlain("IntersectionPointOfAB",input[0].getLabel(),input[1].getLabel());
 
-        /*
-        sb.append(app.getPlain("IntersectionPointOf"));
-        sb.append(" ");
-        sb.append(input[0].getLabel());
-        sb.append(", ");
-        sb.append(input[1].getLabel());*/
-        
-        return sb.toString();
     }
 
 }
