@@ -22,11 +22,10 @@ import geogebra.util.GgbMat;
 
 public class AlgoInvert extends AlgoElement {
 
-	private static final long serialVersionUID = 1L;
 	private GeoList inputList; //input
     private GeoList outputList; //output	
 
-    AlgoInvert(Construction cons, String label, GeoList inputList) {
+    public AlgoInvert(Construction cons, String label, GeoList inputList) {
         super(cons);
         this.inputList = inputList;
                
@@ -37,61 +36,49 @@ public class AlgoInvert extends AlgoElement {
         outputList.setLabel(label);
     }
 
-    public String getClassName() {
+    @Override
+	public String getClassName() {
         return "AlgoInvert";
     }
 
-    protected void setInputOutput(){
+    @Override
+	protected void setInputOutput(){
         input = new GeoElement[1];
         input[0] = inputList;
 
-        output = new GeoElement[1];
-        output[0] = outputList;
+        super.setOutputLength(1);
+        super.setOutput(0, outputList);
         setDependencies(); // done by AlgoElement
     }
 
-    GeoList getResult() {
+    public GeoList getResult() {
         return outputList;
     }
 
-    protected final void compute() {
+    @Override
+	public final void compute() {
     	   		
-   		GgbMat matrix = new GgbMat(inputList);
+    	GgbMat matrix = new GgbMat(inputList);
    		
    		if (matrix.isUndefined() || !matrix.isSquare()) {
   			outputList.setUndefined();
 	   		return;   		
 	   	}
    		
-   		/*
-   		if (matrix.getRows() == 1) {
-   			
-   			double det = matrix.det();
-   			
-   			if (kernel.isZero(det)) {
-   	  			outputList.setUndefined();
-   		   		return;   		
-   		   	}
-   			
-   			// invert 1x1 matrix
-   			matrix = new GgbMatrix(1,1);
-   			matrix.set(1,1,1/det);
-   			
-   			outputList = matrix.getGeoList(outputList, cons);
-   			return;
-   		}*/
-   		
+   		// needed for eg  {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}} 
+   		boolean integers = matrix.hasOnlyIntegers();
+   		double det = Math.round(matrix.determinant());
    		matrix.inverseImmediate();
+   		if(integers){
+   			for(int i=0;i<inputList.size();i++)
+   				for(int j=0;j<inputList.size();j++){
+   					matrix.setEntry(i, j, Math.round(matrix.getEntry(i, j)*det)/det);
+   				}
+   		}
    		
-   		if (matrix.isUndefined()) {
-  			//outputList.setUndefined();
-	   		//return;   		
-	   	}
    		// Invert[{{1,2},{3,4}}]
    		
-   		outputList = matrix.getGeoList(outputList, cons);
-       
-    }
-        
+   		matrix.getGeoList(outputList, cons);      
+    }       
      
 }
