@@ -30,7 +30,6 @@ import java.util.ArrayList;
  */
 public class AlgoLaTeX extends AlgoElement {
 
-	private static final long serialVersionUID = 1L;
 	private GeoElement geo;  // input
 	private GeoBoolean substituteVars; 
 	private GeoBoolean showName; 
@@ -89,11 +88,11 @@ public class AlgoLaTeX extends AlgoElement {
 			input[i] = geos.get(i);
 
 
-        output = new GeoElement[1];        
-        output[0] = text;        
+        setOutputLength(1);        
+        setOutput(0,text);        
         setDependencies(); // done by AlgoElement
     }    
-    
+    private String oldFormat = "";
     public GeoText getGeoText() { return text; }
     
     // calc the current value of the arithmetic tree
@@ -111,7 +110,19 @@ public class AlgoLaTeX extends AlgoElement {
     		boolean substitute = substituteVars == null ? true : substituteVars.getBoolean();
     		boolean show = showName == null ? false : showName.getBoolean();
     		
-    		text.setTemporaryPrintAccuracy();
+    		String format = text.getPrintDecimals()+","+text.getPrintFigures();
+        	text.setTemporaryPrintAccuracy();
+        	if(!format.equals(oldFormat)){
+        		oldFormat = format;
+        		for(int i=0;i<input.length;i++)
+        			if(input[i].getParentAlgorithm()!=null &&
+        					input[i].isGeoText() && !input[i].isLabelSet()){
+        				input[i].setVisualStyle(text);
+        				input[i].getParentAlgorithm().update();
+        			}
+        	}
+    		
+    		
     		
     		//Application.debug(geo.getFormulaString(ExpressionNode.STRING_TYPE_LATEX, substitute ));
     		if(show){
