@@ -31,7 +31,7 @@ public class AlgoLetterToUnicode extends AlgoElement {
       num.setLabel(label);
     }   
   
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoLetterToUnicode";
     }
     
