@@ -14,6 +14,7 @@ package geogebra.kernel;
 
 
 import geogebra.euclidian.EuclidianConstants;
+import geogebra.kernel.implicit.GeoImplicitPoly;
 import geogebra.main.Application;
 
 import java.awt.geom.Point2D;
@@ -314,7 +315,7 @@ public class AlgoLocus extends AlgoElement implements EuclidianViewCE {
 
     // compute locus line
     final protected void compute() {
-    	if (!movingPoint.isDefined() || macroCons == null || !path.toGeoElement().isDefined()) {
+    	if (!movingPoint.isDefined() || macroCons == null || !isPathIterable(path.toGeoElement())) {
     		locus.setUndefined();
     		return;
     	}
@@ -505,6 +506,12 @@ public class AlgoLocus extends AlgoElement implements EuclidianViewCE {
     	//Application.debug("LOCUS COMPUTE updateCascades: " + countUpdates + ", cache used: " + useCache);
     }
     
+    private static boolean isPathIterable(GeoElement geoElement) { 
+    	if(geoElement.isGeoImplicitPoly()) 
+    		return ((GeoImplicitPoly)geoElement).isOnScreen(); 
+    	return geoElement.isDefined(); 
+    }
+    
     /**
      * Calls Pcopy.updateCascade() to compute Qcopy. For non-continous constructions
      * caching of previous paramater positions is used. 
