@@ -15,6 +15,7 @@ package geogebra.kernel;
 import geogebra.kernel.arithmetic.Function;
 import geogebra.kernel.arithmetic.PolyFunction;
 import geogebra.kernel.roots.RealRootFunction;
+import geogebra.main.Application;
 
 import java.util.Arrays;
 import java.util.Iterator;
@@ -35,16 +36,18 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
 	private static final int ROOTS = 0;
     private static final int INTERSECT_POLYNOMIALS = 1;
     private static final int INTERSECT_POLY_LINE = 2;
+    private static final int MULTIPLE_ROOTS = 3;
     private int mode;
 
     GeoFunction f, g; // input  (g for intersection of polynomials)   
     private GeoLine line; // input (for intersection of polynomial with line)
-    private GeoPoint[] rootPoints; // output, inherited from AlgoIntersect 
+    protected GeoPoint[] rootPoints; // output, inherited from AlgoIntersect 
     //private int rootPointsLength;
 
     private String[] labels;
-    private boolean initLabels, setLabels;
-    private EquationSolver eqnSolver;
+    private boolean initLabels;
+	protected boolean setLabels;
+    protected EquationSolver eqnSolver;
     double[] curRoots = new double[30]; // current roots
     int curRealRoots;
 
@@ -78,60 +81,118 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
     }
 
     private AlgoRootsPolynomial(
-        Construction cons,
-        String[] labels,
-        boolean setLabels,
-        GeoFunction f,
-        GeoFunction g,
-        GeoLine l) {
-        super(cons);
-        this.f = f;
-        this.g = g;
-        line = l;
+            Construction cons,
+            String[] labels,
+            boolean setLabels,
+            GeoFunction f,
+            GeoFunction g,
+            GeoLine l) {
+            super(cons);
+            this.f = f;
+            this.g = g;
+            line = l;
 
-        tempPoint = new GeoPoint(cons);
-        
-        // set mode
-        if (g != null)
-            mode = INTERSECT_POLYNOMIALS;
-        else if (l != null)   {
-            mode = INTERSECT_POLY_LINE;           
-        } else
+            tempPoint = new GeoPoint(cons);
+            
+            // set mode
+            if (g != null)
+                mode = INTERSECT_POLYNOMIALS;
+            else if (l != null)   {
+                mode = INTERSECT_POLY_LINE;           
+            } else
+                mode = ROOTS;
+
+            if (mode != ROOTS) { // for intersection of f and g resp. line
+                diffFunction = new Function(kernel);
+            }
+            this.labels = labels;
+            this.setLabels = setLabels; // should lables be used?
+
+            eqnSolver = cons.getEquationSolver();
+
+            //  make sure root points is not null
+            int number = labels == null ? 1 : Math.max(1, labels.length);
+            rootPoints = new GeoPoint[0];
+            initRootPoints(number);
+            initLabels = true;  
+                    
+            setInputOutput(); // for AlgoElement    
+            compute();        
+            
+            // show at least one root point in algebra view
+            // this is enforced here:
+            if (!rootPoints[0].isDefined()) {
+            	rootPoints[0].setCoords(0,0,1);
+            	rootPoints[0].update();
+            	rootPoints[0].setUndefined();
+            	rootPoints[0].update();
+            }
+        }
+
+    public AlgoRootsPolynomial(            
+            GeoFunction f
+            ) {
+            super(f.cons);
+            this.f = f;
+            
+
+            tempPoint = new GeoPoint(cons);
+            
+            // set mode
+                mode = MULTIPLE_ROOTS;
+
+            
+            eqnSolver = cons.getEquationSolver();
+
+            //  make sure root points is not null
+            int number = labels == null ? 1 : Math.max(1, labels.length);
+            rootPoints = new GeoPoint[0];
+            initRootPoints(number);
+            initLabels = true;  
+                    
+            setInputOutput(); // for AlgoElement    
+            compute();        
+            
+            // show at least one root point in algebra view
+            // this is enforced here:
+            if (!rootPoints[0].isDefined()) {
+            	rootPoints[0].setCoords(0,0,1);
+            	rootPoints[0].update();
+            	rootPoints[0].setUndefined();
+            	rootPoints[0].update();
+            }
+        }
+    public AlgoRootsPolynomial(
+            Construction cons,
+            GeoFunction f) {
+            super(cons);
+            this.f = f;
+
+            tempPoint = new GeoPoint(cons);
+            
+            // set mode
             mode = ROOTS;
 
-        if (mode != ROOTS) { // for intersection of f and g resp. line
-            diffFunction = new Function(kernel);
-        }
-        this.labels = labels;
-        this.setLabels = setLabels; // should lables be used?
+            eqnSolver = cons.getEquationSolver();
 
-        eqnSolver = cons.getEquationSolver();
+            //  make sure root points is not null
+            int number = 1;
+            rootPoints = new GeoPoint[0];
+            initRootPoints(number);
+            initLabels = true;  
+                    
+            setInputOutput(); // for AlgoElement    
+            compute();        
+            
 
-        //  make sure root points is not null
-        int number = labels == null ? 1 : Math.max(1, labels.length);
-        rootPoints = new GeoPoint[0];
-        initRootPoints(number);
-        initLabels = true;  
-                
-        setInputOutput(); // for AlgoElement    
-        compute();        
-        
-        // show at least one root point in algebra view
-        // this is enforced here:
-        if (!rootPoints[0].isDefined()) {
-        	rootPoints[0].setCoords(0,0,1);
-        	rootPoints[0].update();
-        	rootPoints[0].setUndefined();
-        	rootPoints[0].update();
         }
-    }
 
     /**
      * The given labels will be used for the resulting points.   
      */
     public void setLabels(String[] labels) {
         this.labels = labels;
-        setLabels = true;
+        setLabels = !cons.isSuppressLabelsActive();
 
         // make sure that there are at least as many
         // points as labels
@@ -141,13 +202,14 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
         update();
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoRootsPolynomial";
     }
 
     // for AlgoElement
     protected void setInputOutput() {
         switch (mode) {
+        	case MULTIPLE_ROOTS:
             case ROOTS : // roots of f
                 input = new GeoElement[1];
                 input[0] = f;
@@ -175,21 +237,30 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
         return rootPoints;
     }
 
-    GeoPoint[] getIntersectionPoints() {
+    protected GeoPoint[] getIntersectionPoints() {
         return rootPoints;
     }
 
-    GeoPoint[] getLastDefinedIntersectionPoints() {
+    protected GeoPoint[] getLastDefinedIntersectionPoints() {
         return null;
     }       
 
+    
     protected void compute() {
         switch (mode) {
             case ROOTS :
                 // roots of f
                 computeRoots();
                 break;
-
+            case MULTIPLE_ROOTS:
+            	if (f.isDefined()) {
+                    Function fun = f.getFunction();
+                    // get polynomial factors anc calc roots
+                    calcRootsMultiple(fun, 0);
+                } else {
+                    curRealRoots = 0;
+                }
+            	break;
             case INTERSECT_POLYNOMIALS :
                 //  intersection of f and g
                 computePolynomialIntersection();
@@ -244,7 +315,7 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
             yValFunction = f.getFunction();
 
             // check for vertical line a*x + c = 0: intersection at x=-c/a 
-            if (kernel.isZero(line.y)) {
+            if (Kernel.isZero(line.y)) {
                 double x = -line.z / line.x;
                 curRoots[0] = x;
                 curRealRoots = 1;
@@ -254,17 +325,19 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
                 //  get difference f - line
                 Function.difference(f.getFunction(), line, diffFunction);               
                 calcRoots(diffFunction, 0);
-                
-                // check if the intersection points really are on the line
-                // this is important for segments and rays
-                for (int i = 0; i < curRealRoots; i++) {
-                	tempPoint.setCoords(curRoots[i], f.evaluate(curRoots[i]), 1.0);
-                	if (! line.isIntersectionPointIncident(tempPoint, Kernel.MIN_PRECISION) ){
-                		removeRoot(i);
-                		i--;
-                	}                	
-                }             
             }
+            
+            // check if the intersection points really are on the line
+            // this is important for segments and rays
+            //Zbynek Konecny 2010-02-12 -- following must be done for both vertical and standard
+            for (int i = 0; i < curRealRoots; i++) {
+            	tempPoint.setCoords(curRoots[i], f.evaluate(curRoots[i]), 1.0);
+            	if (! line.isIntersectionPointIncident(tempPoint, Kernel.MIN_PRECISION) ){
+            		removeRoot(i);
+            		i--;
+            	}                	
+            }
+            //end Zbynek Konecny
         } else {
             curRealRoots = 0;
         }
@@ -274,66 +347,11 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
      * Calculates the roots of the given function resp. its derivative,
      * stores them in curRoots and
      * sets curRealRoots to the number of real roots found.
-     * @param derivDegree: degree of derivative to compute roots from
+     * @param derivDegree degree of derivative to compute roots from
      */
-    final void calcRoots(Function fun, int derivDegree) {  
-    	LinkedList factorList;    	
-    	PolyFunction derivPoly = null;// only needed for derivatives
-		RealRootFunction evalFunction = null; // needed to remove wrong extrema and inflection points 
+    public final void calcRoots(Function fun, int derivDegree) {  
+    	RealRootFunction evalFunction = calcRootsMultiple(fun,derivDegree);
     	
-    	// get polynomial factors for this function
-    	if (derivDegree > 0) {
-    		// try to get the factors of the symbolic derivative
-    		factorList = fun.getSymbolicPolynomialDerivativeFactors(derivDegree, true);
-    		
-    		// if this didn't work take the derivative of the numeric
-    		// expansion of this function
-    		if (factorList == null) {
-    			derivPoly = fun.getNumericPolynomialDerivative(derivDegree);  	
-    			evalFunction = derivPoly;
-    		} else {
-    			evalFunction = fun.getDerivative(derivDegree);
-    		}
-    	} else {
-    		// standard case
-    		factorList = fun.getPolynomialFactors(true);    		
-    	}
-    	
-        double[] roots;
-        int realRoots;
-        curRealRoots = 0; // reset curRoots index 
-        
-    	// we got a list of polynomial factors
-        if (factorList != null) { 
-        	 // compute the roots of every single factor              
-            Iterator it = factorList.iterator();
-            while (it.hasNext()) {
-            	PolyFunction polyFun = (PolyFunction) it.next();                       
-            	
-                //  update the current coefficients of polyFun
-            	// (this is needed for SymbolicPolyFunction objects)
-                if (!polyFun.updateCoeffValues()) {
-                    //  current coefficients are not defined
-                    curRealRoots = 0;
-                    return;
-                }
-
-                // now let's compute the roots of this factor           
-                //  compute all roots of polynomial polyFun
-                roots = polyFun.getCoeffsCopy();   
-                realRoots = eqnSolver.polynomialRoots(roots);  
-                addToCurrentRoots(roots, realRoots);                            
-            }
-        }         
-        // we've got one factor, i.e. derivPoly
-        else if (derivPoly != null) {          
-            //  compute all roots of derivPoly
-            roots = derivPoly.getCoeffsCopy();   
-            realRoots = eqnSolver.polynomialRoots(roots);                           
-            addToCurrentRoots(roots, realRoots);
-        } else
-			return;                      
-
         if (curRealRoots > 1) {
             // sort roots and eliminate duplicate ones
             Arrays.sort(curRoots, 0, curRealRoots);
@@ -359,7 +377,70 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
         }
     }
     
-    // remove roots where the sign of the function's values did not change    
+    public RealRootFunction calcRootsMultiple(Function fun, int derivDegree) {
+    	LinkedList factorList;    	
+    	PolyFunction derivPoly = null;// only needed for derivatives
+		RealRootFunction evalFunction = null; // needed to remove wrong extrema and inflection points 
+    	
+    	// get polynomial factors for this function
+    	if (derivDegree > 0) {
+    		// try to get the factors of the symbolic derivative
+    		factorList = fun.getSymbolicPolynomialDerivativeFactors(derivDegree, true);
+    		
+    		// if this didn't work take the derivative of the numeric
+    		// expansion of this function
+    		if (factorList == null) {
+    			derivPoly = fun.getNumericPolynomialDerivative(derivDegree);  	
+    			evalFunction = derivPoly;
+    		} else {
+    			evalFunction = fun.getDerivative(derivDegree);
+    		}
+    	} else {
+    		// standard case
+    		factorList = fun.getPolynomialFactors(false);    		
+    	}
+    	
+        double[] roots;
+        int realRoots;
+        curRealRoots = 0; // reset curRoots index 
+        
+    	// we got a list of polynomial factors
+        if (factorList != null) { 
+        	 // compute the roots of every single factor              
+            Iterator it = factorList.iterator();
+            while (it.hasNext()) {
+            	PolyFunction polyFun = (PolyFunction) it.next();                       
+            	
+                //  update the current coefficients of polyFun
+            	// (this is needed for SymbolicPolyFunction objects)
+                if (!polyFun.updateCoeffValues()) {
+                    //  current coefficients are not defined
+                    curRealRoots = 0;
+                    return null;
+                }
+
+                // now let's compute the roots of this factor           
+                //  compute all roots of polynomial polyFun
+                roots = polyFun.getCoeffsCopy();   
+                realRoots = eqnSolver.polynomialRoots(roots,true);  
+                addToCurrentRoots(roots, realRoots);                            
+            }
+        }         
+        // we've got one factor, i.e. derivPoly
+        else if (derivPoly != null) {          
+            //  compute all roots of derivPoly
+            roots = derivPoly.getCoeffsCopy();   
+            realRoots = eqnSolver.polynomialRoots(roots,false);                           
+            addToCurrentRoots(roots, realRoots);
+        } else
+			return null;      
+        if(curRealRoots > 1)
+        	Arrays.sort(curRoots, 0, curRealRoots);
+        return evalFunction;
+		
+	}
+
+	// remove roots where the sign of the function's values did not change    
     private void ensureSignChanged(RealRootFunction f) {      	    	
         double left, right, leftEval, rightEval;
         boolean signUnChanged;
@@ -408,7 +489,7 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
         curRealRoots += number;
     }
 
-    final void removeRoot(int pos) {    
+    final private void removeRoot(int pos) {    
     	for (int i = pos+1; i < curRealRoots; i++) {
     		curRoots[i-1] = curRoots[i];
     	}    
@@ -416,7 +497,7 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
     }
 
     // roots array and number of roots
-    final void setRootPoints(double[] roots, int number) {
+    protected final void setRootPoints(double[] roots, int number) {
         initRootPoints(number);
 
         // now set the new values of the roots
@@ -448,7 +529,7 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
     }
 
     // number is the number of current roots
-    private void updateLabels(int number) {  
+    protected void updateLabels(int number) {  
     	if (initLabels) {
     		GeoElement.setLabels(labels, rootPoints);
     		initLabels = false;
@@ -487,7 +568,7 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
         super.remove();
     }
 
-    private void initRootPoints(int number) {
+    protected void initRootPoints(int number) {
         // make sure that there are enough points   
         if (rootPoints.length < number) {
             GeoPoint[] temp = new GeoPoint[number];
@@ -519,12 +600,9 @@ public class AlgoRootsPolynomial extends AlgoIntersect {
     }
 
     public String toString() {
-        StringBuffer sb = new StringBuffer();
         // Michael Borcherds 2008-03-30
         // simplified to allow better Chinese translation
-        sb.append(app.getPlain("RootOfA",f.getLabel()));
-        
-        return sb.toString();
+    	return app.getPlain("RootOfA",f.getLabel());
     }
 
 }
