@@ -26,13 +26,33 @@ public class AlgoSumLower extends AlgoFunctionAreaSums {
 	 */
 	private static final long serialVersionUID = 1L;
 
+	/**
+	 * Creates lower sum
+	 * @param cons construction
+	 * @param label label
+	 * @param f function
+	 * @param a lower bound
+	 * @param b upper bound
+	 * @param n number of columns
+	 */
 	public AlgoSumLower(Construction cons, String label, GeoFunction f, 
 								   NumberValue a, NumberValue b, NumberValue n) {
 		super(cons, label, f, a, b, n, AlgoFunctionAreaSums.TYPE_LOWERSUM);		
-		cons.registerEuclidianViewAlgo(this);
+		cons.registerEuclidianViewCE(this);
 	}
 	
-	protected String getClassName() {
+	private AlgoSumLower( 
+			   NumberValue a, NumberValue b, NumberValue n,double[]vals,double[]borders) {
+		super(a, b, n, AlgoFunctionAreaSums.TYPE_LOWERSUM,vals,borders);		
+		cons.registerEuclidianViewCE(this);
+	}
+	
+	public AlgoSumLower copy() {
+		return new AlgoSumLower((NumberValue)this.getA().deepCopy(kernel),
+				(NumberValue)this.getB().deepCopy(kernel),(NumberValue)this.getN().copy().evaluate(),
+				getValues().clone(),getLeftBorder().clone());
+	}
+	public String getClassName() {
 		return "AlgoSumLower";
 	}
 	
