@@ -115,7 +115,7 @@ public class AlgoText extends AlgoElement {
 	}    
 
 	public GeoText getGeoText() { return text; }
-
+	private String oldFormat = "";
 	protected final void compute() {    
 		
 		// undefined text
@@ -128,7 +128,18 @@ public class AlgoText extends AlgoElement {
 			return;
 		}
 		
-		text.setTemporaryPrintAccuracy();
+		String format = text.getPrintDecimals()+","+text.getPrintFigures();
+    	text.setTemporaryPrintAccuracy();
+    	if(!format.equals(oldFormat)){
+    		oldFormat = format;
+    		for(int i=0;i<input.length;i++)
+    			if(input[i].getParentAlgorithm()!=null &&
+    					input[i].isGeoText() && !input[i].isLabelSet()){
+    			input[i].setVisualStyle(text);
+    			input[i].getParentAlgorithm().update();
+    		}
+    	}
+    	
 		
 		// standard case: set text
 		boolean bool = substituteVars == null ? true : substituteVars.getBoolean();
