@@ -19,15 +19,6 @@ import java.util.TreeSet;
 public abstract class ConstructionElement 
 implements Comparable<ConstructionElement> {
 	
-	// Added for Intergeo File Format (Yves Kreis) -->
-	// writes the <elements> part
-    public static final int ELEMENTS = 0;
-	// writes the <constraints> part
-    public static final int CONSTRAINTS = 1;
-    // writes the <display> part
-    public static final int DISPLAY = 2;
-	// <-- Added for Intergeo File Format (Yves Kreis)
-    
 	protected transient Construction cons; // parent construction of this element
 	protected transient Kernel kernel;      // parent kernel of this element
 	protected transient Application app;  // parent application of this element
@@ -126,13 +117,6 @@ implements Comparable<ConstructionElement> {
 	 */
     public abstract void getXML(StringBuilder sb);
     
-	/**
-	 * Returns I2G representation of this object.
-	 * Intergeo File Format. (Yves Kreis)
-	 * @return xml String
-	 */
-    public abstract void getI2G(StringBuilder sb, int mode);
-        
 	/**
 	  * Removes this object from the current construction.	 
 	  */
