@@ -15,9 +15,12 @@ the Free Software Foundation.
  */
 package geogebra.kernel;
 
+import geogebra.Matrix.CoordNearest;
+import geogebra.Matrix.Coords;
 import geogebra.kernel.arithmetic.MyDouble;
 import geogebra.kernel.arithmetic.NumberValue;
 import geogebra.kernel.integration.EllipticArcLength;
+import geogebra.kernel.kernelND.GeoPointND;
 
 
 /**
@@ -32,7 +35,9 @@ implements LimitedPath, NumberValue, LineProperties {
 	 * 
 	 */
 	private static final long serialVersionUID = 1L;
+	/** conic arc*/
 	public static final int CONIC_PART_ARC = 1;
+	/** conic sector */
 	public static final int CONIC_PART_SECTOR = 2;
 		
 	// parameters (e.g. angles) for arc
@@ -47,18 +52,26 @@ implements LimitedPath, NumberValue, LineProperties {
 	private boolean allowOutlyingIntersections = false;
 	private boolean keepTypeOnGeometricTransform = true;
 			
-	// GeoCirclePart is constructed by AlgoCirclePart... 
+	/**
+	 * GeoCirclePart is constructed by AlgoCirclePart... 
+	 * @param c
+	 * @param type CONIC_PART_ARC or CONIC_PART_SECTOR
+	 */
 	public GeoConicPart(Construction c, int type) {
 		super(c);				
 		conic_part_type = type;			
 	}
 	
+	/**
+	 * Copy constructor
+	 * @param conic
+	 */
 	public GeoConicPart(GeoConicPart conic) {
 		this(conic.cons, conic.getConicPartType());
 		set(conic);
 	}
 	
-	protected String getClassName() {	
+	public String getClassName() {	
 		return "GeoConicPart";
  	}
 	
@@ -114,23 +127,39 @@ implements LimitedPath, NumberValue, LineProperties {
 			allowOutlyingIntersections = cp.allowOutlyingIntersections;
 		}
 	}
-	
+	/**
+	 * Sector or arc
+	 * @return CONIC_PART_ARC or CONIC_PART_SECTOR
+	 */
 	final public int getConicPartType() {
 		return conic_part_type;
 	}
 	
+	/**
+	 * @return start parameter
+	 */
 	final public double getParameterStart() {
 		return paramStart;
 	}
 	
+	
+	/**
+	 * @return end parameter
+	 */
 	final public double getParameterEnd() {
 		return paramEnd;
 	}
 	
+	/**
+	 * @return end parameter - start parameter
+	 */
 	final public double getParameterExtent() {
 		return paramExtent;
 	}
 	
+	/**
+	 * @return start parameter
+	 */
 	final public boolean positiveOrientation() {
 		return posOrientation;
 	}	
@@ -148,8 +177,8 @@ implements LimitedPath, NumberValue, LineProperties {
 		return 
 			posOrientation == c.posOrientation &&
 			conic_part_type == c.conic_part_type &&		
-			kernel.isEqual(paramStart, c.paramStart) &&
-			kernel.isEqual(paramEnd, c.paramEnd) &&
+			Kernel.isEqual(paramStart, c.paramStart) &&
+			Kernel.isEqual(paramEnd, c.paramEnd) &&
 			super.isEqual(c);			 
 	}
 	
@@ -158,6 +187,9 @@ implements LimitedPath, NumberValue, LineProperties {
 	 * For type CONIC_PART_ARC the value is
 	 * the length, for CONIC_PART_SECTOR the value is an area. 
 	 * This method should only be called by the parent algorithm 
+	 * @param a 
+	 * @param b 
+	 * @param positiveOrientation 
 	 */
 	final public void setParameters(double a, double b, boolean positiveOrientation) {
 		value_defined = super.isDefined();
@@ -257,10 +289,20 @@ implements LimitedPath, NumberValue, LineProperties {
 		value_defined = false;
 	}
 	
+	/**
+	 * Returns arc length
+	 * @return arc length
+	 */
 	final public double getValue() {
+		if(!value_defined)
+			return Double.NaN;
 		return value;
 	}
 	
+	/**
+	 * Returns the area
+	 * @return area
+	 */
 	final public double getArea() {
 		return area;
 	}
@@ -272,10 +314,12 @@ implements LimitedPath, NumberValue, LineProperties {
 		sbToString.append(toValueString());			     
         return sbToString.toString();
     }
-	private StringBuffer sbToString = new StringBuffer(50);
+	private StringBuilder sbToString = new StringBuilder(50);
 	
 	final public String toValueString() {
-		return kernel.format(value);	
+		if(value_defined)
+			return kernel.format(value);
+		return kernel.format(Double.NaN);
 	} 
 	
 	public boolean allowOutlyingIntersections() {
@@ -308,7 +352,10 @@ implements LimitedPath, NumberValue, LineProperties {
 	/** 
 	 * states wheter P lies on this conic part or not 
 	 */
-	public boolean isOnPath(GeoPoint P, double eps) {
+	public boolean isOnPath(GeoPointND PI, double eps) {
+		
+		GeoPoint P = (GeoPoint) PI;
+		
 		if (P.getPath() == this)
 			return true;
 		
@@ -328,7 +375,7 @@ implements LimitedPath, NumberValue, LineProperties {
 		switch (type) {
 			case CONIC_CIRCLE:
 			case CONIC_ELLIPSE:
-				setEllipseParameter(P);
+				setEllipseParameter(P.getCoordsInD2(getCoordSys()),P.getPathParameter());
 			break;
 			
 			// degenerate case: two rays or one segment
@@ -376,38 +423,44 @@ implements LimitedPath, NumberValue, LineProperties {
 		return false;
 	}
 	
-	public void pointChanged(GeoPoint P) {
-		PathParameter pp = P.getPathParameter(); 
-		pp.pathType = type;
+	protected void pointChanged(Coords P, PathParameter pp) {
+		
+		
+		pp.setPathType(type);
 
 		switch (type) {
 			case CONIC_CIRCLE:
 			case CONIC_ELLIPSE:
-				setEllipseParameter(P);
-				clipEllipseParameter(P);		
+				setEllipseParameter(P,pp);
+				clipEllipseParameter(P,pp);		
 			break;
 			
 			// degenerate case: two rays or one segment
 			case CONIC_PARALLEL_LINES: 		
 				if (posOrientation) {
 					// segment
-					lines[0].pointChanged(P);
+					lines[0].doPointChanged(P,pp);
 					
 					// make sure we don't get outside [0,1]
 					if (pp.t < 0) {
 						pp.t = 0;
-						pathChanged(P);
+						pathChanged(P,pp);
 					}
 					else if (pp.t > 1) {
 						pp.t = 1;
-						pathChanged(P);
+						pathChanged(P,pp);
 					}
 				} else {
 					// two rays
 					// we take point at infinty
+					/*
 					P.x = -lines[0].y;
 					P.y = lines[0].x;
 					P.z = 0.0;
+					 */
+					P.setX(-lines[0].y);
+					P.setY(lines[0].x);
+					P.setZ(0);
 				}
 			break;
 
@@ -417,12 +470,11 @@ implements LimitedPath, NumberValue, LineProperties {
 		}	
 	}
 	
-	private void setEllipseParameter(GeoPoint P) {
+	private void setEllipseParameter(Coords P, PathParameter pp) {
 		// let GeoConic do the work
-		super.pointChanged(P);		
+		super.pointChanged(P,pp);		
 			
 		// now transform parameter t from [paramStart, paramEnd] to [0, 1]
-		PathParameter pp = P.getPathParameter();
 		if (pp.t < 0)
 			pp.t += Kernel.PI_2;
 		double t = pp.t - paramStart;
@@ -431,7 +483,7 @@ implements LimitedPath, NumberValue, LineProperties {
 		pp.t = t / paramExtent;	
 	}
 	
-	private void clipEllipseParameter(GeoPoint P) {
+	private void clipEllipseParameter(Coords P, PathParameter pp) {
 		// make sure we don't get outside [0,1]
 		// the values of the path parameter are now
 		// between [0, 2pi/paramExtent]
@@ -439,30 +491,32 @@ implements LimitedPath, NumberValue, LineProperties {
 		// handle [1, 2pi/paramExtent]:
 		// take 0 for parameter > (1 + 2pi/paramExtent)/2
 		// else take 1
-		PathParameter pp = P.getPathParameter();
 		if (pp.t > 0.5 + Math.PI/paramExtent) {
 			if (posOrientation)
 				pp.t = 0;
 			else
 				pp.t = 1;
-			pathChanged(P);
+			pathChanged(P,pp);
 		}
 		else if (pp.t > 1) {
 			if (posOrientation)
 				pp.t = 1;
 			else
 				pp.t = 0;
-			pathChanged(P);
+			pathChanged(P,pp);
 		}
 		else if (!posOrientation) {
 			pp.t = 1.0 - pp.t;
 		}	
 	}
 	
-	public void pathChanged(GeoPoint P) {			
-		PathParameter pp = P.getPathParameter();						
-		if (pp.pathType != type || Double.isNaN(pp.t)) {		
-			pointChanged(P);
+	protected void pathChanged(Coords P, PathParameter pp) {
+		if(!value_defined){
+			P.setX(Double.NaN);
+			return;
+		}
+		if (pp.getPathType() != type || Double.isNaN(pp.t)) {		
+			pointChanged(P,pp);
 			return;
 		}
 
@@ -479,8 +533,8 @@ implements LimitedPath, NumberValue, LineProperties {
 			case CONIC_ELLIPSE:	
 				// if type of path changed (other conic) then we
 				// have to recalc the parameter with pointChanged()
-				if (pp.pathType != type) {					
-					pointChanged(P);
+				if (pp.getPathType() != type) {					
+					pointChanged(P,pp);
 					return;
 				}		
 				
@@ -489,29 +543,29 @@ implements LimitedPath, NumberValue, LineProperties {
 						pp.t:
 						1.0 - pp.t;
 				double angle = paramStart + t * paramExtent;
-				P.x = halfAxes[0] * Math.cos(angle);	
-				P.y = halfAxes[1] * Math.sin(angle);
-				P.z = 1.0;
-				
-				//	transform to real world coord system
-				coordsEVtoRW(P);								
+
+				P.setX(halfAxes[0] * Math.cos(angle));
+				P.setY(halfAxes[1] * Math.sin(angle));
+				P.setZ(1);
+				coordsEVtoRW(P);							
 			break;	
 			
 			case CONIC_PARALLEL_LINES:
 				if (posOrientation) { // segment
 					// if type of path changed (other conic) then we
 					// have to recalc the parameter with pointChanged()
-					if (pp.pathType != type) {					
-						pointChanged(P);						
+					if (pp.getPathType() != type) {					
+						pointChanged(P,pp);						
 					}	else {
-						lines[0].pathChanged(P);
+						lines[0].pathChanged(P,pp);
 					}
 				} else {
 					// two rays
 					// we take point at infinty
-					P.x = -lines[0].y;
-					P.y = lines[0].x;
-					P.z = 0.0;
+					P.setX(-lines[0].y);
+					P.setY(lines[0].x);
+					P.setZ(0);
+
 				}
 			break;
 
@@ -523,7 +577,7 @@ implements LimitedPath, NumberValue, LineProperties {
 	/**
 	 * Returns the smallest possible parameter value for this
 	 * path (may be Double.NEGATIVE_INFINITY)
-	 * @return
+	 * 
 	 */
 	public double getMinParameter() {
 		switch (type) {
@@ -548,7 +602,7 @@ implements LimitedPath, NumberValue, LineProperties {
 	/**
 	 * Returns the largest possible parameter value for this
 	 * path (may be Double.POSITIVE_INFINITY)
-	 * @return
+	 * 
 	 */
 	public double getMaxParameter() {
 		switch (type) {
@@ -578,9 +632,8 @@ implements LimitedPath, NumberValue, LineProperties {
 	/**
      * returns all class-specific xml tags for saveXML
      */
-    protected String getXMLtags() {
-        StringBuffer sb = new StringBuffer();
-        sb.append(super.getXMLtags());
+	protected void getXMLtags(StringBuilder sb) {
+        super.getXMLtags(sb);
 		
         // allowOutlyingIntersections
         sb.append("\t<outlyingIntersections val=\"");
@@ -591,8 +644,7 @@ implements LimitedPath, NumberValue, LineProperties {
         sb.append("\t<keepTypeOnTransform val=\"");
         sb.append(keepTypeOnGeometricTransform);
         sb.append("\"/>\n");              
-        
-        return sb.toString();   
+         
     }
 
 	 /**
@@ -615,10 +667,7 @@ implements LimitedPath, NumberValue, LineProperties {
 	}
 
 	
-	public GeoElement [] createTransformedObject(int type, String label, GeoPoint Q, 
-			GeoLine l, GeoVector vec, NumberValue n) {	
-
-		AlgoElement algoParent = null;		
+	public GeoElement [] createTransformedObject(Transform t,String label) {				
 		if (keepTypeOnGeometricTransform) {
 			algoParent = getParentAlgorithm();			
 		}	
@@ -635,14 +684,13 @@ implements LimitedPath, NumberValue, LineProperties {
 	        GeoConic circle = algoCircle.getCircle();
 	        
 	        // transform points and circle
-			points = kernel.transformPoints(type, points, Q, l, vec, n);			
-			GeoConic transformedCircle = kernel.getTransformedConic(type,  circle, Q, l, vec, n);	
+			points = t.transformPoints(points);			
+			GeoConic transformedCircle = t.getTransformedConic(circle);	
 			cons.removeFromConstructionList(transformedCircle.getParentAlgorithm());			
 										
 			// create a new arc from the transformed circle using startPoint and endPoint
 			AlgoConicPartConicPoints algoResult = new AlgoConicPartConicPoints(cons, label, transformedCircle, points[1], points[2], conic_part_type);			
 			GeoConicPart conicPart = algoResult.getConicPart();
-			
 			conicPart.setVisualStyleForTransformations(this);
 			GeoElement [] geos = {conicPart, points[0], points[2], points[1]};
 						
@@ -652,7 +700,7 @@ implements LimitedPath, NumberValue, LineProperties {
 		else if (algoParent instanceof AlgoConicPartCircumcircle) {
 			GeoPoint [] points ={ (GeoPoint) algoParent.input[0], 
 					 (GeoPoint) algoParent.input[1],  (GeoPoint) algoParent.input[2]};			
-			points = kernel.transformPoints(type, points, Q, l, vec, n);
+			points = t.transformPoints(points);
 			
 			AlgoConicPartCircumcircle algo = new AlgoConicPartCircumcircle(cons, label, points[0], points[1], points[2], conic_part_type);
 			GeoConicPart res = algo.getConicPart();
@@ -665,7 +713,7 @@ implements LimitedPath, NumberValue, LineProperties {
 		else if (algoParent instanceof AlgoConicPartConicParameters) {
 			AlgoConicPartConicParameters algo = (AlgoConicPartConicParameters) algoParent;			
 						
-			GeoConic transformedConic = kernel.getTransformedConic(type,  algo.conic, Q, l, vec, n);	
+			GeoConic transformedConic = t.getTransformedConic(algo.conic);	
 			cons.removeFromConstructionList(transformedConic.getParentAlgorithm());			
 										
 			algo = new AlgoConicPartConicParameters(cons, label, transformedConic, algo.startParam, algo.endParam, conic_part_type);			
@@ -678,10 +726,10 @@ implements LimitedPath, NumberValue, LineProperties {
 		else if (algoParent instanceof AlgoConicPartConicPoints) {
 			AlgoConicPartConicPoints algo = (AlgoConicPartConicPoints) algoParent;			
 			GeoPoint [] points ={ algo.getStartPoint(), algo.getEndPoint() };			
-			points = kernel.transformPoints(type, points, Q, l, vec, n);									
+			points = t.transformPoints(points);									
 			GeoConic orgConic = algo.getConic();
 			
-			GeoConic transformedConic = kernel.getTransformedConic(type, orgConic, Q, l, vec, n);	
+			GeoConic transformedConic = t.getTransformedConic(orgConic);	
 			cons.removeFromConstructionList(transformedConic.getParentAlgorithm());		
 		
 			algo = new AlgoConicPartConicPoints(cons, label, transformedConic, points[0], points[1], conic_part_type);			
@@ -692,26 +740,37 @@ implements LimitedPath, NumberValue, LineProperties {
 		}
 		
 		else if (algoParent instanceof AlgoSemicircle) {			
-			AlgoSemicircle algo = (AlgoSemicircle) algoParent;			
-			GeoPoint [] points ={ algo.getA(), algo.getB() };			
-			points = kernel.transformPoints(type, points, Q, l, vec, n);
+			AlgoElement algo =  algoParent;			
+			GeoPoint [] points ={ ((AlgoSemicircle)algo).getA(), ((AlgoSemicircle)algo).getB() };			
+			points = t.transformPoints(points);
 			
 			GeoConic semCirc;
-			if (type == Kernel.TRANSFORM_MIRROR_AT_LINE) {
+			if (t instanceof TransformMirror && t.changesOrientation()) {
 				semCirc = kernel.Semicircle(label, points[1], points[0]);
-			} else {
+			} else if(t.isSimilar()) {
 				semCirc = kernel.Semicircle(label, points[0], points[1]);
+			} else {
+				
+				GeoConic orgConic = ((AlgoSemicircle)algo).getConic();
+				GeoConic transformedConic = t.getTransformedConic(orgConic);
+				cons.removeFromConstructionList(transformedConic.getParentAlgorithm());
+				if(t.changesOrientation()){
+				algo = new AlgoConicPartConicPoints(cons, label, transformedConic, points[0], points[1], conic_part_type);
+				}else
+					algo = new AlgoConicPartConicPoints(cons, label, transformedConic, points[1], points[0], conic_part_type);
+				GeoConicPart conicPart = ((AlgoConicPartConicPoints)algo).getConicPart();
+				conicPart.setVisualStyleForTransformations(this);
+				GeoElement [] geos = {conicPart, points[0], points[1]};
+				return geos;				
 			}
-			
 			semCirc.setVisualStyleForTransformations(this);
-			
 			GeoElement [] geos = {semCirc, points[0], points[1]};
 			return geos;
 		}
 		
 		else {
 			//	create CONIC
-			GeoConic transformedConic = kernel.getTransformedConic(type, this, Q, l, vec, n);
+			GeoConic transformedConic = t.getTransformedConic(this);
 			transformedConic.setLabel(label);
 			GeoElement [] ret = { transformedConic };
 			return ret;
@@ -721,4 +780,160 @@ implements LimitedPath, NumberValue, LineProperties {
 		return new GeoConicPart(this);
 	}
 	
+	/**
+	 * not supported for Arcs etc
+	 * @param geoMatrix 
+	 */
+	public void matrixTransform(GeoList geoMatrix) {
+		
+		setUndefined();
+		
+	}
+	
+	
+	public boolean isInRegion(double x0, double y0) {
+			
+		if(!super.isInRegion(x0, y0))
+			return false;
+		
+
+		//for sector, check if (x0,y0) is on the arc outline
+		if (getConicPartType()==CONIC_PART_SECTOR){
+			double arg = computeArg(x0,y0);
+			if (arg < 0) 
+				arg += Kernel.PI_2;
+			//Application.debug(arg+" <? "+paramExtent);
+
+			return ((arg >= -Kernel.EPSILON) && (arg <= paramExtent+Kernel.EPSILON));
+		}
+			
+		
+		//for arc, check if is inside the arc : cross product with limit 
+		//Application.debug(posOrientation);
+		Coords midpoint = getMidpoint2D();
+		Coords firstVec = getEigenvec(0).mul(getHalfAxis(0)*Math.cos(paramStart)).add(getEigenvec(1).mul(getHalfAxis(1)*Math.sin(paramStart)));
+		Coords secondVec = getEigenvec(0).mul(getHalfAxis(0)*Math.cos(paramEnd)).add(getEigenvec(1).mul(getHalfAxis(1)*Math.sin(paramEnd)));
+
+		double vx = (x0-midpoint.getX())-firstVec.getX(), vy = (y0-midpoint.getY())-firstVec.getY();
+		double lx = secondVec.getX()-firstVec.getX(), ly = secondVec.getY()-firstVec.getY();
+		
+		return (vx*ly-vy*lx>0);
+		
+	}
+	
+	
+	private double computeArg(double x0, double y0) {
+		double px = x0 - b.x;
+		double py = y0 - b.y;
+		
+		// rotate by -alpha
+		double px2 = px * eigenvec[0].x + py * eigenvec[0].y;
+		py = px * eigenvec[1].x + py * eigenvec[1].y;			
+
+		// calc parameter 
+			
+		
+		// relation between the internal parameter t and the angle theta:
+		// t = atan(a/b tan(theta)) where tan(theta) = py / px
+		double arg = Math.atan2(halfAxes[0]*py, halfAxes[1]*px2);
+		if (arg < 0)
+			arg += Kernel.PI_2;
+		return arg - paramStart;
+			
+	}
+
+	protected void moveBackToRegion(GeoPointND pi,RegionParameters rp) {
+		Coords coords = pi.getCoordsInD2(getCoordSys());
+		PathParameter pp = pi.getPathParameter();
+		
+		//try to find the nearest point in the conic part
+		CoordNearest nearestPoint = new CoordNearest(coords);
+		
+
+		
+		//check points of the conic part
+		Coords midpoint = getMidpoint2D();
+		if (getConicPartType()==CONIC_PART_SECTOR)
+			nearestPoint.check(midpoint);
+		
+		Coords ev0 = new Coords(3); ev0.set(getEigenvec(0));
+		Coords ev1 = new Coords(3); ev1.set(getEigenvec(1));	
+		
+		Coords firstPoint = midpoint.add(ev0.mul(getHalfAxis(0)*Math.cos(paramStart))).add(ev1.mul(getHalfAxis(1)*Math.sin(paramStart)));
+		nearestPoint.check(firstPoint);
+		Coords secondPoint = midpoint.add(ev0.mul(getHalfAxis(0)*Math.cos(paramEnd))).add(ev1.mul(getHalfAxis(1)*Math.sin(paramEnd)));
+		nearestPoint.check(secondPoint);
+		
+		//check project points on segments edges
+		Coords[] segPoint;
+		if (getConicPartType()==CONIC_PART_SECTOR){
+			segPoint = coords.projectLine(midpoint, firstPoint.sub(midpoint));
+			if (segPoint[1].getX()>0 && segPoint[1].getX()<1) //check if the projected point is on the segment
+				nearestPoint.check(segPoint[0]);
+			segPoint = coords.projectLine(midpoint, secondPoint.sub(midpoint));
+			if (segPoint[1].getX()>0 && segPoint[1].getX()<1) //check if the projected point is on the segment
+				nearestPoint.check(segPoint[0]);
+		}else{
+			segPoint = coords.projectLine(firstPoint, secondPoint.sub(firstPoint));
+			if (segPoint[1].getX()>0 && segPoint[1].getX()<1) //check if the projected point is on the segment
+				nearestPoint.check(segPoint[0]);
+		}
+		
+		
+		//may calc the nearest point of the global conic
+		if(!super.isInRegion(coords.getX(),coords.getY())){
+			Coords pointConic = coords.copyVector();
+			pointChanged(pointConic, pp);
+			nearestPoint.check(pointConic);
+			rp.setIsOnPath(true);
+		}
+
+		//take nearest point above all
+		coords = nearestPoint.get();
+
+
+		pi.setCoords2D(coords.getX(), coords.getY(), coords.getZ());
+		pi.updateCoordsFrom2D(false,getCoordSys());
+		pi.updateCoords();
+
+
+	}
+	
+	public void regionChanged(GeoPointND PI){
+		super.regionChanged(PI);
+		PI.updateCoords2D();
+		if(!isInRegion(PI))
+			pointChanged(PI);
+		
+	}
+	
+	
+	
+    public boolean hasDrawable3D() {
+    	return true;
+    }
+    
+    public boolean isAllEndpointsLabelsSet() {
+    	AlgoElement algo = this.getParentAlgorithm();
+    	if(algo==null)//should never happen, just to be sure
+    		return false; 
+    	if(algo instanceof geogebra.kernel.AlgoConicPartConicPoints)
+    		return ((AlgoConicPartConicPoints)algo).getStartPoint().isLabelSet() &&
+    		((AlgoConicPartConicPoints)algo).getEndPoint().isLabelSet();
+    	if(algo instanceof geogebra.kernel.AlgoConicPartCircumcircle)
+    		return algo.getInput()[0].isLabelSet() && algo.getInput()[1].isLabelSet() &&
+    		algo.getInput()[2].isLabelSet();	
+    	return false;		
+	} 
+	
+    public GeoPoint getPointParam(double param){
+    	GeoPoint ret = new GeoPoint(cons);
+    	this.pathChanged(ret);
+    	ret.getPathParameter().setT(param);    
+    	this.pathChanged(ret);
+    	ret.updateCoords();        	
+    	return ret;
+    }
+    
+	
 }
