@@ -1501,13 +1501,18 @@ CasEvaluableFunction, ParametricCurve, LineProperties, RealRootFunction, Dilatea
 	 */
 	final public String [] getTempVarCASString(boolean symbolic) {
 		 boolean oldUseTempVariablePrefix = kernel.isUseTempVariablePrefix();
+		 String [] ret= new String[]{"",""};
+		 try{
 		 kernel.setUseTempVariablePrefix(true);
-		 String [] ret = 
+		 ret = new String[] 
 		 {
 			   getCASString(symbolic),
 			   getVarString()
 		 };
-		 kernel.setUseTempVariablePrefix(oldUseTempVariablePrefix);
+		 }
+		 finally{
+			 kernel.setUseTempVariablePrefix(oldUseTempVariablePrefix);
+		 }
 		 return ret;
 	}
     
@@ -1644,5 +1649,10 @@ CasEvaluableFunction, ParametricCurve, LineProperties, RealRootFunction, Dilatea
 	public boolean isGeoFunctionBoolean(){
 		return isBooleanFunction();
 	}
+	
+	@Override
+	public int getMinimumLineThickness() {
+		return isInequality ? 0 : 1;
+	}
 
 }
