@@ -741,4 +741,9 @@ implements FunctionalNVar, CasEvaluableFunction, Region, Transformable, Translat
 			}
 			
 		}
+		
+		@Override
+		public int getMinimumLineThickness() {
+			return isInequality ? 0 : 1;
+		}
 }
