@@ -12,58 +12,83 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.Matrix.Coords;
+import geogebra.euclidian.EuclidianConstants;
+import geogebra.euclidian.EuclidianViewInterface;
 import geogebra.kernel.arithmetic.NumberValue;
+import geogebra.kernel.kernelND.GeoPointND;
 import geogebra.util.Util;
 
-import java.awt.image.BufferedImage;
 import java.io.File;
+import java.util.ArrayList;
 import java.util.Vector;
 
+/**
+ * Image with given filename and corners
+ */
 public class GeoImage extends GeoElement 
 implements Locateable, AbsoluteScreenLocateable,
-		   PointRotateable, Mirrorable, Translateable, Dilateable {
+		   PointRotateable, Mirrorable, Translateable, Dilateable, MatrixTransformable,Transformable {
 	 	
 	/**
 	 * 
 	 */
 	private static final long serialVersionUID = 1L;
-	private String fileName = ""; // image file
+	//private String imageFileName = ""; // image file
 	private GeoPoint [] corners; // corners of the image
-	private BufferedImage image;	
+	//private BufferedImage image;	
 	private int pixelWidth, pixelHeight;
 	private boolean inBackground, defined;
 	private boolean hasAbsoluteLocation;
+	private boolean interpolate=true;
 	
 	// for absolute screen location
 	private int screenX, screenY;
-	boolean hasAbsoluteScreenLocation = false;	
+	private boolean hasAbsoluteScreenLocation = false;	
 	
 	// corner points for transformations
 	private GeoPoint [] tempPoints;
 	
-	private static Vector instances = new Vector();
+	private static Vector<GeoImage> instances = new Vector<GeoImage>();
 	
+	/**
+	 * Creates new image
+	 * @param c construction
+	 */
 	public GeoImage(Construction c) {
 		super(c);
-		setAlphaValue(1f);
-		setAlgebraVisible(false); // don't show in algebra view		
+		
+		// moved from GeoElement's constructor
+		// must be called from the subclass, see
+		//http://benpryor.com/blog/2008/01/02/dont-call-subclass-methods-from-a-superclass-constructor/
+		setConstructionDefaults(); // init visual settings
 
+		setAlphaValue(1f);
+		//setAlgebraVisible(false); // don't show in algebra view		
+		setAuxiliaryObject(true);
+		
 		// three corners of the image: first, second and fourth
 		corners = new GeoPoint[3]; 			
 				
-		instances.add(this);
+		instances.add(this);	
 		defined = true;
 	}  
 
-	
+	/**
+	 * Creates new labeled image
+	 * @param c construction
+	 * @param label
+	 * @param fileName path to the image
+	 */
 	public GeoImage(Construction c, String label, String fileName) {
 		this(c);
-		setFileName(fileName);
+		setImageFileName(fileName);
 		setLabel(label);
 	}  
 	
 	/**
 	 * Copy constructor
+	 * @param img source image
 	 */
 	public GeoImage(GeoImage img) {
 		this(img.cons);
@@ -74,6 +99,17 @@ implements Locateable, AbsoluteScreenLocateable,
 		return new GeoImage(this);
 	}
 	
+    public int getRelatedModeID() {
+    	switch (this.image.getType()){
+    	case 5:
+    		return EuclidianConstants.MODE_IMAGE;
+    	case 6:
+    		return EuclidianConstants.MODE_PEN;
+    	default:
+    		return -1;	
+    	}
+    }
+	
 	private void initTempPoints() {
 		if (tempPoints == null) {
 			//	temp corner points for transformations and absolute location
@@ -89,7 +125,7 @@ implements Locateable, AbsoluteScreenLocateable,
 
 	public void set(GeoElement geo) {
 		GeoImage img = (GeoImage) geo;
-		setFileName(img.fileName);
+		setImageFileName(img.imageFileName);
 		
 		// macro output: don't set corners
 		if (cons != geo.cons && isAlgoMacroOutput()) 
@@ -115,6 +151,9 @@ implements Locateable, AbsoluteScreenLocateable,
 				}
 			}
 		}
+		
+		//interpolation settings
+		interpolate=img.interpolate;
 		defined = img.defined;
 	}
 	
@@ -132,19 +171,25 @@ implements Locateable, AbsoluteScreenLocateable,
 	public static void updateInstances() {
 		for (int i=instances.size()-1; i >= 0 ; i--) {
 			GeoImage geo = (GeoImage) instances.get(i);
-			geo.setFileName(geo.fileName);
+			geo.setImageFileName(geo.imageFileName);
 			geo.updateCascade();
 		}		
 	}
 	
 	public boolean showToolTipText() {
-		return !inBackground;
+		return !inBackground && super.showToolTipText();
 	}
-	
+	/**
+	 * True for background images
+	 * @return true for background images
+	 */
 	final public boolean isInBackground() {
 		return inBackground;
 	}
-	
+	/**
+	 * Switch to background image (or vice versa)
+	 * @param flag true to make it background image
+	 */
 	public void setInBackground(boolean flag) {
 		inBackground = flag;		
 	}
@@ -153,11 +198,11 @@ implements Locateable, AbsoluteScreenLocateable,
 	 * Tries to load the image using the given fileName.
 	 * @param fileName
 	 */
-	public void setFileName(String fileName) {	
-		if (this.fileName.equals(fileName))
+	public void setImageFileName(String fileName) {	
+		if (fileName.equals(this.imageFileName))
 			return;
 				
-		this.fileName = fileName;
+		this.imageFileName = fileName;
 														
 		image = app.getExternalImage(fileName);	
 		if (image != null) {
@@ -170,41 +215,37 @@ implements Locateable, AbsoluteScreenLocateable,
 		// Michael Borcherds 2007-12-10 MD5 code moved to Application.java
 	}
 	
-	public String getFileName() {
-		return fileName;
+	//final public BufferedImage getFillImage() {
+	//	return image;
+	//}		
+	
+	public void setStartPoint(GeoPointND p) throws CircularDefinitionException {    
+		setCorner((GeoPoint) p, 0);
 	}
 	
-	final public BufferedImage getImage() {
-		return image;
-	}		
-	
-	public void setStartPoint(GeoPoint p) throws CircularDefinitionException {    
-		setCorner(p, 0);
-	}
-	
-	public void removeStartPoint(GeoPoint p) {    
+	public void removeStartPoint(GeoPointND p) {    
 		for (int i=0; i < corners.length; i++) {
 			if (corners[i] == p)
 				setCorner(null, i);
 		}
 	}
 	
-	public void setStartPoint(GeoPoint p, int number) throws CircularDefinitionException {
-		setCorner(p, number);
+	public void setStartPoint(GeoPointND p, int number) throws CircularDefinitionException {
+		setCorner((GeoPoint) p, number);
 	}
 	
 	/**
 	 * Sets the startpoint without performing any checks.
 	 * This is needed for macros.	 
 	 */
-	public void initStartPoint(GeoPoint p, int number) {
-		corners[number] = p;
+	public void initStartPoint(GeoPointND p, int number) {
+		corners[number] = (GeoPoint) p;
 	}
 	
 	/**
 	 * Sets a corner of this image. 
-	 * @param p
-	 * @param number: 0, 1 or 2 (first, second and fourth corner)
+	 * @param p corner point
+	 * @param number 0, 1 or 2 (first, second and fourth corner)
 	 */
 	public void setCorner(GeoPoint p, int number)  {
 		// macro output uses initStartPoint() only
@@ -221,7 +262,7 @@ implements Locateable, AbsoluteScreenLocateable,
 		if (p == null) {
 			//	remove old dependencies
 			if (corners[number] != null) 
-				corners[number].unregisterLocateable(this);	
+				corners[number].getLocateableList().unregisterLocateable(this);	
 						
 			// copy old first corner as absolute position
 			if (number == 0 && corners[0] != null) {
@@ -239,11 +280,11 @@ implements Locateable, AbsoluteScreenLocateable,
 			
 			// remove old dependencies
 			if (corners[number] != null) 
-				corners[number].unregisterLocateable(this);		
+				corners[number].getLocateableList().unregisterLocateable(this);		
 			
 			corners[number] = p;
 			//	add new dependencies
-			corners[number].registerLocateable(this);								
+			corners[number].getLocateableList().registerLocateable(this);								
 		}					
 		
 		// absolute screen position should be deactivated
@@ -266,7 +307,7 @@ implements Locateable, AbsoluteScreenLocateable,
 		}
 	}		
 	
-	protected void doRemove() {
+	public void doRemove() {
 		instances.remove(this);		
 		
 		// remove background image
@@ -278,7 +319,7 @@ implements Locateable, AbsoluteScreenLocateable,
 		super.doRemove();		
 		for (int i=0; i < corners.length; i++) {
 			// tell corner	
-			if (corners[i] != null) corners[i].unregisterLocateable(this);
+			if (corners[i] != null) corners[i].getLocateableList().unregisterLocateable(this);
 		}		
 	}
 	
@@ -289,7 +330,11 @@ implements Locateable, AbsoluteScreenLocateable,
 	public GeoPoint [] getStartPoints() {
 		return corners;
 	}
-	
+	/**
+	 * Returns n-th corner point
+	 * @param number 1 for boottom left, others clockwise
+	 * @return corner point
+	 */
 	final public GeoPoint getCorner(int number) {
 		return corners[number];
 	}
@@ -297,6 +342,22 @@ implements Locateable, AbsoluteScreenLocateable,
 	final public boolean hasAbsoluteLocation() {
 		return hasAbsoluteLocation;
 	}	
+
+	/**
+	 * 
+	 * @return true if the image wants to be interpolated
+	 */
+	final public boolean isInterpolate(){
+		return interpolate;
+	}
+	
+	/**
+	 * sets if the image want to be interpolated
+	 * @param flag
+	 */
+	final public void setInterpolate(boolean flag){
+		interpolate=flag;
+	}
 	
 	public void setWaitForStartPoint() {
 		// this can be ignored for an image 
@@ -304,13 +365,7 @@ implements Locateable, AbsoluteScreenLocateable,
 		// is irrelevant for the rest of the construction
 	}
 	
-	public void setMode(int mode) {
-	}
-
-	public int getMode() {
-		return 0;
-	}
-
+	
 	final public boolean isDefined() {
 		if(!defined) return false;
 		for (int i=0; i < corners.length; i++) {
@@ -321,8 +376,8 @@ implements Locateable, AbsoluteScreenLocateable,
 	}
 
 	/**
-	 * makes image invisible 
-	 * needed for Sequence's cached images 
+	 * makes image invisible
+	 * needed for Sequence's cached images
  	*/
 	public void setUndefined() {
 		defined = false;		
@@ -333,18 +388,18 @@ implements Locateable, AbsoluteScreenLocateable,
 	}
 	
 	public String toString() {				
-		return label;
+		return label == null ? app.getPlain("Image") : label;
 	}	
 
 	public boolean showInAlgebraView() {
-		return false;
+		return true;
 	}
 
 	protected boolean showInEuclidianView() {		
 		return image != null && isDefined();
 	}
 
-	protected String getClassName() {
+	public String getClassName() {
 		return "GeoImage";
 	}
 	
@@ -373,11 +428,11 @@ implements Locateable, AbsoluteScreenLocateable,
 	}
 	
 	/**
-	 * Returns wheter this image can be fixed.
-	 */	
+	 * Returns whether this image can be fixed.
+	 *
 	public boolean isFixable() {
 		return (hasAbsoluteScreenLocation || hasAbsoluteLocation) && isIndependent();
-	}
+	}*/
 	
 	public boolean isFillable() {
 		return true;
@@ -406,19 +461,23 @@ implements Locateable, AbsoluteScreenLocateable,
 	/**
 	* returns all class-specific xml tags for getXML
 	*/
-	protected String getXMLtags() {   	
-	   	StringBuffer sb = new StringBuffer();	   		   		   	
+	protected void getXMLtags(StringBuilder sb) {  		   	
 			   	
 	   	// name of image file
 		sb.append("\t<file name=\"");
 // Michael Borcherds 2007-12-10 this line restored (not needed now MD5 code put in the correct place)
-		sb.append(fileName);
+		sb.append(imageFileName);
 		sb.append("\"/>\n");
 		
 	 	// name of image file
 		sb.append("\t<inBackground val=\"");
 		sb.append(inBackground);
-		sb.append("\"/>\n");	
+		sb.append("\"/>\n");
+		
+		
+		// image has to be interpolated
+		if (!isInterpolate())
+    		sb.append("\t<interpolate val=\"false\"/>\n");
 
 		// locateion of image
 		if (hasAbsoluteScreenLocation) {
@@ -433,15 +492,16 @@ implements Locateable, AbsoluteScreenLocateable,
 			}
 		}
 		
+		getAuxiliaryXML(sb);
+		
 //	   	sb.append(getXMLvisualTags());
 //	   	sb.append(getBreakpointXML());
-		sb.append(super.getXMLtags());
-			
-	   return sb.toString();   
+		super.getXMLtags(sb);
+ 
    	}
    	
    	private String getXMLabsScreenLoc() {
-   		StringBuffer sb = new StringBuffer();
+   		StringBuilder sb = new StringBuilder();
    		
    		sb.append("\t<absoluteScreenLocation x=\"");
    		sb.append(screenX);
@@ -452,7 +512,7 @@ implements Locateable, AbsoluteScreenLocateable,
    	}
    	
     private String getCornerPointXML(int number) {
-    	StringBuffer sb = new StringBuffer();    	
+    	StringBuilder sb = new StringBuilder();    	
 		sb.append("\t<startPoint number=\"");
 		sb.append(number);
 		sb.append("\"");
@@ -463,15 +523,16 @@ implements Locateable, AbsoluteScreenLocateable,
 			sb.append(" z=\"" + corners[number].z + "\"");			
     	} else {
 			sb.append(" exp=\"");
-			boolean oldValue = kernel.isTranslateCommandName();
-			kernel.setTranslateCommandName(false);
+			boolean oldValue = kernel.isPrintLocalizedCommandNames();
+			kernel.setPrintLocalizedCommandNames(false);
 			sb.append(Util.encodeXML(corners[number].getLabel()));
-			kernel.setTranslateCommandName(oldValue);
+			kernel.setPrintLocalizedCommandNames(oldValue);
 			sb.append("\"");			    	
     	}
 		sb.append("/>\n");
 		return sb.toString();
     }
+    
 
 	public void setAbsoluteScreenLoc(int x, int y) {
 		screenX = x;
@@ -515,7 +576,7 @@ implements Locateable, AbsoluteScreenLocateable,
 			// remove startpoints
 			for (int i=0; i < 3; i++) {
 				if (corners[i] != null) {
-					corners[i].unregisterLocateable(this);						
+					corners[i].getLocateableList().unregisterLocateable(this);						
 				}
 			}	
 			corners[1] = null;
@@ -541,8 +602,8 @@ implements Locateable, AbsoluteScreenLocateable,
 	 * coordinates. Note: if this image
 	 * has an absolute screen location, result is set to undefined.
 	 * 
-	 * @param result: here the result is stored.
-	 * @param number of the corner point 1, 2, 3 or 4) 
+	 * @param result here the result is stored.
+	 * @param n number of the corner point (1, 2, 3 or 4) 
 	 */
 	public void calculateCornerPoint(GeoPoint result, int n) {		
 		if (hasAbsoluteScreenLocation) {
@@ -700,6 +761,22 @@ implements Locateable, AbsoluteScreenLocateable,
     	}     
 	}
 
+	public void matrixTransform(double a,double b,double c, double d) {
+		if (!initTransformPoints()) return;
+    	
+    	// calculate the new corner points
+    	for (int i=0; i < corners.length; i++) {
+    		GeoVec2D vec = tempPoints[i].getVector();
+    		vec.matrixTransform(a, b, c, d);    
+    		if (corners[i] == null) corners[i] = new GeoPoint(cons);
+    		corners[i].setCoords(vec);    			
+    	}     
+	}
+	
+	public boolean isMatrixTransformable() { 
+		return true;
+	}
+
 	public void mirror(GeoLine g) {
 		if (!initTransformPoints()) return;
     	
@@ -710,7 +787,7 @@ implements Locateable, AbsoluteScreenLocateable,
     	}  
 	}
 
-	public void translate(GeoVector v) {
+	public void translate(Coords v) {
 		if (!initTransformPoints()) return;
     	
     	// calculate the new corner points
@@ -743,16 +820,67 @@ implements Locateable, AbsoluteScreenLocateable,
 		if (((GeoImage)geo).pixelWidth != this.pixelWidth) return false;
 		if (((GeoImage)geo).pixelHeight != this.pixelHeight) return false;
 		
-		String md5A=this.fileName.substring(0, this.fileName.indexOf(File.separator));
-		String md5B=((GeoImage)geo).fileName.substring(0, ((GeoImage)geo).fileName.indexOf(File.separator));
+		String md5A=this.imageFileName.substring(0, this.imageFileName.indexOf(File.separator));
+		String md5B=((GeoImage)geo).imageFileName.substring(0, ((GeoImage)geo).imageFileName.indexOf(File.separator));
 		// MD5 checksums equal, so images almost certainly identical
 		if (md5A.equals(md5B)) return true;
 		return false;
 	}
-
-
+	
 	public boolean isAlwaysFixed() {
 		return false;
+	}	
+
+	public boolean isVector3DValue() {		
+		return false;
+	}
+	
+	public boolean hasMoveableInputPoints(EuclidianViewInterface view) {
+		
+		if (hasAbsoluteLocation()) return false;
+		
+		for (int i = 0 ; i < corners.length ; i++) {
+			if (corners[i] != null && !corners[i].isMoveable(view)) return false;
+		}
+		return true;
+	}
+	
+	private ArrayList<GeoPoint> al = null;
+
+	/**
+	 * Returns all free parent points of this GeoElement.	 
+	 */
+	public ArrayList<GeoPoint> getFreeInputPoints(EuclidianViewInterface view) {		
+			if (hasAbsoluteLocation()) return null;
+			
+			if (al == null) al = new ArrayList<GeoPoint>();
+			else al.clear();
+			
+			for (int i = 0 ; i < corners.length ; i++) {
+				if (corners[i] != null) al.add(corners[i]);
+			}
+			
+			return al;
+	}
+	
+	final public boolean isAuxiliaryObjectByDefault() {
+		return true;
+	}
+
+	final public boolean isAlgebraViewEditable() {
+		return false;
 	}
 
+	public void matrixTransform(double a00, double a01, double a02, double a10,
+			double a11, double a12, double a20, double a21, double a22) {
+		for (int i=0; i < corners.length; i++) {
+    		GeoVec2D vec = tempPoints[i].getVector();
+    		vec.matrixTransform(a00, a01, a02, a10,a11,a12,a20,a21,a22);    
+    		if (corners[i] == null) corners[i] = new GeoPoint(cons);
+    		corners[i].setCoords(vec);    			
+    	}
+		
+	}
+
+
 }
