@@ -39,7 +39,6 @@ implements Path,
 Translateable,PointRotateable, Mirrorable, Dilateable, LineProperties,
 GeoLineND, MatrixTransformable, GeoFunctionable, Evaluatable, Transformable {
 	
-	private static final long serialVersionUID = 1L;
 	// modes
     public static final int EQUATION_IMPLICIT = 0;
     public static final int EQUATION_EXPLICIT = 1;
@@ -1312,7 +1311,10 @@ GeoLineND, MatrixTransformable, GeoFunctionable, Evaluatable, Transformable {
 	}
 	
 	public void doRemove() {
-		
+		if(getStartPoint()!=null)
+			getStartPoint().removeIncidence(this);
+		if(getEndPoint()!=null)
+			getEndPoint().removeIncidence(this);
 		if (pointsOnLine!=null) {
 			for (int i=0; i<pointsOnLine.size(); ++i) {
 				GeoPoint p = pointsOnLine.get(i);
