@@ -195,7 +195,7 @@ public class GeoList extends GeoElement implements ListValue, LineProperties,
 		} else {
 			// create a copy of geo
 			final GeoElement ret = geo.copyInternal(cons);
-			ret.setParentAlgorithm(getParentAlgorithm());
+			ret.setParentAlgorithmSimple(getParentAlgorithm());
 			return ret;
 		}
 	}
@@ -492,7 +492,6 @@ public class GeoList extends GeoElement implements ListValue, LineProperties,
 		cacheList.clear();
 		clear();
 		setUndefined();
-		System.gc();
 	}
 
 	public final void add(final GeoElement geo) {
