@@ -1,8 +1,11 @@
 package geogebra.kernel;
 
+import geogebra.euclidian.EuclidianConstants;
 import geogebra.euclidian.EuclidianView;
+import geogebra.kernel.arithmetic.ExpressionNode;
 import geogebra.kernel.arithmetic.MyStringBuffer;
 import geogebra.kernel.arithmetic.TextValue;
+import geogebra.kernel.kernelND.GeoPointND;
 import geogebra.main.Application;
 import geogebra.util.Util;
 
@@ -22,26 +25,45 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	private boolean needsUpdatedBoundingBox = false;
 	
 	// font options
-	private boolean serifFont = false;
-	private int fontStyle = Font.PLAIN;
-	private int fontSize = 0; // size relative to default font size
-	public int printDecimals = -1;
-	public int printFigures = -1;
-	public boolean useSignificantFigures = false;
+	private boolean serifFont;
+	private int fontStyle;
+	private int fontSize = 0; // must be zero, as that is the value NOT saved to XML
+	private int printDecimals = -1;
+	private int printFigures = -1;
+	private boolean useSignificantFigures = false;
+	
+	final public static int FONTSIZE_EXTRA_SMALL = 0;
+	final public static int FONTSIZE_VERY_SMALL = 1;
+	final public static int FONTSIZE_SMALL = 2;
+	final public static int FONTSIZE_MEDIUM = 3;
+	final public static int FONTSIZE_LARGE = 4;
+	final public static int FONTSIZE_VERY_LARGE = 5;
+	final public static int FONTSIZE_EXTRA_LARGE = 6;
 	
 	// for absolute screen location
-	boolean hasAbsoluteScreenLocation = false;
+	private boolean hasAbsoluteScreenLocation = false;
 	
 	public GeoText(Construction c) {
 		super(c);
+		
+		// moved from GeoElement's constructor
+		// must be called from the subclass, see
+		//http://benpryor.com/blog/2008/01/02/dont-call-subclass-methods-from-a-superclass-constructor/
+		setConstructionDefaults(); // init visual settings
+
 		// don't show in algebra view	
-		setAlgebraVisible(false); 	
+		//setAlgebraVisible(false); 
+		setAuxiliaryObject(true);
 	}  
 	
 	public GeoText(Construction c, String label, String value) {
+		this(c, value);
+		setLabel(label);
+	}  
+	
+	public GeoText(Construction c, String value) {
 		this(c);
 		setTextString(value);
-		setLabel(label);
 	}  
 	
 	/**
@@ -57,13 +79,22 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	}
 
 	public void set(GeoElement geo) {
-		GeoText gt = (GeoText) geo;				
-		str = gt.str;
-		isLaTeX = gt.isLaTeX;		
-		
+		GeoText gt = (GeoText) geo;	
 		// macro output: don't set start point
-		if (cons != geo.cons && isAlgoMacroOutput()) 
+		// but update to desired number format
+		if (cons != geo.cons && isAlgoMacroOutput()){
+			if(!useSignificantFigures)
+				gt.setPrintDecimals(printDecimals > -1 ? printDecimals :  kernel.getPrintDecimals(), true);	
+			else
+				gt.setPrintFigures(printFigures > -1 ? printFigures :  kernel.getPrintFigures(),true);				
+			str = gt.str;
+			isLaTeX = gt.isLaTeX;		
 			return;
+		}
+		
+		str = gt.str;
+		isLaTeX = gt.isLaTeX;
+			
 		
 		// needed for Corner[Element[text
 		setBoundingBox(gt.getBoundingBox());
@@ -124,15 +155,15 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	 * Sets the startpoint without performing any checks.
 	 * This is needed for macros.	 
 	 */
-	public void initStartPoint(GeoPoint p, int number) {
-		startPoint = p;
+	public void initStartPoint(GeoPointND p, int number) {
+		startPoint = (GeoPoint) p;
 	}
 	
-	public void setStartPoint(GeoPoint p, int number)  throws CircularDefinitionException {
+	public void setStartPoint(GeoPointND p, int number)  throws CircularDefinitionException {
 		setStartPoint(p);
 	}
 	
-	public void removeStartPoint(GeoPoint p) {    
+	public void removeStartPoint(GeoPointND p) {    
 		if (startPoint == p) {
 			try {
 				setStartPoint(null);
@@ -140,19 +171,18 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		}
 	}
 			
-	public void setStartPoint(GeoPoint p) throws CircularDefinitionException { 
+	public void setStartPoint(GeoPointND p) throws CircularDefinitionException { 
 		// don't allow this if it's eg Text["hello",(2,3)]
-		if (alwaysFixed) return;		
-		
+		if (alwaysFixed) return;				
 		// macro output uses initStartPoint() only
 		//if (isAlgoMacroOutput()) return; 
 		
 		// check for circular definition
-		if (isParentOf(p))
+		if (isParentOf((GeoElement) p))
 			throw new CircularDefinitionException();		
 		
 		// remove old dependencies
-		if (startPoint != null) startPoint.unregisterLocateable(this);	
+		if (startPoint != null) startPoint.getLocateableList().unregisterLocateable(this);	
 		
 		// set new location	
 		if (p == null) {
@@ -163,9 +193,9 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 			labelOffsetX = 0;
 			labelOffsetY = 0;					
 		} else {
-			startPoint = p;
+			startPoint = (GeoPoint) p;
 			//	add new dependencies
-			startPoint.registerLocateable(this);
+			startPoint.getLocateableList().registerLocateable(this);
 			
 			// absolute screen position should be deactivated
 			setAbsoluteScreenLocActive(false);
@@ -174,18 +204,18 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	
 	
 	
-	protected void doRemove() {
+	public void doRemove() {
 		super.doRemove();
 		// tell startPoint	
-		if (startPoint != null) startPoint.unregisterLocateable(this);
+		if (startPoint != null) startPoint.getLocateableList().unregisterLocateable(this);
 	}
 	
-	public GeoPoint getStartPoint() {
+	public GeoPointND getStartPoint() {
 		return startPoint;
 	}
 	
 	
-	public GeoPoint [] getStartPoints() {
+	public GeoPointND [] getStartPoints() {
 		if (startPoint == null)
 			return null;
 	
@@ -203,13 +233,7 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		// as the position of its startpoint
 		// is irrelevant for the rest of the construction
 	}
-	
-	public void setMode(int mode) {
-	}
-
-	public int getMode() {
-		return 0;
-	}
+		
 	
 	public void update() {
 
@@ -244,11 +268,19 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	 * Returns quoted text value string.
 	 */
 	public String toOutputValueString() {	
+		int printForm = kernel.getCASPrintForm();
+		
 		sbToString.setLength(0);
-		sbToString.append('\"');
+		if (printForm == ExpressionNode.STRING_TYPE_LATEX)
+			sbToString.append("\\text{``");
+		else
+			sbToString.append('\"');
 		if (str != null)
 			sbToString.append(str);
-		sbToString.append('\"');	
+		if (printForm == ExpressionNode.STRING_TYPE_LATEX)
+			sbToString.append("''}");
+		else
+			sbToString.append('\"');
 		return sbToString.toString();	
 	}
 	
@@ -262,19 +294,23 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		sbToString.append('\"');	
 		return sbToString.toString();
 	}
-	private StringBuffer sbToString = new StringBuffer(80);
+	private StringBuilder sbToString = new StringBuilder(80);
 
-	protected boolean showInAlgebraView() {
-		return false;
+	public boolean showInAlgebraView() {
+		return true;
 	}
 
 	protected boolean showInEuclidianView() {		
 		return isDefined();
 	}
 
-	protected String getClassName() {
+	public String getClassName() {
 		return "GeoText";
 	}
+
+    public int getRelatedModeID() {
+    	return EuclidianConstants.MODE_TEXT;
+    }
 	
     protected String getTypeString() {
 		return "Text";
@@ -291,11 +327,11 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		return !isFixed();
 	}
 	
-	// used for eg Text["text",(1,2)]
-	// to stop it being editable
+	/** used for eg Text["text",(1,2)]
+	* to stop it being editable */
 	boolean isTextCommand = false;
 	
-	public void setIsCommand(boolean isCommand) {
+	public void setIsTextCommand(boolean isCommand) {
 		this.isTextCommand = isCommand;
 	}
 	
@@ -307,13 +343,20 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		return isTextCommand;
 	}
 	
-	void setAlgoMacroOutput(boolean isAlgoMacroOutput) {
-		super.setAlgoMacroOutput(true);
-		setIsCommand(true);
+	public boolean isLaTeXTextCommand() {
+
+		if (!isTextCommand || getParentAlgorithm() == null) return false;
+
+		return getParentAlgorithm().isLaTeXTextCommand();
 	}
 	
-	// used for eg Text["text",(1,2)]
-	// to stop it being draggable
+	void setAlgoMacroOutput(boolean isAlgoMacroOutput) {
+		super.setAlgoMacroOutput(true);
+		setIsTextCommand(true);
+	}
+	
+	/** used for eg Text["text",(1,2)]
+	 * to stop it being draggable */
 	boolean alwaysFixed = false;
 	
 	public void setAlwaysFixed(boolean alwaysFixed) {
@@ -350,58 +393,57 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	
 	public MyStringBuffer getText() {
 		if (str != null)
-			return new MyStringBuffer(str);
+			return new MyStringBuffer(kernel, str);
 		else
-			return new MyStringBuffer("");
+			return new MyStringBuffer(kernel, "");
 	}	
-		
+
 	/**
-	   * save object in XML format
-	   */ 
-	  public final String getXML() {
-		 StringBuffer sb = new StringBuffer();
-	 
-		 // an independent text needs to add
-		 // its expression itself
-		 // e.g. text0 = "Circle"
-		 if (isIndependent()) {
+	  * save object in XML format
+	  */ 
+	public final void getXML(StringBuilder sb) {
+
+		// an independent text needs to add
+		// its expression itself
+		// e.g. text0 = "Circle"
+		if (isIndependent() && getDefaultGeoType() < 0) {
 			sb.append("<expression");
-				sb.append(" label=\"");
-				sb.append(Util.encodeXML(label));
-				sb.append("\" exp=\"");
-				sb.append(Util.encodeXML(toOutputValueString()));
-				// expression   
+			sb.append(" label=\"");
+			sb.append(Util.encodeXML(label));
+			sb.append("\" exp=\"");
+			sb.append(Util.encodeXML(toOutputValueString()));
+			// expression   
 			sb.append("\"/>\n");
-		 }
-  		  
-		  sb.append("<element"); 
-			  sb.append(" type=\"text\"");
-			  sb.append(" label=\"");
-			  sb.append(Util.encodeXML(label));
-		  sb.append("\">\n");
-		  sb.append(getXMLtags());
-		  sb.append("</element>\n");
-	  	  
-		  return sb.toString();
-	  }
+		}
+
+		sb.append("<element"); 
+		sb.append(" type=\"text\"");
+		sb.append(" label=\"");
+		sb.append(Util.encodeXML(label));
+		if (getDefaultGeoType() >= 0) {
+			sb.append("\" default=\"");
+			sb.append(getDefaultGeoType());
+		}
+		sb.append("\">\n");
+		getXMLtags(sb);
+		sb.append("</element>\n");
+
+	}
 
 	/**
 	* returns all class-specific xml tags for getXML
 	*/
-   	protected String getXMLtags() {   	
-	   	StringBuffer sb = new StringBuffer();
-	   	sb.append(getXMLvisualTags(false));			
+		protected void getXMLtags(StringBuilder sb) {
+	   	getXMLvisualTags(sb, false);			
 		
-		if (isFixed()) {
-			sb.append("\t<fixed val=\"true\"/>\n");	
-		}
+	   	getXMLfixedTag(sb);
 		
 		if (isLaTeX) {
 			sb.append("\t<isLaTeX val=\"true\"/>\n");	
 		}
 		
 		// font settings
-		if (serifFont || fontSize != 0 || fontStyle != 0) {
+		if (serifFont || fontSize != 0 || fontStyle != 0 || isLaTeX) {
 			sb.append("\t<font serif=\"");
 			sb.append(serifFont);
 			sb.append("\" size=\"");
@@ -425,19 +467,21 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 			sb.append("\"/>\n");
 		}
 						
-		sb.append(getBreakpointXML());
+		getBreakpointXML(sb);
+		
+		getAuxiliaryXML(sb);
 
 		// store location of text (and possible labelOffset)
 		sb.append(getXMLlocation());			
-			
-	   return sb.toString();   
+		getScriptTags(sb);
+
    	}
    	
    	/**
    	 * Returns startPoint of this text in XML notation.  	 
    	 */
    	private String getXMLlocation() {   		
-   		StringBuffer sb = new StringBuffer();   				
+   		StringBuilder sb = new StringBuilder();   				
    		
    		if (hasAbsoluteScreenLocation) {
    			sb.append("\t<absoluteScreenLocation ");			
@@ -461,8 +505,8 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
    		return sb.toString();
    	}
 
-	public void setAllVisualProperties(GeoElement geo) {
-		super.setAllVisualProperties(geo);
+	public void setAllVisualProperties(GeoElement geo, boolean keepAdvanced) {
+		super.setAllVisualProperties(geo, keepAdvanced);
 		
 		// start point of text
 		if (geo instanceof GeoText) {
@@ -535,7 +579,7 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	}
 	
 	public void setRealWorldLoc(double x, double y) {
-		GeoPoint loc = getStartPoint();
+		GeoPoint loc = (GeoPoint) getStartPoint();
 		if (loc == null) {
 			loc = new GeoPoint(cons);	
 			try {setStartPoint(loc); }
@@ -553,7 +597,7 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		if (flag) {
 			// remove startpoint
 			if (startPoint != null) {
-				startPoint.unregisterLocateable(this);				
+				startPoint.getLocateableList().unregisterLocateable(this);				
 				startPoint = null;
 			}			
 		} else {
@@ -573,6 +617,50 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	public int getFontSize() {
 		return fontSize;
 	}
+	
+	public static int getRelativeFontSize(int index) {
+		switch (index) {
+		case FONTSIZE_EXTRA_SMALL: // extra small
+			return -12;
+		case FONTSIZE_VERY_SMALL: // very small
+			return -6;
+		case FONTSIZE_SMALL: // small
+			return 0;
+		default:
+		case FONTSIZE_MEDIUM: // medium
+			return 16;
+		case FONTSIZE_LARGE: // large
+			return 32;
+		case FONTSIZE_VERY_LARGE: // very large
+			return 64;
+		case FONTSIZE_EXTRA_LARGE: // extra large
+			return 128;
+		}
+	}
+	
+	public static int getFontSizeIndex(int relativeFontSize) {
+		switch (relativeFontSize) {
+		case -12: // extra small
+			return FONTSIZE_EXTRA_SMALL;
+		case -8: // old files
+		case -6: // very small
+			return FONTSIZE_VERY_SMALL;
+		case 0: // small
+		case -2: // old files
+		case -4: // old files
+			return FONTSIZE_SMALL;
+		default: // old files (2,4,6,8)
+		case 16: // medium
+			return FONTSIZE_MEDIUM;
+		case 32: // large
+			return FONTSIZE_LARGE;
+		case 64: // very large
+			return FONTSIZE_VERY_LARGE;
+		case 128: // extra large
+			return FONTSIZE_EXTRA_LARGE;
+		}
+	}
+	
 	public void setFontSize(int size) {
 		fontSize = size;
 	}
@@ -684,37 +772,23 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 	// Michael Borcherds 2008-04-30
 	final public boolean isEqual(GeoElement geo) {
 		// return false if it's a different type
+		if (str == null) return false;
 		if (geo.isGeoText()) return str.equals(((GeoText)geo).str); else return false;
 	}
 	public void setZero() {
 		str="";
 	}
 	
-	public static Comparator compare = new Comparator() {
-	      public int compare(Object a, Object b) {
-	        GeoText itemA = (GeoText) a;
-	        GeoText itemB = (GeoText) b;
-	        int comp = itemA.getTextString().compareTo(itemB.getTextString());
-	        
-	        
-	        if (comp == 0) 
-	        	// if we return 0 for equal strings, the TreeSet deletes the equal one
-	        	return itemA.getConstructionIndex() > itemB.getConstructionIndex() ? -1 : 1;
-	        else
-	        	return comp;
-	      }
-	};
 	
 	/**
 	 * Returns a comparator for GeoText objects.
 	 * If equal, doesn't return zero (otherwise TreeSet deletes duplicates)
 	 */
-	public static Comparator getComparator() {
+	public static Comparator<GeoText> getComparator() {
 		if (comparator == null) {
-			comparator = new Comparator() {
-			      public int compare(Object a, Object b) {
-				        GeoText itemA = (GeoText) a;
-				        GeoText itemB = (GeoText) b;
+			comparator = new Comparator<GeoText>() {
+			      public int compare(GeoText itemA, GeoText itemB) {
+
 				        int comp = itemA.getTextString().compareTo(itemB.getTextString());
 				        
 				        
@@ -729,9 +803,10 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		
 		return comparator;
 	}
-	private static Comparator comparator;
-
-	public void setTemporaryPrintAccuracy() {
+	
+	private static Comparator<GeoText> comparator;
+	
+		public void setTemporaryPrintAccuracy() {
 		if (useSignificantFigures()) {
 			kernel.setTemporaryPrintFigures(printFigures);
 		}
@@ -749,4 +824,25 @@ implements Locateable, AbsoluteScreenLocateable, TextValue, TextProperties {
 		return alwaysFixed;
 	}
 
+	public boolean isVector3DValue() {
+		// TODO Auto-generated method stub
+		return false;
+	}
+	
+	final public boolean isAuxiliaryObjectByDefault() {
+		return true;
+	}
+
+	public boolean justFontSize() {
+		return false;
+	}
+	
+	public boolean isRedefineable() {
+		return true;
+	}
+	
+	
+
+
+
 }
