@@ -18,6 +18,7 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.kernel.arithmetic.ExpressionNode;
 import geogebra.kernel.arithmetic.ExpressionValue;
 import geogebra.kernel.arithmetic.ListValue;
 import geogebra.kernel.arithmetic.MyDouble;
@@ -25,25 +26,29 @@ import geogebra.kernel.arithmetic.MyList;
 import geogebra.kernel.arithmetic.NumberValue;
 import geogebra.kernel.arithmetic.ValidExpression;
 import geogebra.kernel.arithmetic.VectorValue;
-import geogebra.kernel.complex.Complex;
+import geogebra.main.Application;
+import geogebra.util.Unicode;
 
 import java.util.HashSet;
 
+import org.apache.commons.math.complex.Complex;
+
 /** 
  * 
  * @author  Markus
  * @version 
  */
-final public class GeoVec2D extends ValidExpression
-implements VectorValue {        
+final public class GeoVec2D extends ValidExpression implements MatrixTransformable, VectorValue {        
 
     public double x = Double.NaN;
     public double y = Double.NaN;    
     
-    private int mode; // POLAR or CARTESIAN   
+    private int mode; // POLAR or CARTESIAN  
+    private static GeoVec2D imaginaryUnit;
     
     private Kernel kernel;
     
+    
     /** Creates new GeoVec2D */
     public GeoVec2D(Kernel kernel) {
     	this.kernel = kernel;
@@ -71,6 +76,19 @@ implements VectorValue {
         mode = v.mode;
     }
     
+    public static GeoVec2D getImaginaryUnit(Kernel kernel) {
+    	if (imaginaryUnit == null) {
+    		imaginaryUnit = new GeoVec2D(kernel, 0, 1);
+    		imaginaryUnit.setMode(Kernel.COORD_COMPLEX);
+    	}
+    	
+    	return imaginaryUnit;
+    }
+    
+    public boolean isImaginaryUnit() {
+    	return mode == Kernel.COORD_COMPLEX && x == 0 && y == 1;
+    }
+    
 	public ExpressionValue deepCopy(Kernel kernel) {
 		return new GeoVec2D(this);
 	}   
@@ -410,12 +428,10 @@ implements VectorValue {
       //c.x = (x1 * x2 + y1 * y2)/(x2 * x2 + y2 * b.y);
       //c.y = (y1 * x2 - x1 * y2)/(x2 * x2 + y2 * b.y);
       
-      Complex out = new Complex();
-      
-      Complex.over(new Complex(a.x, a.y), new Complex(b.x, b.y), out);
-      
+      Complex out = new Complex(a.x, a.y);     
+      out = out.divide(new Complex(b.x, b.y));
       c.x = out.getReal();
-      c.y = out.getImag();
+      c.y = out.getImaginary();
     	c.setMode(Kernel.COORD_COMPLEX);
       
     }
@@ -431,99 +447,140 @@ implements VectorValue {
       //c.y = ( - x1 * y2)/(x2 * x2 + y2 * b.y);
 
     
-      Complex out = new Complex();
-      
-      Complex.over(a.getDouble(), new Complex(b.x, b.y), out);
-      
-      c.x = out.getReal();
-      c.y = out.getImag();
+        Complex out = new Complex(a.getDouble(), 0);     
+        out = out.divide(new Complex(b.x, b.y));
+        c.x = out.getReal();
+        c.y = out.getImaginary();
     	c.setMode(Kernel.COORD_COMPLEX);
 }
     
     /** c = a * b Michael Borcherds 2007-12-09 */
     final public static void complexMultiply(GeoVec2D a, GeoVec2D b, GeoVec2D c) {                                       
     	// NB temporary variables *crucial*: a and c can be the same variable
-    	double x1=a.x,y1=a.y,x2=b.x,y2=b.y;
+    	//double x1=a.x,y1=a.y,x2=b.x,y2=b.y;
     	//  do multiply
-      c.x = (x1 * x2 - y1 * y2);
-      c.y = (y2 * x1 + x2 * y1);
+      //c.x = (x1 * x2 - y1 * y2);
+      //c.y = (y2 * x1 + x2 * y1);
+    	
+    	
+      Complex out = new Complex(a.x, a.y);     
+      out = out.multiply(new Complex(b.x, b.y));
+      c.x = out.getReal();
+      c.y = out.getImaginary();
+
     	c.setMode(Kernel.COORD_COMPLEX);
     }
 
     /** c = a ^ b Michael Borcherds 2009-03-10 */
     final public static void complexPower(GeoVec2D a, NumberValue b, GeoVec2D c) {                                       
-        Complex out = new Complex();
-        
-        out = Complex.pow(new Complex(a.x, a.y), b.getDouble());
-        
+        Complex out = new Complex(a.x, a.y);     
+        out = out.pow(new Complex(b.getDouble(), 0));
         c.x = out.getReal();
-        c.y = out.getImag();
+        c.y = out.getImaginary();
       	c.setMode(Kernel.COORD_COMPLEX);
     }
 
+    /** c = sqrt(a) Michael Borcherds 2010-02-07 */
+    final public static void complexSqrt(GeoVec2D a, GeoVec2D c) {                                       
+        Complex out = new Complex(a.x, a.y);     
+        out = out.sqrt();
+        c.x = out.getReal();
+        c.y = out.getImaginary();
+      	c.setMode(Kernel.COORD_COMPLEX);
+    }
+
+    /** c = sqrt(a) Michael Borcherds 2010-02-07 */
+    final public static void complexCbrt(GeoVec2D a, GeoVec2D c) {                                       
+        Complex out = new Complex(a.x, a.y);     
+        out = out.pow(new Complex(1/3d, 0));
+        c.x = out.getReal();
+        c.y = out.getImaginary();
+      	c.setMode(Kernel.COORD_COMPLEX);
+    }
+
+    /** c = sqrt(a) Michael Borcherds 2010-02-07 */
+    final public static void complexConjugate(GeoVec2D a, GeoVec2D c) {                                       
+        Complex out = new Complex(a.x, a.y);     
+        out = out.conjugate();
+        c.x = out.getReal();
+        c.y = out.getImaginary();
+      	c.setMode(Kernel.COORD_COMPLEX);
+    }
+
+    /** c = sqrt(a) Michael Borcherds 2010-02-07 */
+    final public static double arg(GeoVec2D a) {                                       
+        return Math.atan2(a.y, a.x);
+    }
+
     /** c = a ^ b Michael Borcherds 2009-03-10 */
     final public static void complexPower(NumberValue a, GeoVec2D b, GeoVec2D c) {                                       
-        Complex out = new Complex();
-        
-        out = Complex.pow(new Complex(a.getDouble(), 0.0), new Complex(b.x, b.y));
-        
+        Complex out = new Complex(a.getDouble(), 0);     
+        out = out.pow(new Complex(b.x, b.y));
         c.x = out.getReal();
-        c.y = out.getImag();
+        c.y = out.getImaginary();
       	c.setMode(Kernel.COORD_COMPLEX);
     }
 
     /** c = e ^ a Michael Borcherds 2009-03-10 */
     final public static void complexExp(GeoVec2D a, GeoVec2D c) {                                       
-        Complex out = new Complex();
-        
-        out = Complex.exp(new Complex(a.x, a.y));
-        
+        Complex out = new Complex(a.x, a.y);     
+        out = out.exp();
         c.x = out.getReal();
-        c.y = out.getImag();
+        c.y = out.getImaginary();
       	c.setMode(Kernel.COORD_COMPLEX);
     }
 
     /** c = natural log(a) Michael Borcherds 2009-03-10 */
     final public static void complexLog(GeoVec2D a, GeoVec2D c) {                                       
-        Complex out = new Complex();
-        
-        out = Complex.log(new Complex(a.x, a.y));
-        
+        Complex out = new Complex(a.x, a.y);     
+        out = out.log();
         c.x = out.getReal();
-        c.y = out.getImag();
+        c.y = out.getImaginary();
       	c.setMode(Kernel.COORD_COMPLEX);
     }
 
-    /** c = natural log(a) Michael Borcherds 2009-03-10 */
+    /** c = abs(a) Michael Borcherds 2009-03-10 */
     final public static double complexAbs(GeoVec2D a) {                                       
-                
-        return Complex.abs(new Complex(a.x, a.y));
+        Complex out = new Complex(a.x, a.y);     
+
+        return out.abs();
     }
 
     /** c = a ^ b Michael Borcherds 2009-03-14 */
     final public static void complexPower(GeoVec2D a, GeoVec2D b, GeoVec2D c) {                                       
-        Complex out = new Complex();
-        
-        out = Complex.pow(new Complex(a.x, a.y), new Complex(b.x, b.y));
-        
+        Complex out = new Complex(a.x, a.y);     
+        out = out.pow(new Complex(b.x, b.y));
         c.x = out.getReal();
-        c.y = out.getImag();
+        c.y = out.getImaginary();
       	c.setMode(Kernel.COORD_COMPLEX);
     }
 
     /** c = a * b Michael Borcherds 2007-12-09 */
     final public static void complexMultiply(GeoVec2D a, NumberValue b, GeoVec2D c) {                                       
     	// NB temporary variables *crucial*: a and c can be the same variable
-    	double x1=a.x,y1=a.y,x2=b.getDouble();
+    	//double x1=a.x,y1=a.y,x2=b.getDouble();
     	//  do multiply
-      c.x = (x1 * x2);
-      c.y = (x2 * y1);
+      //c.x = (x1 * x2);
+      //c.y = (x2 * y1);
+        Complex out = new Complex(a.x, a.y);     
+        out = out.multiply(new Complex(b.getDouble(), 0));
+        c.x = out.getReal();
+        c.y = out.getImaginary();
+
     	c.setMode(Kernel.COORD_COMPLEX);
     }
 
     final public static void inner(GeoVec2D a, GeoVec2D b, double c) {
         c = a.x * b.x + a.y * b.y;        
-    }       
+    }   
+
+    /*
+     * see also GeoVec3D.vectorProduct()
+     */
+    final public static void vectorProduct(GeoVec2D a, GeoVec2D b, MyDouble c) {
+        c.set(a.x * b.y - a.y * b.x);        
+    }           
+    
     
     final public static void inner(GeoVec2D a, GeoVec2D b, MyDouble c) {
         c.set(a.x * b.x + a.y * b.y);        
@@ -539,7 +596,20 @@ implements VectorValue {
 		return !(Double.isNaN(x) || Double.isNaN( y));
 	}
     
-    final public String toString() {          
+    final public String toString() {
+    	if (isImaginaryUnit()){
+    		switch (kernel.getCASPrintForm()){
+    			case ExpressionNode.STRING_TYPE_MPREDUCE:
+    				return "i";
+    				
+    			default:
+//    			case ExpressionNode.STRING_TYPE_GEOGEBRA:
+//    			case ExpressionNode.STRING_TYPE_GEOGEBRA_XML:
+//    			case ExpressionNode.STRING_TYPE_LATEX:
+    				return Unicode.IMAGINARY;
+    		}
+    	}
+    	
 		sbToString.setLength(0);
 		sbToString.append('(');
 		sbToString.append(kernel.format(x));
@@ -548,13 +618,16 @@ implements VectorValue {
 		sbToString.append(')');         
         return sbToString.toString();
     }         
-	private StringBuffer sbToString = new StringBuffer(50);
+	private StringBuilder sbToString = new StringBuilder(50);
     
     /**
      * interface VectorValue implementation
      */           
     final public GeoVec2D getVector() {
-        return this;
+    	if (this.isImaginaryUnit()) 
+    		return new GeoVec2D(this);
+    	else 
+    		return this;
     }        
         
     final public boolean isConstant() {
@@ -569,9 +642,11 @@ implements VectorValue {
         return  mode;
     }        
     
-    final public ExpressionValue evaluate() { return this; }
+    final public ExpressionValue evaluate() { 
+    	return getVector(); 
+    }
     
-    final public HashSet getVariables() { return null; }
+    final public HashSet<GeoElement> getVariables() { return null; }
     
     final public void setMode(int mode) {
         this.mode = mode;
@@ -650,13 +725,22 @@ implements VectorValue {
 			c = ((NumberValue)(MyList.getCell(list,0,1).evaluate())).getDouble();
 			d = ((NumberValue)(MyList.getCell(list,1,1).evaluate())).getDouble();
 	 
-			x1 = a*x + b*y;
-			y1 = c*x + d*y;
-			x=x1;
-			y=y1;
-			return;
+			matrixTransform(a,b,c,d);
+	 }
+	 public void matrixTransform(double a,double b,double c,double d) {
+		 
+			Double x1 = a*x + b*y;
+			Double y1 = c*x + d*y;
+
+			x=x1; 
+			y=y1;		
+	 }
+	 public boolean isMatrixTransformable(){
+		 return true;
+	 }
+	 public GeoElement toGeoElement(){
+		 return null;
 	 }
-	 
 	 /** multiplies 2D vector by a 3x3 affine matrix
 	  *  a b c
 	  *  d e f
@@ -670,13 +754,24 @@ implements VectorValue {
 		 
 			double a,b,c,d,e,f,g,h,i,x1,y1,z1,xx = x, yy = y, zz = 1;
 			
-			// use homogeneous coordinates if available
-			if (rt instanceof GeoVec3D) {
+			boolean vector = false;
+			
+			if ((rt instanceof GeoPoint) || (rt instanceof GeoLine)) {
 				GeoVec3D p = (GeoVec3D)rt;
+				// use homogeneous coordinates if available
 				xx = p.x;
 				yy = p.y;
 				zz = p.z;
-			} 
+			} else if (rt.isVectorValue()) {
+				GeoVec2D v = ((VectorValue)rt).getVector();
+				xx = v.x;
+				yy = v.y;
+				
+				// consistent with 3D vectors
+				zz = 0; 
+				vector = true;
+				
+			} else Application.debug("error in GeoVec2D");
 			
 			a = ((NumberValue)(MyList.getCell(list,0,0).evaluate())).getDouble();
 			b = ((NumberValue)(MyList.getCell(list,1,0).evaluate())).getDouble();
@@ -687,16 +782,62 @@ implements VectorValue {
 			g = ((NumberValue)(MyList.getCell(list,0,2).evaluate())).getDouble();
 			h = ((NumberValue)(MyList.getCell(list,1,2).evaluate())).getDouble();
 			i = ((NumberValue)(MyList.getCell(list,2,2).evaluate())).getDouble();
-	 
-			x1 = a * xx + b * yy + c * zz;
-			y1 = d * xx + e * yy + f * zz;
+			
+			x = a * xx + b * yy + c * zz;
+			y = d * xx + e * yy + f * zz;
 			z1 = g * xx + h * yy + i * zz;
-			x=x1 / z1;
-			y=y1 / z1;
+			
+			if (!vector) {
+				x=x / z1;
+				y=y / z1;
+			} else {
+				if (!Kernel.isZero(z1)) {
+					// for a Vector, if z1!=0 then the answer can't be represented by a 2D vector
+					// so set undefined
+					// won't happen when 3rd row of matrix is (0,0,1)
+					x = Double.NaN;
+					y = Double.NaN;
+				}
+			}
+			
 			return;
 	 }
-		public void setZero() {
+	 
+	 public void setZero() {
 			x=0;
 			y=0;
 		}
+
+		public boolean isVector3DValue() {
+			// TODO Auto-generated method stub
+			return false;
+		}
+		
+		public String toOutputValueString() {
+			return toValueString();
+		}
+
+		public void matrixTransform(double a00, double a01, double a02,
+				double a10, double a11, double a12, double a20, double a21,
+				double a22) {
+			
+			double	xx = x;
+			double	yy = y;
+			double	zz = 1;
+			
+	 
+			double x1 = a00 * xx + a01 * yy + a02 * zz;
+			double y1 = a10 * xx + a11 * yy + a12 * zz;
+			double z1 = a20 * xx + a21 * yy + a22 * zz;
+			x=x1 / z1;
+			y=y1 / z1;
+			return;
+			
+		}
+		
+		public Kernel getKernel() {
+			return kernel;
+		}
+
+		
 }
