@@ -1,23 +1,25 @@
 package geogebra.kernel;
 
+import geogebra.kernel.kernelND.GeoPointND;
+
 
 /**
  * Interface for GeoElements that have a start point (GeoText, GeoVector)
  */
 public interface Locateable {
-	public void setStartPoint(GeoPoint p) throws CircularDefinitionException;
-	public void removeStartPoint(GeoPoint p);	
-	public GeoPoint getStartPoint();
+	public void setStartPoint(GeoPointND p) throws CircularDefinitionException;
+	public void removeStartPoint(GeoPointND p);	
+	public GeoPointND getStartPoint();
 		
 	// GeoImage has three startPoints (i.e. corners)
-	public void setStartPoint(GeoPoint p, int number) throws CircularDefinitionException;
-	public GeoPoint [] getStartPoints();
+	public void setStartPoint(GeoPointND p, int number) throws CircularDefinitionException;
+	public GeoPointND [] getStartPoints();
 	
 	/**
 	 * Sets the startpoint without performing any checks.
 	 * This is needed for macros.	 
 	 */
-	public void initStartPoint(GeoPoint p, int number);
+	public void initStartPoint(GeoPointND p, int number);
 	
 	public boolean hasAbsoluteLocation();
 	
