@@ -14,6 +14,7 @@ package geogebra.kernel;
 
 import geogebra.GeoGebra;
 import geogebra.kernel.arithmetic.ExpressionNode;
+import geogebra.kernel.kernelND.GeoPointND;
 import geogebra.main.Application;
 import geogebra.main.MyError;
 import geogebra.util.Util;
@@ -21,6 +22,7 @@ import geogebra.util.Util;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.LinkedList;
+import java.util.Set;
 import java.util.TreeSet;
 
 /**
@@ -43,11 +45,16 @@ public class Macro {
 	private String [] macroInputLabels, macroOutputLabels;
 	private Class [] inputTypes;
 	
-	private LinkedList usingAlgos = new LinkedList();	
+	private LinkedList<AlgoElement> usingAlgos = new LinkedList<AlgoElement>();	
 		
 	/**
 	 * Creates a new macro 
-	 * using the given input and output GeoElements.		  
+	 * using the given input and output GeoElements.
+	 * @param kernel Kernel
+	 * @param cmdName Command name
+	 * @param input Array of input objects
+	 * @param output Array of output objects
+	 * @throws Exception if	macro initialization fails (unnecessary input,	independent output)  
 	 */
 	public Macro(Kernel kernel, String cmdName,  
 					GeoElement [] input, GeoElement [] output) 
@@ -59,21 +66,34 @@ public class Macro {
 	/**
 	 * Creates a new macro. Note: you need to call initMacro() when using
 	 * this constructor.
+	 * @param kernel Kernel
+	 * @param cmdName Command name
 	 */
 	public Macro(Kernel kernel, String cmdName) { 	
 		this.kernel = kernel;
-		setCommandName(cmdName);						
+		setCommandName(cmdName);	
+		copyCaptions = true;
 	}		
 	
 	/**
 	 * Returns all input geos from the macro construction.
+	 * @return all input geos from the macro construction.
 	 */
 	public GeoElement [] getMacroInput() {
 		return macroInput;
 	}
 	
+	/**
+	 * Returns kernel
+	 * @return kernel
+	 */
+	public Kernel getKernel(){
+		return kernel;
+	}
+	
 	/**
 	 * Returns all output geos from the macro construction.
+	 * @return Array of output elements
 	 */
 	public GeoElement [] getMacroOutput() {
 		return macroOutput;
@@ -81,6 +101,8 @@ public class Macro {
 	
 	/**
 	 * Returns whether geo is part of this macro's construction.
+	 * @param geo Geo to be found in construction
+	 * @return true iff geo is part of this macro's construction.
 	 */
 	final public boolean isInMacroConstruction(GeoElement geo) {
 		return geo.cons == macroCons;
@@ -88,11 +110,18 @@ public class Macro {
 	
 	/**
 	 * Returns the construction object of this macro.
+	 * @return construction object of this macro.
 	 */
 	public Construction getMacroConstruction() {
 		return macroCons;
 	}		
 
+	/**
+	 * Initiates macro
+	 * @param macroCons
+	 * @param inputLabels
+	 * @param outputLabels
+	 */
 	public void initMacro(Construction macroCons, String [] inputLabels, String [] outputLabels) {				
 		this.macroCons = macroCons;
 		//this.macroConsXML = macroCons.getConstructionXML();
@@ -121,27 +150,24 @@ public class Macro {
 		for (int i=0; i < macroInputLabels.length; i++) {    		
 			macroInput[i] = macroCons.lookupLabel(macroInputLabels[i]);  
 			macroInput[i].setFixed(false);						
-			//Application.debug("macroInput[" + i + "] = " + macroInput[i]);
     	}
 		
     	for (int i=0; i < macroOutputLabels.length; i++) {    		
     		macroOutput[i] = macroCons.lookupLabel(macroOutputLabels[i]);            		    		    		    	
-			//Application.debug("macroOutput[" + i + "] = " + macroOutput[i]);
     	}         		
 	}
 	
 	private void initMacro(GeoElement [] input, GeoElement [] output)  throws Exception {
 		// check that every output object depends on an input object
 		// and that all input objects are really needed
-		boolean [] inputNeeded = new boolean[input.length];
+		
 		for (int i=0; i < output.length; i++) {
 			boolean dependsOnInput = false;
 			
 			for (int k=0; k < input.length; k++) {
 				boolean dependencyFound = output[i].isChildOf(input[k]);
 				if (dependencyFound) {
-					dependsOnInput = true; 
-					inputNeeded[k] = true;
+					dependsOnInput = true; 					
 				}
 			}
 			
@@ -150,16 +176,10 @@ public class Macro {
 						.getError("Tool.OutputNotDependent") +
 						": " + output[i].getNameDescription());
 			}
-		}	
-		for (int k=0; k < input.length; k++) {			
-			if (!inputNeeded[k]) {
-				throw new Exception(kernel.getApplication()
-						.getError("Tool.InputNotNeeded") +
-						": " + input[k].getNameDescription());
-			}
 		}
 		
 		
+		
 		// steps to create a macro
 		// 1) outputAndParents = set of all predecessors of output objects 
 		// 2) inputChildren = set of all children of input objects
@@ -169,7 +189,7 @@ public class Macro {
 		// 6) create a new macro-construction from this XML representation
 		
 		// 1) create the set of all parents of this macro's output objects				
-		TreeSet outputParents = new TreeSet();		
+		TreeSet<GeoElement> outputParents = new TreeSet<GeoElement>();		
 		for (int i=0; i < output.length; i++) {
 			 output[i].addPredecessorsToSet(outputParents, false);
 			 
@@ -177,25 +197,25 @@ public class Macro {
 			 //       these points must be part of the macro construction
 			 if (output[i] instanceof Locateable) {
 				 Locateable loc = (Locateable) output[i];
-				 GeoPoint [] points = loc.getStartPoints();
+				 GeoPointND [] points = (GeoPointND[]) loc.getStartPoints();
 				 if (points != null) {
 					 for (int k=0; k < points.length; k++) {
-						 outputParents.add(points[k]);
-						 points[k].addPredecessorsToSet(outputParents, false);
+						 outputParents.add((GeoElement) points[k]);
+						 ((GeoElement) points[k]).addPredecessorsToSet(outputParents, false);
 					 }
 				 }
 			 }
 		}			
-		
 		// 2) and 3) get intersection of inputChildren and outputParents				
-		TreeSet macroConsOrigElements = new TreeSet(); 
-    	Iterator it = outputParents.iterator();    	
+		TreeSet<ConstructionElement> macroConsOrigElements = new TreeSet<ConstructionElement>();
+		TreeSet<Long> usedAlgoIds = new TreeSet<Long>();
+    	Iterator<GeoElement> it = outputParents.iterator();    	
     	while (it.hasNext()) {
-    		GeoElement outputParent = (GeoElement) it.next();
+    		GeoElement outputParent = it.next();
     		if (outputParent.isLabelSet()) {
     			for (int i=0; i < input.length; i++) {
     				 if (outputParent.isChildOf(input[i])) {
-    					 addDependentElement(outputParent, macroConsOrigElements);    					    			    	 
+    					 addDependentElement(outputParent, macroConsOrigElements,usedAlgoIds);    					    			    	 
     			    	 // add parent only once: get out of loop
     					 i = input.length; 
     				 }
@@ -210,13 +230,17 @@ public class Macro {
     	boolean [] isOutputLabeled = new boolean[output.length];
     	String [] inputLabels = new String[input.length];
     	String [] outputLabels = new String[output.length];
-    	
+    	GeoPointND[] startPoints = new GeoPointND[input.length];
     	for (int i=0; i < input.length; i++) {
     		isInputLabeled[i] = input[i].isLabelSet();
     		if (!isInputLabeled[i]) {
     			input[i].label = input[i].getDefaultLabel();
     			input[i].labelSet = true;
-        	}    		        		    			    		        	    	
+        	}    		     
+    		if(input[i] instanceof GeoVector){
+    			startPoints[i]=((GeoVector)input[i]).getStartPoint();
+    			((GeoVector)input[i]).setStartPoint(null);
+    		}
     		inputLabels[i] = input[i].label;
     		    	
     		// add input element to macroConsOrigElements
@@ -225,7 +249,9 @@ public class Macro {
     			case GeoElement.GEO_CLASS_SEGMENT:    				
     			case GeoElement.GEO_CLASS_RAY:
     			case GeoElement.GEO_CLASS_POLYGON:
-    			case GeoElement.GEO_CLASS_FUNCTION:    			
+    			case GeoElement.GEO_CLASS_FUNCTION:
+    			case GeoElement.GEO_CLASS_INTERVAL:
+    			case GeoElement.GEO_CLASS_CURVE_CARTESIAN://added by Zbynek Konecny, 2010-05-25 (http://www.geogebra.org/forum/viewtopic.php?t=7275)
     				// add parent algo and its input objects to macroConsOrigElements
     				addSpecialInputElement(input[i], macroConsOrigElements);
     				break;    				    			
@@ -241,7 +267,6 @@ public class Macro {
     		}
     		
     	}   
-    	
     	for (int i=0; i < output.length; i++) {
     		isOutputLabeled[i] = output[i].isLabelSet();
     		if (!isOutputLabeled[i]) {
@@ -251,7 +276,7 @@ public class Macro {
     		outputLabels[i] = output[i].label;
     		
     		// add output element and its algorithm to macroConsOrigElements 
-    		addDependentElement(output[i], macroConsOrigElements); 	    		
+    		addDependentElement(output[i], macroConsOrigElements,usedAlgoIds); 	    		
     	}    	    	
     	    	
 		// 5) create XML representation for macro-construction
@@ -260,13 +285,16 @@ public class Macro {
     	// if we used temp labels in step (4) remove them again
     	for (int i=0; i < input.length; i++) {    		
     		if (!isInputLabeled[i]) 
-    			input[i].labelSet = false;        	    		
+    			input[i].labelSet = false;
+    		if(input[i] instanceof GeoVector){
+    			((GeoVector)input[i]).setStartPoint(startPoints[i]);
+    		}
     	}    	    
     	for (int i=0; i < output.length; i++) {    		
     		if (!isOutputLabeled[i])		
     			output[i].labelSet = false;        
     	}    	    	    	    	    
-    	
+    	Application.debug(macroConsXML);
 		// 6) create a new macro-construction from this XML representation
     	Construction macroCons = createMacroConstruction(macroConsXML); 
     	    	
@@ -276,14 +304,19 @@ public class Macro {
 	
 	/**
 	 * Adds the geo, its parent algorithm and all its siblings to the consElementSet
+	 * and its id to used AlgoIds
+	 * @param geo Element to be added (with parent and siblings)
+	 * @param consElementSet Set of geos & algos used in macro construction
+	 * @param usedAlgoIds Set of IDs of algorithms used in macro construction
 	 */	
-	public static void addDependentElement(GeoElement geo, TreeSet consElementSet) {		 
+	public static void addDependentElement(GeoElement geo, Set<ConstructionElement> consElementSet,Set<Long> usedAlgoIds) {		 
 		 AlgoElement algo = geo.getParentAlgorithm();
-		 
-	   	 if (algo.isInConstructionList()) {
+		 if (algo.isInConstructionList()) {
 	   		// STANDARD case
 	   		// add algorithm
-	   		consElementSet.add(algo);
+			Long algoID = new Long(algo.getID()); 
+	   		if(!usedAlgoIds.contains(algoID))consElementSet.add(algo);
+	   			usedAlgoIds.add(algoID);
 	   		
 	   		// add all output elements including geo
 	   		GeoElement [] algoOutput = algo.getOutput();
@@ -302,8 +335,10 @@ public class Macro {
 	 * Adds the geo, its parent algorithm and all input of the parent algorithm to the consElementSet.
 	 * This is used for e.g. a segment that is used as an input object of a macro. We also need to
 	 * have the segment's start and endpoint.
+	 * @param geo
+	 * @param consElementSet
 	 */	
-	public static void addSpecialInputElement(GeoElement geo, TreeSet consElementSet) {		 
+	public static void addSpecialInputElement(GeoElement geo, Set<ConstructionElement> consElementSet) {		 
 		 // add geo
 		 consElementSet.add(geo);
 		 
@@ -325,45 +360,39 @@ public class Macro {
 	
 	/**
 	 * Note: changes macroConsElements
-	 * @param input
+	 * @param kernel
 	 * @param macroConsElements
-	 * @return
+	 * @return XML string of macro construction
 	 */
-	 public static String buildMacroXML(Kernel kernel, TreeSet macroConsElements) {	
+	 public static String buildMacroXML(Kernel kernel, Set<ConstructionElement> macroConsElements) {	
 		// change kernel settings temporarily
 		int oldCoordStlye = kernel.getCoordStyle();
-		int oldDecimals = kernel.getPrintDecimals();
 		int oldPrintForm = kernel.getCASPrintForm();        
 	    kernel.setCoordStyle(Kernel.COORD_STYLE_DEFAULT);                 		
 	    kernel.setCASPrintForm(ExpressionNode.STRING_TYPE_GEOGEBRA_XML);
 		 
     	// get the XML for all macro construction elements
-    	StringBuffer macroConsXML = new StringBuffer(500);
+    	StringBuilder macroConsXML = new StringBuilder(500);
     	macroConsXML.append("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n");
     	macroConsXML.append("<geogebra format=\"" + GeoGebra.XML_FILE_FORMAT  + "\">\n");
     	macroConsXML.append("<construction author=\"\" title=\"\" date=\"\">\n");
     	     	    	      	
-    	Iterator it = macroConsElements.iterator();
+    	Iterator<ConstructionElement> it = macroConsElements.iterator();
     	while (it.hasNext()) {    		
-    		ConstructionElement ce = (ConstructionElement) it.next();    		    		
+    		ConstructionElement ce = it.next();    		    		
     		
     		if (ce.isGeoElement()) {
-    			macroConsXML.append(ce.getXML());
+    			ce.getXML(macroConsXML);
     		}
     		else if (ce.isAlgoElement()) {
     			AlgoElement algo = (AlgoElement) ce;
-        		macroConsXML.append(algo.getXML(false));    			
+    			algo.getXML(macroConsXML, false);    			
     		}
     	}
     	
     	macroConsXML.append("</construction>\n");
     	macroConsXML.append("</geogebra>");
-    	   
-//    	Application.debug("*** Macro XML BEGIN ***");
-//    	Application.debug(macroConsXML);
-//    	System.out.flush();
-//    	Application.debug("*** Macro XML END ***"); 
-    	
+    	   	
     	 // restore old kernel settings
         kernel.setCoordStyle(oldCoordStlye);   
         kernel.setCASPrintForm(oldPrintForm);
@@ -403,11 +432,18 @@ public class Macro {
     	return mk.getConstruction();
     }	 	                 
 			
-	
+	/**
+	 * Add link to algo using this macro 
+	 * @param algoMacro
+	 */
 	public void registerAlgorithm(AlgoMacro algoMacro) {						
 		usingAlgos.add(algoMacro);			
 	}
 	
+	/**
+	 * Remove link to algo using this macro 
+	 * @param algoMacro
+	 */
 	public void unregisterAlgorithm(AlgoMacro algoMacro) {
 		usingAlgos.remove(algoMacro);			
 	}		
@@ -415,12 +451,15 @@ public class Macro {
 	/**
 	 * Returns whether this macro is being used by algorithms
 	 * in the current construction.
+	 * @return true iff this macro is being used by algorithms in the current construction
 	 */
 	final public boolean isUsed() {	
 		return usingAlgos.size() >  0;
 	}
 	
-	
+	/**
+	 * Removes links to all algos using this macro 
+	 */
 	final public void setUnused() {	
 		usingAlgos.clear();
 	}
@@ -429,11 +468,16 @@ public class Macro {
 	 * Returns the types of input objects of the default macro construction.
 	 * This can be used to check whether a given GeoElement array can be used
 	 * as input for this macro.
+	 * @return types of input objects
 	 */
 	final public Class [] getInputTypes() {	
 		return inputTypes;
 	}			
 	
+	/**
+	 * Returns the tool help 
+	 * @return tool help
+	 */
 	public String getToolHelp() {		
 		return toolHelp;				
 	}
@@ -441,9 +485,10 @@ public class Macro {
 	
 	/**
 	 * Returns a String showing all needed types of this macro.
+	 * @return string showing all needed types of this macro.
 	 */
 	public String getNeededTypesString() {
-		StringBuffer sb = new StringBuffer();			
+		StringBuilder sb = new StringBuilder();			
         sb.append(macroInput[0].translatedTypeString());	       
         for (int i = 1; i < macroInput.length; ++i) {
             sb.append(", ");	            
@@ -452,6 +497,10 @@ public class Macro {
 		return sb.toString();				
 	}
 
+	/**
+	 * Sets tool help.
+	 * @param toolHelp Tool help. Either "","null" or null for empty.
+	 */
 	public void setToolHelp(String toolHelp) {
 		if (toolHelp == null || toolHelp.equals("null"))
 			this.toolHelp = "";
@@ -459,19 +508,35 @@ public class Macro {
 			this.toolHelp = toolHelp;
 	}
 
+	/**
+	 * Returns command name
+	 * @return Command name
+	 */
 	public String getCommandName() {
 		return cmdName;
 	}
 
+	/**
+	 * Sets commandd name
+	 * @param name Command name
+	 */
 	public void setCommandName(String name) {
 		if (name != null)
 			this.cmdName = name;
 	}
 
+	/**
+	 * Returns tool name
+	 * @return Tool name
+	 */
 	public String getToolName() {		
 		return toolName;
 	}
 	
+	/**
+	 * Returns toolname, if empty, returns command name.
+	 * @return Toolname, if empty, returns command name.
+	 */
 	public String getToolOrCommandName() {
 		if (!"".equals(toolName)) 
 			return toolName;
@@ -479,6 +544,10 @@ public class Macro {
 			return cmdName;			
 	}
 
+	/**
+	 * Sets tool name
+	 * @param name new tool name
+	 */
 	public void setToolName(String name) {
 		if (name == null || name.equals("null") || name.length() == 0)
 			this.toolName = cmdName;
@@ -486,6 +555,10 @@ public class Macro {
 			this.toolName = name;
 	}
 	
+	/**
+	 * Sets icon filename
+	 * @param name Icon filename, "" or null for empty
+	 */
 	public void setIconFileName(String name) {
 		if (name == null)
 			this.iconFileName = "";
@@ -493,6 +566,10 @@ public class Macro {
 			this.iconFileName = name;
 	}
 	
+	/**
+	 * Returns icon filename
+	 * @return icon filename
+	 */
 	public String getIconFileName() {
 		return iconFileName;
 	}
@@ -501,7 +578,7 @@ public class Macro {
 	 * Returns the syntax descriptiont of this macro.
 	 */
 	public String toString() {
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 		sb.append(cmdName);
         sb.append("[ ");
                
@@ -522,11 +599,11 @@ public class Macro {
 	
 	
 	/**
-	 * Returns XML representation of this macro for
-	 * saving in a ggb file.
+	 * Adds XML representation of this macro for
+	 * saving in a ggb file to given string builder.
+	 * @param sb StringBuilder for adding the macro representation
 	 */
-    public String getXML() {      
-        StringBuffer sb = new StringBuffer();               
+    public void getXML(StringBuilder sb) {               
         sb.append("<macro cmdName=\"");
         sb.append(Util.encodeXML(cmdName));         
         sb.append("\" toolName=\"");
@@ -536,7 +613,9 @@ public class Macro {
         sb.append("\" iconFile=\""); 
         sb.append(Util.encodeXML(iconFileName));  
         sb.append("\" showInToolBar=\"");
-        sb.append(showInToolBar);  
+        sb.append(showInToolBar);
+        sb.append("\" copyCaptions=\"");
+        sb.append(copyCaptions);  
 		sb.append("\">\n");
     			        
         // add input labels
@@ -565,22 +644,71 @@ public class Macro {
         
         // macro construction XML
        // sb.append(macroConsXML);
-        sb.append(macroCons.getConstructionXML());
+        macroCons.getConstructionXML(sb);
         
         sb.append("</macro>\n");           
-        return sb.toString();
     }
 
+    /**
+	 * Returns whether this macro should be shown in toolbar
+	 * @return true iff this macro should be shown in toolbar
+	 */
 	public final boolean isShowInToolBar() {
 		return showInToolBar;
 	}
 
+	/**
+	 * Sets whether this macro should be shown in toolbar
+	 * @param showInToolBar true iff this macro should be shown in toolbar
+	 */
 	public final void setShowInToolBar(boolean showInToolBar) {
 		this.showInToolBar = showInToolBar;
 	}
 	
-	public ArrayList getUsedMacros() {
+	/**
+	 * Returns list of macros used by this one
+	 * @return list of macros used by this one
+	 */
+	public ArrayList<Macro> getUsedMacros() {
 		return macroCons.getUsedMacros();
 	}
-		  
+	
+	/**
+	 * Returns list of geos created using this macro
+	 * @return list of geos created using this macro
+	 */
+	public ArrayList<GeoElement> getDependentGeos(){
+		ArrayList<GeoElement> geos = new ArrayList<GeoElement>();
+		Iterator<AlgoElement> curr = usingAlgos.iterator();
+		while(curr.hasNext()){
+			AlgoElement algo=curr.next();
+			
+			//seek for the first visible geo
+			GeoElement geo = algo.getOutput(0);
+			while(!geo.labelSet && geo.getAllChildren().size()>0){
+				geo=geo.getAllChildren().first();
+			}
+
+			//add that geo and its siblings
+			algo=geo.getParentAlgorithm();
+			for(int i = 0; i < algo.getOutputLength(); i++){
+				geos.add(algo.getOutput(i));
+			}
+		}
+		return geos;
+	}
+	private boolean copyCaptions;
+	/**
+	 * Set whether the macro should copy captions of resulting objects
+	 * @param copyCaptions true to copy
+	 */
+	public void setCopyCaptionsAndVisibility(boolean copyCaptions) {
+		this.copyCaptions=copyCaptions;
+	}
+	/**
+	 * @return true if the macro copies captions of resulting objects
+	 */
+	public boolean isCopyCaptionsAndVisibility() {
+		return copyCaptions;
+	}
 }
