@@ -13,10 +13,11 @@ the Free Software Foundation.
 package geogebra.kernel;
 
 
+
 public class MyPoint {
 	public double x, y;
 	public boolean lineTo;
-	
+
 	public MyPoint(double x, double y, boolean lineTo) {
 		this.x = x;
 		this.y = y;
@@ -37,4 +38,12 @@ public class MyPoint {
 	public String toString() {
 		return "(" + x + ", " + y + ")";
 	}
+
+	public double distance(MyPoint p) {
+		return GeoVec2D.length(p.x - x, p.y - y);
+	}
+
+	public GeoPoint getGeoPoint(Construction cons) {
+		return new GeoPoint(cons, null, x, y, 1.0);
+	}
 }
