@@ -18,12 +18,16 @@ package geogebra.kernel;
 public class PathParameter {
 	
 	double t;
-	int pathType = -1;
+	private int pathType = -1;
 	
 	public PathParameter() {
 		t = Double.NaN;
 	}
 	
+	public PathParameter(PathParameter pp){
+		set(pp);
+	}
+	
 	public PathParameter(double t) {
 		this.t = t;
 	}
