@@ -12,8 +12,25 @@ the Free Software Foundation.
 
 package geogebra.kernel;
 
+import geogebra.Matrix.Coords;
+/**
+ * Represents geos that can be translated 
+ *
+ */
 public interface Translateable {
-	public void translate(GeoVector v);
+	/**
+	 * Translate by vector
+	 * @param v translation vector
+	 */
+	public void translate(Coords v);
+	/**
+	 * Return the geo
+	 * @return geo element
+	 */
 	public GeoElement toGeoElement();
+	/**
+	 * Returns true if the element is translateable
+	 * @return true
+	 */
 	public boolean isTranslateable();
 }
