@@ -35,7 +35,7 @@ import java.util.Set;
  * @version 
  */
 public class Command extends ValidExpression 
-implements ReplaceableValue {
+implements ReplaceableValue, ReplaceChildrenByValues {
     
      
     // list of arguments
