@@ -32,6 +32,7 @@ import geogebra.main.Application;
 import geogebra.main.MyError;
 import geogebra.util.Unicode;
 
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
@@ -728,7 +729,7 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 	 * 
 	 * @return number of replacements done
 	 */
-	int replaceXYZnodes(FunctionVariable xVar, FunctionVariable yVar, FunctionVariable zVar) {
+	int replaceXYZnodes(FunctionVariable xVar, FunctionVariable yVar, FunctionVariable zVar, ArrayList<ExpressionNode> undecided) {
 		if ((xVar == null) && ((yVar == null) & (zVar == null))) {
 			return 0;
 		}
@@ -736,18 +737,18 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 		// left tree
 		int replacements = 0;
 		if (left.isExpressionNode()) {
-			replacements += ((ExpressionNode) left).replaceXYZnodes(xVar, yVar, zVar);
+			replacements += ((ExpressionNode) left).replaceXYZnodes(xVar, yVar, zVar,undecided);
 		}
 		// right tree
 		if ((right != null) && right.isExpressionNode()) {
-			replacements += ((ExpressionNode) right).replaceXYZnodes(xVar, yVar, zVar);
+			replacements += ((ExpressionNode) right).replaceXYZnodes(xVar, yVar, zVar,undecided);
 		}
 
 		switch (operation) {
 		case XCOORD:
 			if (xVar != null) {
-				replacements++;
-				operation = MULTIPLY;
+				undecided.add(this);
+				operation = MULTIPLY_OR_FUNCTION;
 				right = left;
 				left = xVar;
 			}
@@ -755,8 +756,8 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 
 		case YCOORD:
 			if (yVar != null) {
-				replacements++;
-				operation = MULTIPLY;
+				undecided.add(this);
+				operation = MULTIPLY_OR_FUNCTION;
 				right = left;
 				left = yVar;
 			}
@@ -764,12 +765,27 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 
 		case ZCOORD:
 			if (zVar != null) {
-				replacements++;
-				operation = MULTIPLY;
+				undecided.add(this);
+				operation = MULTIPLY_OR_FUNCTION;
 				right = left;
 				left = zVar;
 			}
 			break;
+		case POWER:
+			if(left.isExpressionNode() && ((ExpressionNode)left).operation == MULTIPLY_OR_FUNCTION){
+				right = new ExpressionNode(kernel,((ExpressionNode)left).getRight(), POWER, right);
+				left = ((ExpressionNode)left).getLeft();
+				operation = MULTIPLY;
+			}
+			break;
+			
+		case FACTORIAL:
+			if(left.isExpressionNode() && ((ExpressionNode)left).operation == MULTIPLY_OR_FUNCTION){
+				right = new ExpressionNode(kernel,((ExpressionNode)left).getRight(), FACTORIAL, null);
+				left = ((ExpressionNode)left).getLeft();
+				operation = MULTIPLY;
+			}
+
 		}
 
 		return replacements;
@@ -1872,7 +1888,7 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 					break;
 				}
 
-				if (right.isLeaf() || (opID(right) >= MULTIPLY)) { // not +, -
+				if (right.isLeaf() || (opID(right) >= MULTIPLY && opID(right) != FUNCTION_NVAR)) { // not +, -
 					if (rightStr.charAt(0) == '-') { // convert - - to +
 						if ((STRING_TYPE == STRING_TYPE_LATEX) && kernel.isInsertLineBreaks()) {
 							sb.append(" \\-+ ");
@@ -3749,6 +3765,7 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 			return Kernel.isEqual(((NumberValue) ev1).getDouble(), ((NumberValue) ev2).getDouble(),
 					Kernel.EPSILON);
 		} else if (ev1.isTextValue() && ev2.isTextValue()) {
+			Application.debug(ev1.getClass()+" "+((TextValue) ev1).toValueString());
 			return ((TextValue) ev1).toValueString().equals(((TextValue) ev2).toValueString());
 		} else if (ev1.isVectorValue() && ev2.isVectorValue()) {
 			return ((VectorValue) ev1).getVector().equals(((VectorValue) ev2).getVector());
