@@ -18,6 +18,7 @@ the Free Software Foundation.
 
 package geogebra.kernel.arithmetic;
 
+import geogebra.kernel.GeoElement;
 import geogebra.kernel.Kernel;
 
 import java.util.HashSet;
@@ -32,6 +33,7 @@ public interface ExpressionValue {
     public boolean isLeaf();
     public boolean isNumberValue();
 	public boolean isVectorValue();	
+	public boolean isVector3DValue();	
 	public boolean isListValue();
 	public boolean isBooleanValue();
 	public boolean isPolynomialInstance();
@@ -44,9 +46,12 @@ public interface ExpressionValue {
 	public boolean contains(ExpressionValue ev);
 	public ExpressionValue deepCopy(Kernel kernel);
     public ExpressionValue evaluate();
-    public HashSet getVariables();   
+    public HashSet<GeoElement> getVariables();   
     public String toValueString();
+    public String toOutputValueString();
     public String toLaTeXString(boolean symbolic);   
     public void resolveVariables();
+	public String toRealString();
+	public Kernel getKernel();
 }
 
