@@ -670,10 +670,14 @@ implements ExpressionValue, RealRootFunction, Functional {
 		// get variable string with tmp prefix, 
 		// e.g. "x" becomes "ggbtmpvarx" here
 		boolean isUseTempVariablePrefix = kernel.isUseTempVariablePrefix();
-		kernel.setUseTempVariablePrefix(true);
-		String varStr = fVars[0].toString();
-		kernel.setUseTempVariablePrefix(isUseTempVariablePrefix);
-    	
+		String varStr = null;
+		try{
+			kernel.setUseTempVariablePrefix(true);
+			varStr = fVars[0].toString();
+		}
+		finally{
+			kernel.setUseTempVariablePrefix(isUseTempVariablePrefix);	
+		}
     	StringBuilder sb = new StringBuilder();
     	sb.append("Derivative(");
     	if (!keepFractions)
