@@ -23,6 +23,7 @@ import geogebra.main.MyError;
 import geogebra.util.MaxSizeHashMap;
 import geogebra.util.MyMath;
 
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Set;
 
@@ -433,8 +434,13 @@ public class FunctionNVar extends ValidExpression implements ReplaceableValue,
 		}
 		
 		// try to replace x(x+1) by x*(x+1)
-		expression.replaceXYZnodes(xVar, yVar, zVar);		
+		expression.replaceXYZnodes(xVar, yVar, zVar, undecided);
+		for(ExpressionNode en: undecided)
+			en.setOperation(ExpressionNode.MULTIPLY);
+		undecided.clear();
 	}
+	
+	private static ArrayList<ExpressionNode> undecided = new ArrayList<ExpressionNode>();
 
 	private void initType(ExpressionValue ev) {
 		if (ev.isBooleanValue()) {
@@ -576,6 +582,8 @@ public class FunctionNVar extends ValidExpression implements ReplaceableValue,
 		// e.g. a in Derivative[a*x^2,x] needs to be renamed temporarily when a exists in GeoGebra
 		// see http://www.geogebra.org/trac/ticket/929
 		boolean oldTempVariableValue = kernel.isUseTempVariablePrefix();
+		String expString;
+		try{
 		kernel.setUseTempVariablePrefix(true);
 		
 		// did expression change since last time?
@@ -597,13 +605,13 @@ public class FunctionNVar extends ValidExpression implements ReplaceableValue,
 		}
 
 		// build command string for CAS
-		String expString = symbolic ? 
+		expString = symbolic ? 
 				casEvalStringSymbolic : 
 				expression.getCASstring(ExpressionNode.STRING_TYPE_GEOGEBRA, false);
-		
+		}finally{
 		// set back kernel
 		kernel.setUseTempVariablePrefix(oldTempVariableValue);
-
+		}
 		// substitute % by expString in ggbCasCmd
 		String casString = ggbCasCmd.replaceAll("%", expString);
 		FunctionNVar resultFun = null;		
