@@ -25,6 +25,11 @@ public class FunctionVariable extends MyDouble {
 		super(kernel);
 	}
 	
+	public FunctionVariable(Kernel kernel, String varStr) {
+		super(kernel);
+		setVarString(varStr);
+	}
+	
 	/**
 	 * Returns true to avoid deep copies in an ExpressionNode tree.
 	 */
@@ -34,10 +39,14 @@ public class FunctionVariable extends MyDouble {
 	
 	public void setVarString(String varStr) {
 		this.varStr = varStr;
-	}		
+	}
+	
+	public String getSetVarString() {
+		return varStr;
+	}
 	
 	final public String toString() {
-		return varStr;
+		return kernel.printVariableName(varStr);
 	}
 
 	/*
