@@ -36,7 +36,7 @@ import java.util.HashSet;
  * 
  * @author Markus Hohenwarter
  */
-public class MyList extends ValidExpression implements ListValue, ReplaceableValue {
+public class MyList extends ValidExpression implements ListValue, ReplaceableValue, ReplaceChildrenByValues {
 
 	private Kernel kernel;
 	private int matrixRows = -1;  // -1 means not calculated, 0 means not a matrix
@@ -957,6 +957,31 @@ public class MyList extends ValidExpression implements ListValue, ReplaceableVal
 		return isDefined;
 	}
 
+	public void clear() {
+		listElements.clear();
+	}
+
+	public void replaceChildrenByValues(GeoElement geo) { 
+		for(int i=0;i<size();i++){ 
+			ExpressionValue insert = getListElement(i); 
+			if(insert instanceof ReplaceChildrenByValues) 
+				((ReplaceChildrenByValues)insert).replaceChildrenByValues(geo); 
+		} 
+
+	} 
+
+	/** 
+	 * Same as deep copy, but doesn't deep copy elements 
+	 * @param kernel2 kernel 
+	 * @return copy of this list 
+	 */ 
+	 public MyList getCopy(Kernel kernel2) { 
+		 MyList ret = new MyList(kernel,size()); 
+		 for(int i=0;i<size();i++){ 
+			 ret.listElements.add(ExpressionNode.copy(listElements.get(i), kernel2)); 
+		 } 
+		 return ret; 
+	 } 
 
 
 }
