@@ -14,6 +14,7 @@ package geogebra.kernel.cas;
 
 import geogebra.kernel.CasEvaluableFunction;
 import geogebra.kernel.Construction;
+import geogebra.kernel.Kernel;
 
 public class AlgoPartialFractions extends AlgoCasBase {
    
@@ -36,11 +37,15 @@ public class AlgoPartialFractions extends AlgoCasBase {
 		// get variable string with tmp prefix, 
 		// e.g. "x" becomes "ggbtmpvarx" here
 		boolean isUseTempVariablePrefix = kernel.isUseTempVariablePrefix();
+		String varStr = null;
+		try{
 		kernel.setUseTempVariablePrefix(true);
-		String varStr = f.getVarString();
-		kernel.setUseTempVariablePrefix(isUseTempVariablePrefix);
+		varStr =  f.getVarString();
+		}finally{
+			kernel.setUseTempVariablePrefix(isUseTempVariablePrefix);
+		}
 
-		 kernel.internationalizeDigits = internationalizeDigits;
+		 Kernel.internationalizeDigits = internationalizeDigits;
 		
 		 sb.setLength(0);
 		 sb.append("PartialFractions(%");
