@@ -928,9 +928,10 @@ public class AlgebraProcessor {
 		} else if (en.operation == en.FUNCTION) {
 			ExpressionValue left = en.left;
 			ExpressionValue right = en.right;
+			//the isConstant() here makes difference between f(1) and f(x), see #2155
 			if (left.isLeaf() && left.isGeoElement() &&
 				right.isLeaf() && right.isNumberValue() &&
-				!isIndependent) {
+				 !right.isConstant() && !isIndependent) {
 				f = (GeoFunction) kernel.DependentGeoCopy(label, (GeoElement)left);
 				ret[0] = f;		
 				return ret;
