@@ -2,10 +2,11 @@ package geogebra.kernel.commands;
 
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoList;
+import geogebra.kernel.GeoLocus;
 import geogebra.kernel.GeoNumeric;
+import geogebra.kernel.GeoText;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.Command;
-import geogebra.main.Application;
 import geogebra.main.MyError;
 
 /*
@@ -32,17 +33,34 @@ public class CmdFirst extends CommandProcessor {
 						kernel.First(c.getLabel(),
 						(GeoList) arg[0], null ) };
 				return ret;
+			} else if (arg[0].isGeoText()) {
+				GeoElement[] ret = { 
+						kernel.First(c.getLabel(),
+						(GeoText) arg[0], null ) };
+				return ret;
 			} else
 				throw argErr(app, c.getName(), arg[0]);
 		case 2:
-			boolean ok0 = arg[0].isGeoList();
-			if ( ok0 && arg[1].isGeoNumeric() ) {
+			boolean list = arg[0].isGeoList();
+			boolean string = arg[0].isGeoText();
+			boolean locus = arg[0].isGeoLocus();
+			if ( list && arg[1].isGeoNumeric() ) {
 				GeoElement[] ret = { 
 						kernel.First(c.getLabel(),
 						(GeoList) arg[0], (GeoNumeric) arg[1] ) };
 				return ret;
+			} else if ( string && arg[1].isGeoNumeric() ) {
+				GeoElement[] ret = { 
+						kernel.First(c.getLabel(),
+						(GeoText) arg[0], (GeoNumeric) arg[1] ) };
+				return ret;
+			} else if ( locus && arg[1].isGeoNumeric() ) {
+				GeoElement[] ret = { 
+						kernel.FirstLocus(c.getLabel(),
+						(GeoLocus) arg[0], (GeoNumeric) arg[1] ) };
+				return ret;
 			} else
-				throw argErr(app, c.getName(), ok0 ? arg[1] : arg[0]);
+				throw argErr(app, c.getName(), (list && string) ? arg[1] : arg[0]);
 			
 		
 		default:
