@@ -3,6 +3,7 @@ package geogebra.kernel.commands;
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoNumeric;
+import geogebra.kernel.GeoText;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.Command;
 import geogebra.main.MyError;
@@ -31,18 +32,29 @@ public class CmdLast extends CommandProcessor {
 						kernel.Last(c.getLabel(),
 						(GeoList) arg[0], null ) };
 				return ret;
+			} else if (arg[0].isGeoText()) {
+				GeoElement[] ret = { 
+						kernel.Last(c.getLabel(),
+						(GeoText) arg[0], null ) };
+				return ret;
 			} else
 				throw argErr(app, c.getName(), arg[0]);
 		
 		case 2:
-			boolean ok0 = arg[0].isGeoList();
-			if ( ok0 && arg[1].isGeoNumeric() ) {
+			boolean list = arg[0].isGeoList();
+			boolean text = arg[0].isGeoText();
+			if ( list && arg[1].isGeoNumeric() ) {
 				GeoElement[] ret = { 
 						kernel.Last(c.getLabel(),
 						(GeoList) arg[0], (GeoNumeric) arg[1] ) };
 				return ret;
+			} else if ( text && arg[1].isGeoNumeric() ) {
+				GeoElement[] ret = { 
+						kernel.Last(c.getLabel(),
+						(GeoText) arg[0], (GeoNumeric) arg[1] ) };
+				return ret;
 			} else
-				throw argErr(app, c.getName(), ok0 ? arg[1] : arg[0]);
+				throw argErr(app, c.getName(), (list && text) ? arg[1] : arg[0]);
 		
 		default:
 			throw argNumErr(app, c.getName(), n);
