@@ -1,6 +1,8 @@
 package geogebra.kernel.commands;
 
 import geogebra.kernel.GeoElement;
+import geogebra.kernel.GeoFunction;
+import geogebra.kernel.GeoInterval;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.Command;
@@ -29,6 +31,11 @@ public class CmdMin extends CommandProcessor {
 						kernel.Min(c.getLabel(),
 						(GeoList) arg[0]) };
 				return ret;
+			} else if (arg[0].isGeoInterval()) {
+				GeoElement[] ret = { 
+						kernel.Min(c.getLabel(),
+						(GeoInterval) arg[0]) };
+				return ret;
 			} else
 				throw argErr(app, c.getName(), arg[0]);
 		
@@ -44,6 +51,23 @@ public class CmdMin extends CommandProcessor {
 				
 			}  else
 				throw argErr(app, c.getName(), arg[0]);
+		
+		case 3:		//Min[f,a,b]
+			arg=resArgs(c);
+			if( (ok[0]=arg[0].isGeoFunction()) &&
+			    (ok[1]=arg[1].isNumberValue())     &&
+			    (ok[2]=arg[2].isNumberValue())  )
+			{
+				GeoElement[] ret= {
+						kernel.Min(c.getLabel(),
+						(GeoFunction) arg[0],
+						(NumberValue) arg[1],
+						(NumberValue) arg[2])
+				};//array
+				return ret;
+			}else{
+				throw argErr(app,c.getName(),arg[0]);
+			}//if
 
 		default:
 			throw argNumErr(app, c.getName(), n);
