@@ -2,6 +2,7 @@ package geogebra.kernel.commands;
 
 import geogebra.kernel.GeoConic;
 import geogebra.kernel.GeoElement;
+import geogebra.kernel.GeoLocus;
 import geogebra.kernel.GeoPolygon;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.Command;
@@ -19,26 +20,31 @@ public class CmdPerimeter extends CommandProcessor {
 
 	public GeoElement[] process(Command c) throws MyError {
 		int n = c.getArgumentNumber();
-		boolean[] ok = new boolean[n];
 		GeoElement[] arg;
 
 		switch (n) {
 		case 1:
-			// Circumference[ <GeoPolygon> ]
+			// Perimeter[ <GeoPolygon> ]
 			arg = resArgs(c);
-			if (ok[0] = (arg[0].isGeoPolygon())) {
+			if ( (arg[0].isGeoPolygon())) {
 
 				GeoElement[] ret = { kernel.Perimeter(c.getLabel(),
 						(GeoPolygon) arg[0]) };
 				return ret;
 
-				// Circumference[ <Conic> ]
-			} else if (ok[0] = (arg[0].isGeoConic())) {
+				// Perimeter[ <Conic> ]
+			} else if ( (arg[0].isGeoConic())) {
 
 				GeoElement[] ret = { kernel.Circumference(c.getLabel(),
 						(GeoConic) arg[0]) };
 				return ret;
 
+			} else if ( (arg[0].isGeoLocus())) {
+				//Perimeter[locus]
+				GeoElement[] ret = { kernel.Perimeter(c.getLabel(),
+						(GeoLocus) arg[0]) };
+				return ret;
+
 			} else
 				throw argErr(app, c.getName(), arg[0]);
 
@@ -48,9 +54,3 @@ public class CmdPerimeter extends CommandProcessor {
 	}
 
 }
-
-class CmdCircumference extends CmdPerimeter {
-	public CmdCircumference(Kernel kernel) {
-		super(kernel);
-	}
-}
