@@ -2,6 +2,7 @@ package geogebra.kernel.commands;
 
 
 import geogebra.kernel.GeoElement;
+import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoPoint;
 import geogebra.kernel.Kernel;
 import geogebra.kernel.arithmetic.Command;
@@ -25,8 +26,14 @@ public GeoElement[] process(Command c) throws MyError {
 
     arg = resArgs(c);
     switch (n) {
-    	case 0:
-    		throw argNumErr(app, "Polygon", n);
+	    case 0 :
+	    	throw argNumErr(app, c.getName(), n);
+    	//G.Sturr 2010-3-14
+		case 1:
+		if (arg[0].isGeoList())
+			return kernel.Polygon(c.getLabels(), (GeoList) arg[0]);
+		//END G.Sturr
+		
     	case 3:        
         // regular polygon
         if (arg[0].isGeoPoint() && 
