@@ -52,7 +52,7 @@ public class MacroProcessor extends CommandProcessor {
 			
 			if (!lengthOk) {
 				StringBuilder sb = new StringBuilder();
-		        sb.append(app.getMenu("Macro") + " " + macro.getCommandName() + ":\n");
+		        sb.append(app.getMenu("Tool") + " " + macro.getCommandName() + ":\n");
 		        sb.append(app.getError("IllegalArgumentNumber") + ": " + arg.length);
 		        sb.append("\n\nSyntax:\n" + macro.toString());
 				throw new MyError(app, sb.toString());
@@ -63,7 +63,7 @@ public class MacroProcessor extends CommandProcessor {
 		for (int i=0; i < macroInputTypes.length; i++) {
 			if (!macroInputTypes[i].isInstance(arg[i]))	{				
 				StringBuilder sb = new StringBuilder();
-		        sb.append(app.getPlain("Macro") + " " + macro.getCommandName() + ":\n");
+		        sb.append(app.getMenu("Tool") + " " + macro.getCommandName() + ":\n");
 		        sb.append(app.getError("IllegalArgument") + ": ");	            
 	            sb.append(arg[i].getNameDescription());	            	            
 		        sb.append("\n\nSyntax:\n" + macro.toString());
