@@ -7,4 +7,10 @@ public interface RealRootDerivFunction extends RealRootFunction {
 	 * @param x	 
 	 */
 	public double [] evaluateDerivFunc(double x);
+	
+	/**
+	 * returns derivative's value
+	 * @param x	 
+	 */
+	public double evaluateDerivative(double x);
 }
