@@ -29,7 +29,7 @@ public class AlgoListCovariance extends AlgoStats2D {
         super(cons,label,geoListx,AlgoStats2D.STATS_COVARIANCE);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoListCovariance";
     }
 }
