@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Mean of y-coords of a list of Points
@@ -29,7 +29,11 @@ public class AlgoListMeanY extends AlgoStats2D {
         super(cons,label,geoListx,AlgoStats2D.STATS_MEANY);
     }
 
-    protected String getClassName() {
+	public AlgoListMeanY(Construction cons, GeoList geoListx) {
+        super(cons,geoListx,AlgoStats2D.STATS_MEANY);
+    }
+
+    public String getClassName() {
         return "AlgoListMeanY";
     }
 }
