@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Sxx of a list of Points
@@ -29,7 +29,11 @@ public class AlgoListSXX extends AlgoStats2D {
         super(cons,label,geoListx,AlgoStats2D.STATS_SXX);
     }
 
-    protected String getClassName() {
+	public AlgoListSXX(Construction cons, GeoList geoListx) {
+        super(cons,geoListx,AlgoStats2D.STATS_SXX);
+    }
+
+    public String getClassName() {
         return "AlgoListSXX";
     }
 }
