@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Sigma(xy) of a list of Points
@@ -29,7 +29,7 @@ public class AlgoListSigmaXY extends AlgoStats2D {
         super(cons,label,geoListx,AlgoStats2D.STATS_SIGMAXY);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoListSigmaXY";
     }
 }
