@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Mean of a list
@@ -29,7 +29,11 @@ public class AlgoMean extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_MEAN);
     }
 
-    protected String getClassName() {
+    public AlgoMean(Construction cons, GeoList geoList) {
+        super(cons,geoList,AlgoStats1D.STATS_MEAN);
+	}
+
+	public String getClassName() {
         return "AlgoMean";
     }
 }
