@@ -12,9 +12,9 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
+import geogebra.kernel.Construction;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoNumeric;
-import geogebra.kernel.Construction;
 
 /**
  * Mean of a list
@@ -34,7 +34,7 @@ public class AlgoProduct extends AlgoStats1D {
         super(cons,label,geoList,n,AlgoStats1D.STATS_PRODUCT);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoProduct";
     }
 }
