@@ -22,17 +22,17 @@ import geogebra.kernel.arithmetic.NumberValue;
  * @author Michael Borcherds
  * @version
  */
-public class AlgoRandom extends AlgoTwoNumFunction {
+public class AlgoRandom extends AlgoTwoNumFunction implements SetRandomValue {
 
 	public AlgoRandom(Construction cons, String label, NumberValue a,
 			NumberValue b) {
 		super(cons, label, a, b);
 
 		// output is random number
-		cons.addRandomNumber(num);
+		cons.addRandomGeo(num);
 }
 
-	protected String getClassName() {
+	public String getClassName() {
 		return "AlgoRandom";
 	}
 
@@ -44,11 +44,27 @@ public class AlgoRandom extends AlgoTwoNumFunction {
 		
 	}
 
-	private static double random(double a, double b) {
-		double min = Math.min(a, b);
-		double max = Math.max(a, b);
+	private double random(double a, double b) {
+		// make sure 4.000000001 is not rounded up to 5
+		a = kernel.checkInteger(a);
+		b = kernel.checkInteger(b);
+		
+		// Math.floor/ceil to make sure
+		// RandomBetween[3.2, 4.7] is between 3.2 and 4.7
+		double min = Math.ceil(Math.min(a, b));
+		double max = Math.floor(Math.max(a, b));
 		return Math.floor(Math.random()*(max - min +1)) + min;
 
 	}
 
+	public void setRandomValue(double d) {
+		d = Math.round(kernel.checkInteger(d));
+		
+		if (d >= a.getDouble() && d <= b.getDouble()) {
+			num.setValue(d);
+			num.updateRepaint();
+		}
+			
+	}
+
 }
