@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Sxx of a list
@@ -29,7 +29,7 @@ public class AlgoSXX extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_SXX);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoSXX";
     }
 }
