@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Sum of Squares of a list
@@ -29,7 +29,11 @@ public class AlgoSigmaXX extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_SIGMAXX);
     }
 
-    protected String getClassName() {
+	public AlgoSigmaXX(Construction cons, GeoList geoList) {
+        super(cons,geoList,AlgoStats1D.STATS_SIGMAXX);
+    }
+
+    public String getClassName() {
         return "AlgoSigmaXX";
     }
 }
