@@ -12,8 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
+import geogebra.kernel.GeoList;
 
 /**
  * Standard Deviation of a list
@@ -29,7 +29,11 @@ public class AlgoStandardDeviation extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_SD);
     }
 
-    protected String getClassName() {
+	public AlgoStandardDeviation(Construction cons, GeoList geoList) {
+        super(cons,geoList,AlgoStats1D.STATS_SD);
+    }
+
+    public String getClassName() {
         return "AlgoStandardDeviation";
     }
 }
