@@ -12,9 +12,9 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
+import geogebra.kernel.Construction;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoNumeric;
-import geogebra.kernel.Construction;
 
 /**
  * Mean of a list
@@ -30,11 +30,15 @@ public class AlgoSum extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_SIGMAX);
     }
     
+	public AlgoSum(Construction cons, GeoList geoList) {
+        super(cons,geoList,AlgoStats1D.STATS_SIGMAX);
+    }
+    
     public AlgoSum(Construction cons, String label, GeoList geoList, GeoNumeric n) {
         super(cons,label,geoList,n,AlgoStats1D.STATS_SIGMAX);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoSum";
     }
 }
