@@ -12,9 +12,8 @@ the Free Software Foundation.
 
 package geogebra.kernel.statistics;
 
-import geogebra.kernel.GeoList;
 import geogebra.kernel.Construction;
-import geogebra.kernel.statistics.AlgoStats1D;
+import geogebra.kernel.GeoList;
 
 
 /**
@@ -31,7 +30,7 @@ public class AlgoVariance extends AlgoStats1D {
         super(cons,label,geoList,AlgoStats1D.STATS_VARIANCE);
     }
 
-    protected String getClassName() {
+    public String getClassName() {
         return "AlgoVariance";
     }
 }
