@@ -119,22 +119,24 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 		} 	
 
 
+		GeoElement geo;					
+		if (app.selectedGeosSize() == 1) {
+			// selected geo
+			geo = app.getSelectedGeos().get(0);										
+		}				
+		else {
+			// last created geo
+			geo = app.getLastCreatedGeoElement();			
+		}	
+		
 		// show RENAME dialog when a letter is typed		
+		// or edit Textfield for any keypress
 		char ch = event.getKeyChar();		
-		if (Character.isLetter(ch) && 
+		if ((Character.isLetter(ch) && 
 				!event.isMetaDown() &&
 				!event.isAltDown() &&
-				!event.isControlDown()) 
+				!event.isControlDown()) || geo instanceof GeoTextField)
 		{
-			GeoElement geo;					
-			if (app.selectedGeosSize() == 1) {
-				// selected geo
-				geo = app.getSelectedGeos().get(0);										
-			}				
-			else {
-				// last created geo
-				geo = app.getLastCreatedGeoElement();			
-			}	
 
 			// open rename dialog
 			if (geo != null) {	
@@ -310,6 +312,14 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 				}
 				break;
 
+				// export to GeoGebraWeb
+			case KeyEvent.VK_B:
+				if (!app.isApplet() && event.isShiftDown()) {
+					app.exportToLMS(true);
+					consumed = true;
+				} 
+				break;
+
 			case KeyEvent.VK_C:
 				// Ctrl-shift-c: copy graphics view to clipboard
 				//   should also work in applets with no menubar
@@ -356,7 +366,7 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 
 			case KeyEvent.VK_M:
 				if (!app.isApplet() && event.isShiftDown()) {
-					app.exportToLMS();
+					app.exportToLMS(false);
 					consumed = true;
 				} else if (!app.isApplet() || app.isRightClickEnabled()) {
 					app.setStandardView();
@@ -504,6 +514,8 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 				break;
 
 				// Ctrl + "+", Ctrl + "-" zooms in or out in graphics view
+			case KeyEvent.VK_ADD:
+			case KeyEvent.VK_SUBTRACT:
 			case KeyEvent.VK_PLUS:
 			case KeyEvent.VK_MINUS:
 			case KeyEvent.VK_EQUALS:	
@@ -581,7 +593,7 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 			EuclidianViewInterface ev=app.getActiveEuclidianView();
 			int width = ev.getWidth();
 			int height = ev.getHeight();
-			if (ev.hasFocus())
+			if (ev.hasFocus() && app.isShiftDragZoomEnabled())
 				switch (keyCode) {
 
 				case KeyEvent.VK_PAGE_UP:
