@@ -11,6 +11,7 @@ package geogebra.plugin;
  
  */
 import geogebra.GeoGebra;
+import geogebra.JavaScriptAPI;
 import geogebra.cas.GeoGebraCAS;
 import geogebra.euclidian.EuclidianView;
 import geogebra.io.MyImageIO;
@@ -27,6 +28,8 @@ import geogebra.kernel.Traceable;
 import geogebra.kernel.arithmetic.NumberValue;
 import geogebra.kernel.commands.AlgebraProcessor;
 import geogebra.main.Application;
+import geogebra.util.Base64;
+import geogebra.util.Util;
 
 import java.awt.Color;
 import java.awt.geom.Rectangle2D;
@@ -71,7 +74,7 @@ import javax.imageio.stream.ImageOutputStream;
     Tranferred applet interface methods (the relevant ones) from GeoGebraAppletBase
 */
 
-public class GgbAPI {
+public class GgbAPI implements JavaScriptAPI {
 
     ///// ----- Properties ----- /////
     private Application         app=                null;   //References ...
@@ -1177,6 +1180,47 @@ public class GgbAPI {
 			return geo.isMoveable();
 	}
 
+	final public String getBase64() {
+		return getBase64(false);
+	}
+	
+	
+	public void setOnTheFlyPointCreationActive(boolean flag) {
+		app.setOnTheFlyPointCreationActive(flag);
+		
+	}
+
+	public void setUndoPoint() {
+		kernel.getConstruction().storeUndoInfo();
+	}
+
+
+	public String getIPAddress() {
+		return Util.getIPAddress();
+	}
+
+	public String getHostname() {
+		return Util.getHostname();
+	}
+
+	public void startAnimation() {
+		kernel.getAnimatonManager().startAnimation();		
+	}
+
+	public void stopAnimation() {
+		kernel.getAnimatonManager().stopAnimation();		
+	}
+
+	public void hideCursorWhenDragging(boolean hideCursorWhenDragging) {
+		kernel.getApplication()
+		.setUseTransparentCursorWhenDragging(hideCursorWhenDragging);
+	}
+
+	public boolean isAnimationRunning() {
+		return kernel.getAnimatonManager().isRunning();
+	}
+	
+
 
 		
 	
